/*@import "flat-ui-pro";*/
@font-face {
  font-family: 'Glyphicons Regular';
  src: url('[[relativeurl]]/public/app/default/assets/core/pyrocms/pyrocms-theme/resources/fonts/glyphicons/glyphicons-regular.eot');
  src: url('[[relativeurl]]/public/app/default/assets/core/pyrocms/pyrocms-theme/resources/fonts/glyphicons/glyphicons-regular.eot?#iefix') format('embedded-opentype'), url('[[relativeurl]]/public/app/default/assets/core/pyrocms/pyrocms-theme/resources/fonts/glyphicons/glyphicons-regular.woff2') format('woff2'), url('[[relativeurl]]/public/app/default/assets/core/pyrocms/pyrocms-theme/resources/fonts/glyphicons/glyphicons-regular.woff') format('woff'), url('[[relativeurl]]/public/app/default/assets/core/pyrocms/pyrocms-theme/resources/fonts/glyphicons/glyphicons-regular.ttf') format('truetype'), url('[[relativeurl]]/public/app/default/assets/core/pyrocms/pyrocms-theme/resources/fonts/glyphicons/glyphicons-regular.svg#glyphiconsregular') format('svg');
}
@font-face {
  font-family: 'Glyphicons Filetypes';
  src: url('[[relativeurl]]/public/app/default/assets/core/pyrocms/pyrocms-theme/resources/fonts/glyphicons/glyphicons-filetypes-regular.eot');
  src: url('[[relativeurl]]/public/app/default/assets/core/pyrocms/pyrocms-theme/resources/fonts/glyphicons/glyphicons-filetypes-regular.eot?#iefix') format('embedded-opentype'), url('[[relativeurl]]/public/app/default/assets/core/pyrocms/pyrocms-theme/resources/fonts/glyphicons/glyphicons-filetypes-regular.woff2') format('woff2'), url('[[relativeurl]]/public/app/default/assets/core/pyrocms/pyrocms-theme/resources/fonts/glyphicons/glyphicons-filetypes-regular.woff') format('woff'), url('[[relativeurl]]/public/app/default/assets/core/pyrocms/pyrocms-theme/resources/fonts/glyphicons/glyphicons-filetypes-regular.ttf') format('truetype'), url('[[relativeurl]]/public/app/default/assets/core/pyrocms/pyrocms-theme/resources/fonts/glyphicons/glyphicons-filetypes-regular.svg#glyphicons_filetypesregular') format('svg');
}
.filetypes {
  position: relative;
  top: 1px;
  display: inline-block;
  font-family: 'Glyphicons Filetypes';
  font-style: normal;
  font-weight: normal;
  vertical-align: top;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
}
.filetypes.x05 {
  font-size: 12px;
}
.filetypes.x2 {
  font-size: 48px;
}
.filetypes.x3 {
  font-size: 72px;
}
.filetypes.x4 {
  font-size: 96px;
}
.filetypes.x5 {
  font-size: 120px;
}
.filetypes.light:before {
  color: #f2f2f2;
}
.filetypes.drop:before {
  text-shadow: -1px 1px 3px rgba(0, 0, 0, 0.3);
}
.filetypes.flip {
  -moz-transform: scaleX(-1);
  -o-transform: scaleX(-1);
  -webkit-transform: scaleX(-1);
  transform: scaleX(-1);
  filter: FlipH;
  -ms-filter: "FlipH";
}
.filetypes.flipv {
  -moz-transform: scaleY(-1);
  -o-transform: scaleY(-1);
  -webkit-transform: scaleY(-1);
  transform: scaleY(-1);
  filter: FlipV;
  -ms-filter: "FlipV";
}
.filetypes.rotate90 {
  -webkit-transform: rotate(90deg);
  -moz-transform: rotate(90deg);
  -ms-transform: rotate(90deg);
  transform: rotate(90deg);
}
.filetypes.rotate180 {
  -webkit-transform: rotate(180deg);
  -moz-transform: rotate(180deg);
  -ms-transform: rotate(180deg);
  transform: rotate(180deg);
}
.filetypes.rotate270 {
  -webkit-transform: rotate(270deg);
  -moz-transform: rotate(270deg);
  -ms-transform: rotate(270deg);
  transform: rotate(270deg);
}
.filetypes-txt:before {
  content: "\E001";
}
.filetypes-doc:before {
  content: "\E002";
}
.filetypes-rtf:before {
  content: "\E003";
}
.filetypes-log:before {
  content: "\E004";
}
.filetypes-tex:before {
  content: "\E005";
}
.filetypes-msg:before {
  content: "\E006";
}
.filetypes-text:before {
  content: "\E007";
}
.filetypes-wpd:before {
  content: "\E008";
}
.filetypes-wps:before {
  content: "\E009";
}
.filetypes-docx:before {
  content: "\E010";
}
.filetypes-page:before {
  content: "\E011";
}
.filetypes-csv:before {
  content: "\E012";
}
.filetypes-dat:before {
  content: "\E013";
}
.filetypes-tar:before {
  content: "\E014";
}
.filetypes-xml:before {
  content: "\E015";
}
.filetypes-vcf:before {
  content: "\E016";
}
.filetypes-pps:before {
  content: "\E017";
}
.filetypes-key:before {
  content: "\E018";
}
.filetypes-ppt:before {
  content: "\E019";
}
.filetypes-pptx:before {
  content: "\E020";
}
.filetypes-sdf:before {
  content: "\E021";
}
.filetypes-gbr:before {
  content: "\E022";
}
.filetypes-ged:before {
  content: "\E023";
}
.filetypes-mp3:before {
  content: "\E024";
}
.filetypes-m4a:before {
  content: "\E025";
}
.filetypes-waw:before {
  content: "\E026";
}
.filetypes-wma:before {
  content: "\E027";
}
.filetypes-mpa:before {
  content: "\E028";
}
.filetypes-iff:before {
  content: "\E029";
}
.filetypes-aif:before {
  content: "\E030";
}
.filetypes-ra:before {
  content: "\E031";
}
.filetypes-mid:before {
  content: "\E032";
}
.filetypes-m3v:before {
  content: "\E033";
}
.filetypes-e-3gp:before {
  content: "\E034";
}
.filetypes-swf:before {
  content: "\E035";
}
.filetypes-avi:before {
  content: "\E036";
}
.filetypes-asx:before {
  content: "\E037";
}
.filetypes-mp4:before {
  content: "\E038";
}
.filetypes-e-3g2:before {
  content: "\E039";
}
.filetypes-mpg:before {
  content: "\E040";
}
.filetypes-asf:before {
  content: "\E041";
}
.filetypes-vob:before {
  content: "\E042";
}
.filetypes-wmv:before {
  content: "\E043";
}
.filetypes-mov:before {
  content: "\E044";
}
.filetypes-srt:before {
  content: "\E045";
}
.filetypes-m4v:before {
  content: "\E046";
}
.filetypes-flv:before {
  content: "\E047";
}
.filetypes-rm:before {
  content: "\E048";
}
.filetypes-png:before {
  content: "\E049";
}
.filetypes-psd:before {
  content: "\E050";
}
.filetypes-psp:before {
  content: "\E051";
}
.filetypes-jpg:before {
  content: "\E052";
}
.filetypes-tif:before {
  content: "\E053";
}
.filetypes-tiff:before {
  content: "\E054";
}
.filetypes-gif:before {
  content: "\E055";
}
.filetypes-bmp:before {
  content: "\E056";
}
.filetypes-tga:before {
  content: "\E057";
}
.filetypes-thm:before {
  content: "\E058";
}
.filetypes-yuv:before {
  content: "\E059";
}
.filetypes-dds:before {
  content: "\E060";
}
.filetypes-ai:before {
  content: "\E061";
}
.filetypes-eps:before {
  content: "\E062";
}
.filetypes-ps:before {
  content: "\E063";
}
.filetypes-svg:before {
  content: "\E064";
}
.filetypes-pdf:before {
  content: "\E065";
}
.filetypes-pct:before {
  content: "\E066";
}
.filetypes-indd:before {
  content: "\E067";
}
.filetypes-xlr:before {
  content: "\E068";
}
.filetypes-xls:before {
  content: "\E069";
}
.filetypes-xlsx:before {
  content: "\E070";
}
.filetypes-db:before {
  content: "\E071";
}
.filetypes-dbf:before {
  content: "\E072";
}
.filetypes-mdb:before {
  content: "\E073";
}
.filetypes-pdb:before {
  content: "\E074";
}
.filetypes-sql:before {
  content: "\E075";
}
.filetypes-aacd:before {
  content: "\E076";
}
.filetypes-app:before {
  content: "\E077";
}
.filetypes-exe:before {
  content: "\E078";
}
.filetypes-com:before {
  content: "\E079";
}
.filetypes-bat:before {
  content: "\E080";
}
.filetypes-apk:before {
  content: "\E081";
}
.filetypes-jar:before {
  content: "\E082";
}
.filetypes-hsf:before {
  content: "\E083";
}
.filetypes-pif:before {
  content: "\E084";
}
.filetypes-vb:before {
  content: "\E085";
}
.filetypes-cgi:before {
  content: "\E086";
}
.filetypes-css:before {
  content: "\E087";
}
.filetypes-js:before {
  content: "\E088";
}
.filetypes-php:before {
  content: "\E089";
}
.filetypes-xhtml:before {
  content: "\E090";
}
.filetypes-htm:before {
  content: "\E091";
}
.filetypes-html:before {
  content: "\E092";
}
.filetypes-asp:before {
  content: "\E093";
}
.filetypes-cer:before {
  content: "\E094";
}
.filetypes-jsp:before {
  content: "\E095";
}
.filetypes-cfm:before {
  content: "\E096";
}
.filetypes-aspx:before {
  content: "\E097";
}
.filetypes-rss:before {
  content: "\E098";
}
.filetypes-csr:before {
  content: "\E099";
}
.filetypes-less:before {
  content: "\003C";
}
.filetypes-otf:before {
  content: "\E101";
}
.filetypes-ttf:before {
  content: "\E102";
}
.filetypes-font:before {
  content: "\E103";
}
.filetypes-fnt:before {
  content: "\E104";
}
.filetypes-eot:before {
  content: "\E105";
}
.filetypes-woff:before {
  content: "\E106";
}
.filetypes-zip:before {
  content: "\E107";
}
.filetypes-zipx:before {
  content: "\E108";
}
.filetypes-rar:before {
  content: "\E109";
}
.filetypes-targ:before {
  content: "\E110";
}
.filetypes-sitx:before {
  content: "\E111";
}
.filetypes-deb:before {
  content: "\E112";
}
.filetypes-e-7z:before {
  content: "\E113";
}
.filetypes-pkg:before {
  content: "\E114";
}
.filetypes-rpm:before {
  content: "\E115";
}
.filetypes-cbr:before {
  content: "\E116";
}
.filetypes-gz:before {
  content: "\E117";
}
.filetypes-dmg:before {
  content: "\E118";
}
.filetypes-cue:before {
  content: "\E119";
}
.filetypes-bin:before {
  content: "\E120";
}
.filetypes-iso:before {
  content: "\E121";
}
.filetypes-hdf:before {
  content: "\E122";
}
.filetypes-vcd:before {
  content: "\E123";
}
.filetypes-bak:before {
  content: "\E124";
}
.filetypes-tmp:before {
  content: "\E125";
}
.filetypes-ics:before {
  content: "\E126";
}
.filetypes-msi:before {
  content: "\E127";
}
.filetypes-cfg:before {
  content: "\E128";
}
.filetypes-ini:before {
  content: "\E129";
}
.filetypes-prf:before {
  content: "\E130";
}
.animated {
  -webkit-animation-duration: 1s;
  animation-duration: 1s;
  -webkit-animation-fill-mode: both;
  animation-fill-mode: both;
  -webkit-animation-timing-function: ease-in-out;
  animation-timing-function: ease-in-out;
  animation-iteration-count: infinite;
  -webkit-animation-iteration-count: infinite;
}
@-webkit-keyframes pulse {
  0% {
    -webkit-transform: scale(1);
  }
  50% {
    -webkit-transform: scale(1.1);
  }
  100% {
    -webkit-transform: scale(1);
  }
}
@keyframes pulse {
  0% {
    transform: scale(1);
  }
  50% {
    transform: scale(1.1);
  }
  100% {
    transform: scale(1);
  }
}
.pulse {
  -webkit-animation-name: pulse;
  animation-name: pulse;
}
@-webkit-keyframes rotateIn {
  0% {
    -webkit-transform-origin: center center;
    -webkit-transform: rotate(-200deg);
    opacity: 0;
  }
  100% {
    -webkit-transform-origin: center center;
    -webkit-transform: rotate(0);
    opacity: 1;
  }
}
@keyframes rotateIn {
  0% {
    transform-origin: center center;
    transform: rotate(-200deg);
    opacity: 0;
  }
  100% {
    transform-origin: center center;
    transform: rotate(0);
    opacity: 1;
  }
}
.rotateIn {
  -webkit-animation-name: rotateIn;
  animation-name: rotateIn;
}
@-webkit-keyframes bounce {
  0%,
  20%,
  50%,
  80%,
  100% {
    -webkit-transform: translateY(0);
  }
  40% {
    -webkit-transform: translateY(-30px);
  }
  60% {
    -webkit-transform: translateY(-15px);
  }
}
@keyframes bounce {
  0%,
  20%,
  50%,
  80%,
  100% {
    transform: translateY(0);
  }
  40% {
    transform: translateY(-30px);
  }
  60% {
    transform: translateY(-15px);
  }
}
.bounce {
  -webkit-animation-name: bounce;
  animation-name: bounce;
}
@-webkit-keyframes swing {
  20%,
  40%,
  60%,
  80%,
  100% {
    -webkit-transform-origin: top center;
  }
  20% {
    -webkit-transform: rotate(15deg);
  }
  40% {
    -webkit-transform: rotate(-10deg);
  }
  60% {
    -webkit-transform: rotate(5deg);
  }
  80% {
    -webkit-transform: rotate(-5deg);
  }
  100% {
    -webkit-transform: rotate(0deg);
  }
}
@keyframes swing {
  20% {
    transform: rotate(15deg);
  }
  40% {
    transform: rotate(-10deg);
  }
  60% {
    transform: rotate(5deg);
  }
  80% {
    transform: rotate(-5deg);
  }
  100% {
    transform: rotate(0deg);
  }
}
.swing {
  -webkit-transform-origin: top center;
  transform-origin: top center;
  -webkit-animation-name: swing;
  animation-name: swing;
}
@-webkit-keyframes tada {
  0% {
    -webkit-transform: scale(1);
  }
  10%,
  20% {
    -webkit-transform: scale(0.9) rotate(-3deg);
  }
  30%,
  50%,
  70%,
  90% {
    -webkit-transform: scale(1.1) rotate(3deg);
  }
  40%,
  60%,
  80% {
    -webkit-transform: scale(1.1) rotate(-3deg);
  }
  100% {
    -webkit-transform: scale(1) rotate(0);
  }
}
@keyframes tada {
  0% {
    transform: scale(1);
  }
  10%,
  20% {
    transform: scale(0.9) rotate(-3deg);
  }
  30%,
  50%,
  70%,
  90% {
    transform: scale(1.1) rotate(3deg);
  }
  40%,
  60%,
  80% {
    transform: scale(1.1) rotate(-3deg);
  }
  100% {
    transform: scale(1) rotate(0);
  }
}
.tada {
  -webkit-animation-name: tada;
  animation-name: tada;
}
.glyphicons {
  position: relative;
  top: 1px;
  display: inline-block;
  font-family: 'Glyphicons Regular';
  font-style: normal;
  font-weight: normal;
  vertical-align: top;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
}
.glyphicons.x05 {
  font-size: 12px;
}
.glyphicons.x2 {
  font-size: 48px;
}
.glyphicons.x3 {
  font-size: 72px;
}
.glyphicons.x4 {
  font-size: 96px;
}
.glyphicons.x5 {
  font-size: 120px;
}
.glyphicons.light:before {
  color: #f2f2f2;
}
.glyphicons.drop:before {
  text-shadow: -1px 1px 3px rgba(0, 0, 0, 0.3);
}
.glyphicons.flip {
  -moz-transform: scaleX(-1);
  -o-transform: scaleX(-1);
  -webkit-transform: scaleX(-1);
  transform: scaleX(-1);
  filter: FlipH;
  -ms-filter: "FlipH";
}
.glyphicons.flipv {
  -moz-transform: scaleY(-1);
  -o-transform: scaleY(-1);
  -webkit-transform: scaleY(-1);
  transform: scaleY(-1);
  filter: FlipV;
  -ms-filter: "FlipV";
}
.glyphicons.rotate90 {
  -webkit-transform: rotate(90deg);
  -moz-transform: rotate(90deg);
  -ms-transform: rotate(90deg);
  transform: rotate(90deg);
}
.glyphicons.rotate180 {
  -webkit-transform: rotate(180deg);
  -moz-transform: rotate(180deg);
  -ms-transform: rotate(180deg);
  transform: rotate(180deg);
}
.glyphicons.rotate270 {
  -webkit-transform: rotate(270deg);
  -moz-transform: rotate(270deg);
  -ms-transform: rotate(270deg);
  transform: rotate(270deg);
}
.glyphicons-glass:before {
  content: "\E001";
}
.glyphicons-leaf:before {
  content: "\E002";
}
.glyphicons-dog:before {
  content: "\E003";
}
.glyphicons-user:before {
  content: "\E004";
}
.glyphicons-girl:before {
  content: "\E005";
}
.glyphicons-car:before {
  content: "\E006";
}
.glyphicons-user-add:before {
  content: "\E007";
}
.glyphicons-user-remove:before {
  content: "\E008";
}
.glyphicons-film:before {
  content: "\E009";
}
.glyphicons-magic:before {
  content: "\E010";
}
.glyphicons-envelope:before {
  content: "\2709";
}
.glyphicons-camera:before {
  content: "\E011";
}
.glyphicons-heart:before {
  content: "\E013";
}
.glyphicons-beach-umbrella:before {
  content: "\E014";
}
.glyphicons-train:before {
  content: "\E015";
}
.glyphicons-print:before {
  content: "\E016";
}
.glyphicons-bin:before {
  content: "\E017";
}
.glyphicons-music:before {
  content: "\E018";
}
.glyphicons-note:before {
  content: "\E019";
}
.glyphicons-heart-empty:before {
  content: "\E020";
}
.glyphicons-home:before {
  content: "\E021";
}
.glyphicons-snowflake:before {
  content: "\2744";
}
.glyphicons-fire:before {
  content: "\E023";
}
.glyphicons-magnet:before {
  content: "\E024";
}
.glyphicons-parents:before {
  content: "\E025";
}
.glyphicons-binoculars:before {
  content: "\E026";
}
.glyphicons-road:before {
  content: "\E027";
}
.glyphicons-search:before {
  content: "\E028";
}
.glyphicons-cars:before {
  content: "\E029";
}
.glyphicons-notes-2:before {
  content: "\E030";
}
.glyphicons-pencil:before {
  content: "\270F";
}
.glyphicons-bus:before {
  content: "\E032";
}
.glyphicons-wifi-alt:before {
  content: "\E033";
}
.glyphicons-luggage:before {
  content: "\E034";
}
.glyphicons-old-man:before {
  content: "\E035";
}
.glyphicons-woman:before {
  content: "\E036";
}
.glyphicons-file:before {
  content: "\E037";
}
.glyphicons-coins:before {
  content: "\E038";
}
.glyphicons-airplane:before {
  content: "\2708";
}
.glyphicons-notes:before {
  content: "\E040";
}
.glyphicons-stats:before {
  content: "\E041";
}
.glyphicons-charts:before {
  content: "\E042";
}
.glyphicons-pie-chart:before {
  content: "\E043";
}
.glyphicons-group:before {
  content: "\E044";
}
.glyphicons-keys:before {
  content: "\E045";
}
.glyphicons-calendar:before {
  content: "\E046";
}
.glyphicons-router:before {
  content: "\E047";
}
.glyphicons-camera-small:before {
  content: "\E048";
}
.glyphicons-star-empty:before {
  content: "\E049";
}
.glyphicons-star:before {
  content: "\E050";
}
.glyphicons-link:before {
  content: "\E051";
}
.glyphicons-eye-open:before {
  content: "\E052";
}
.glyphicons-eye-close:before {
  content: "\E053";
}
.glyphicons-alarm:before {
  content: "\E054";
}
.glyphicons-clock:before {
  content: "\E055";
}
.glyphicons-stopwatch:before {
  content: "\E056";
}
.glyphicons-projector:before {
  content: "\E057";
}
.glyphicons-history:before {
  content: "\E058";
}
.glyphicons-truck:before {
  content: "\E059";
}
.glyphicons-cargo:before {
  content: "\E060";
}
.glyphicons-compass:before {
  content: "\E061";
}
.glyphicons-keynote:before {
  content: "\E062";
}
.glyphicons-paperclip:before {
  content: "\E063";
}
.glyphicons-power:before {
  content: "\E064";
}
.glyphicons-lightbulb:before {
  content: "\E065";
}
.glyphicons-tag:before {
  content: "\E066";
}
.glyphicons-tags:before {
  content: "\E067";
}
.glyphicons-cleaning:before {
  content: "\E068";
}
.glyphicons-ruler:before {
  content: "\E069";
}
.glyphicons-gift:before {
  content: "\E070";
}
.glyphicons-umbrella:before {
  content: "\2602";
}
.glyphicons-book:before {
  content: "\E072";
}
.glyphicons-bookmark:before {
  content: "\E073";
}
.glyphicons-wifi:before {
  content: "\E074";
}
.glyphicons-cup:before {
  content: "\E075";
}
.glyphicons-stroller:before {
  content: "\E076";
}
.glyphicons-headphones:before {
  content: "\E077";
}
.glyphicons-headset:before {
  content: "\E078";
}
.glyphicons-warning-sign:before {
  content: "\E079";
}
.glyphicons-signal:before {
  content: "\E080";
}
.glyphicons-retweet:before {
  content: "\E081";
}
.glyphicons-refresh:before {
  content: "\E082";
}
.glyphicons-roundabout:before {
  content: "\E083";
}
.glyphicons-random:before {
  content: "\E084";
}
.glyphicons-heat:before {
  content: "\E085";
}
.glyphicons-repeat:before {
  content: "\E086";
}
.glyphicons-display:before {
  content: "\E087";
}
.glyphicons-log-book:before {
  content: "\E088";
}
.glyphicons-address-book:before {
  content: "\E089";
}
.glyphicons-building:before {
  content: "\E090";
}
.glyphicons-eyedropper:before {
  content: "\E091";
}
.glyphicons-adjust:before {
  content: "\E092";
}
.glyphicons-tint:before {
  content: "\E093";
}
.glyphicons-crop:before {
  content: "\E094";
}
.glyphicons-vector-path-square:before {
  content: "\E095";
}
.glyphicons-vector-path-circle:before {
  content: "\E096";
}
.glyphicons-vector-path-polygon:before {
  content: "\E097";
}
.glyphicons-vector-path-line:before {
  content: "\E098";
}
.glyphicons-vector-path-curve:before {
  content: "\E099";
}
.glyphicons-vector-path-all:before {
  content: "\E100";
}
.glyphicons-font:before {
  content: "\E101";
}
.glyphicons-italic:before {
  content: "\E102";
}
.glyphicons-bold:before {
  content: "\E103";
}
.glyphicons-text-underline:before {
  content: "\E104";
}
.glyphicons-text-strike:before {
  content: "\E105";
}
.glyphicons-text-height:before {
  content: "\E106";
}
.glyphicons-text-width:before {
  content: "\E107";
}
.glyphicons-text-resize:before {
  content: "\E108";
}
.glyphicons-left-indent:before {
  content: "\E109";
}
.glyphicons-right-indent:before {
  content: "\E110";
}
.glyphicons-align-left:before {
  content: "\E111";
}
.glyphicons-align-center:before {
  content: "\E112";
}
.glyphicons-align-right:before {
  content: "\E113";
}
.glyphicons-justify:before {
  content: "\E114";
}
.glyphicons-list:before {
  content: "\E115";
}
.glyphicons-text-smaller:before {
  content: "\E116";
}
.glyphicons-text-bigger:before {
  content: "\E117";
}
.glyphicons-embed:before {
  content: "\E118";
}
.glyphicons-embed-close:before {
  content: "\E119";
}
.glyphicons-table:before {
  content: "\E120";
}
.glyphicons-message-full:before {
  content: "\E121";
}
.glyphicons-message-empty:before {
  content: "\E122";
}
.glyphicons-message-in:before {
  content: "\E123";
}
.glyphicons-message-out:before {
  content: "\E124";
}
.glyphicons-message-plus:before {
  content: "\E125";
}
.glyphicons-message-minus:before {
  content: "\E126";
}
.glyphicons-message-ban:before {
  content: "\E127";
}
.glyphicons-message-flag:before {
  content: "\E128";
}
.glyphicons-message-lock:before {
  content: "\E129";
}
.glyphicons-message-new:before {
  content: "\E130";
}
.glyphicons-inbox:before {
  content: "\E131";
}
.glyphicons-inbox-plus:before {
  content: "\E132";
}
.glyphicons-inbox-minus:before {
  content: "\E133";
}
.glyphicons-inbox-lock:before {
  content: "\E134";
}
.glyphicons-inbox-in:before {
  content: "\E135";
}
.glyphicons-inbox-out:before {
  content: "\E136";
}
.glyphicons-cogwheel:before {
  content: "\E137";
}
.glyphicons-cogwheels:before {
  content: "\E138";
}
.glyphicons-picture:before {
  content: "\E139";
}
.glyphicons-adjust-alt:before {
  content: "\E140";
}
.glyphicons-database-lock:before {
  content: "\E141";
}
.glyphicons-database-plus:before {
  content: "\E142";
}
.glyphicons-database-minus:before {
  content: "\E143";
}
.glyphicons-database-ban:before {
  content: "\E144";
}
.glyphicons-folder-open:before {
  content: "\E145";
}
.glyphicons-folder-plus:before {
  content: "\E146";
}
.glyphicons-folder-minus:before {
  content: "\E147";
}
.glyphicons-folder-lock:before {
  content: "\E148";
}
.glyphicons-folder-flag:before {
  content: "\E149";
}
.glyphicons-folder-new:before {
  content: "\E150";
}
.glyphicons-edit:before {
  content: "\E151";
}
.glyphicons-new-window:before {
  content: "\E152";
}
.glyphicons-check:before {
  content: "\E153";
}
.glyphicons-unchecked:before {
  content: "\E154";
}
.glyphicons-more-windows:before {
  content: "\E155";
}
.glyphicons-show-big-thumbnails:before {
  content: "\E156";
}
.glyphicons-show-thumbnails:before {
  content: "\E157";
}
.glyphicons-show-thumbnails-with-lines:before {
  content: "\E158";
}
.glyphicons-show-lines:before {
  content: "\E159";
}
.glyphicons-playlist:before {
  content: "\E160";
}
.glyphicons-imac:before {
  content: "\E161";
}
.glyphicons-macbook:before {
  content: "\E162";
}
.glyphicons-ipad:before {
  content: "\E163";
}
.glyphicons-iphone:before {
  content: "\E164";
}
.glyphicons-iphone-transfer:before {
  content: "\E165";
}
.glyphicons-iphone-exchange:before {
  content: "\E166";
}
.glyphicons-ipod:before {
  content: "\E167";
}
.glyphicons-ipod-shuffle:before {
  content: "\E168";
}
.glyphicons-ear-plugs:before {
  content: "\E169";
}
.glyphicons-record:before {
  content: "\E170";
}
.glyphicons-step-backward:before {
  content: "\E171";
}
.glyphicons-fast-backward:before {
  content: "\E172";
}
.glyphicons-rewind:before {
  content: "\E173";
}
.glyphicons-play:before {
  content: "\E174";
}
.glyphicons-pause:before {
  content: "\E175";
}
.glyphicons-stop:before {
  content: "\E176";
}
.glyphicons-forward:before {
  content: "\E177";
}
.glyphicons-fast-forward:before {
  content: "\E178";
}
.glyphicons-step-forward:before {
  content: "\E179";
}
.glyphicons-eject:before {
  content: "\E180";
}
.glyphicons-facetime-video:before {
  content: "\E181";
}
.glyphicons-download-alt:before {
  content: "\E182";
}
.glyphicons-mute:before {
  content: "\E183";
}
.glyphicons-volume-down:before {
  content: "\E184";
}
.glyphicons-volume-up:before {
  content: "\E185";
}
.glyphicons-screenshot:before {
  content: "\E186";
}
.glyphicons-move:before {
  content: "\E187";
}
.glyphicons-more:before {
  content: "\E188";
}
.glyphicons-brightness-reduce:before {
  content: "\E189";
}
.glyphicons-brightness-increase:before {
  content: "\E190";
}
.glyphicons-circle-plus:before {
  content: "\E191";
}
.glyphicons-circle-minus:before {
  content: "\E192";
}
.glyphicons-circle-remove:before {
  content: "\E193";
}
.glyphicons-circle-ok:before {
  content: "\E194";
}
.glyphicons-circle-question-mark:before {
  content: "\E195";
}
.glyphicons-circle-info:before {
  content: "\E196";
}
.glyphicons-circle-exclamation-mark:before {
  content: "\E197";
}
.glyphicons-remove:before {
  content: "\E198";
}
.glyphicons-ok:before {
  content: "\E199";
}
.glyphicons-ban:before {
  content: "\E200";
}
.glyphicons-download:before {
  content: "\E201";
}
.glyphicons-upload:before {
  content: "\E202";
}
.glyphicons-shopping-cart:before {
  content: "\E203";
}
.glyphicons-lock:before {
  content: "\E204";
}
.glyphicons-unlock:before {
  content: "\E205";
}
.glyphicons-electricity:before {
  content: "\E206";
}
.glyphicons-ok-2:before {
  content: "\E207";
}
.glyphicons-remove-2:before {
  content: "\E208";
}
.glyphicons-cart-out:before {
  content: "\E209";
}
.glyphicons-cart-in:before {
  content: "\E210";
}
.glyphicons-left-arrow:before {
  content: "\E211";
}
.glyphicons-right-arrow:before {
  content: "\E212";
}
.glyphicons-down-arrow:before {
  content: "\E213";
}
.glyphicons-up-arrow:before {
  content: "\E214";
}
.glyphicons-resize-small:before {
  content: "\E215";
}
.glyphicons-resize-full:before {
  content: "\E216";
}
.glyphicons-circle-arrow-left:before {
  content: "\E217";
}
.glyphicons-circle-arrow-right:before {
  content: "\E218";
}
.glyphicons-circle-arrow-top:before {
  content: "\E219";
}
.glyphicons-circle-arrow-down:before {
  content: "\E220";
}
.glyphicons-play-button:before {
  content: "\E221";
}
.glyphicons-unshare:before {
  content: "\E222";
}
.glyphicons-share:before {
  content: "\E223";
}
.glyphicons-chevron-right:before {
  content: "\E224";
}
.glyphicons-chevron-left:before {
  content: "\E225";
}
.glyphicons-bluetooth:before {
  content: "\E226";
}
.glyphicons-euro:before {
  content: "\20AC";
}
.glyphicons-usd:before {
  content: "\E228";
}
.glyphicons-gbp:before {
  content: "\E229";
}
.glyphicons-retweet-2:before {
  content: "\E230";
}
.glyphicons-moon:before {
  content: "\E231";
}
.glyphicons-sun:before {
  content: "\2609";
}
.glyphicons-cloud:before {
  content: "\2601";
}
.glyphicons-direction:before {
  content: "\E234";
}
.glyphicons-brush:before {
  content: "\E235";
}
.glyphicons-pen:before {
  content: "\E236";
}
.glyphicons-zoom-in:before {
  content: "\E237";
}
.glyphicons-zoom-out:before {
  content: "\E238";
}
.glyphicons-pin:before {
  content: "\E239";
}
.glyphicons-albums:before {
  content: "\E240";
}
.glyphicons-rotation-lock:before {
  content: "\E241";
}
.glyphicons-flash:before {
  content: "\E242";
}
.glyphicons-google-maps:before {
  content: "\E243";
}
.glyphicons-anchor:before {
  content: "\2693";
}
.glyphicons-conversation:before {
  content: "\E245";
}
.glyphicons-chat:before {
  content: "\E246";
}
.glyphicons-male:before {
  content: "\E247";
}
.glyphicons-female:before {
  content: "\E248";
}
.glyphicons-asterisk:before {
  content: "\002A";
}
.glyphicons-divide:before {
  content: "\00F7";
}
.glyphicons-snorkel-diving:before {
  content: "\E251";
}
.glyphicons-scuba-diving:before {
  content: "\E252";
}
.glyphicons-oxygen-bottle:before {
  content: "\E253";
}
.glyphicons-fins:before {
  content: "\E254";
}
.glyphicons-fishes:before {
  content: "\E255";
}
.glyphicons-boat:before {
  content: "\E256";
}
.glyphicons-delete:before {
  content: "\E257";
}
.glyphicons-sheriffs-star:before {
  content: "\E258";
}
.glyphicons-qrcode:before {
  content: "\E259";
}
.glyphicons-barcode:before {
  content: "\E260";
}
.glyphicons-pool:before {
  content: "\E261";
}
.glyphicons-buoy:before {
  content: "\E262";
}
.glyphicons-spade:before {
  content: "\E263";
}
.glyphicons-bank:before {
  content: "\E264";
}
.glyphicons-vcard:before {
  content: "\E265";
}
.glyphicons-electrical-plug:before {
  content: "\E266";
}
.glyphicons-flag:before {
  content: "\E267";
}
.glyphicons-credit-card:before {
  content: "\E268";
}
.glyphicons-keyboard-wireless:before {
  content: "\E269";
}
.glyphicons-keyboard-wired:before {
  content: "\E270";
}
.glyphicons-shield:before {
  content: "\E271";
}
.glyphicons-ring:before {
  content: "\02DA";
}
.glyphicons-cake:before {
  content: "\E273";
}
.glyphicons-drink:before {
  content: "\E274";
}
.glyphicons-beer:before {
  content: "\E275";
}
.glyphicons-fast-food:before {
  content: "\E276";
}
.glyphicons-cutlery:before {
  content: "\E277";
}
.glyphicons-pizza:before {
  content: "\E278";
}
.glyphicons-birthday-cake:before {
  content: "\E279";
}
.glyphicons-tablet:before {
  content: "\E280";
}
.glyphicons-settings:before {
  content: "\E281";
}
.glyphicons-bullets:before {
  content: "\E282";
}
.glyphicons-cardio:before {
  content: "\E283";
}
.glyphicons-t-shirt:before {
  content: "\E284";
}
.glyphicons-pants:before {
  content: "\E285";
}
.glyphicons-sweater:before {
  content: "\E286";
}
.glyphicons-fabric:before {
  content: "\E287";
}
.glyphicons-leather:before {
  content: "\E288";
}
.glyphicons-scissors:before {
  content: "\E289";
}
.glyphicons-bomb:before {
  content: "\E290";
}
.glyphicons-skull:before {
  content: "\E291";
}
.glyphicons-celebration:before {
  content: "\E292";
}
.glyphicons-tea-kettle:before {
  content: "\E293";
}
.glyphicons-french-press:before {
  content: "\E294";
}
.glyphicons-coffee-cup:before {
  content: "\E295";
}
.glyphicons-pot:before {
  content: "\E296";
}
.glyphicons-grater:before {
  content: "\E297";
}
.glyphicons-kettle:before {
  content: "\E298";
}
.glyphicons-hospital:before {
  content: "\E299";
}
.glyphicons-hospital-h:before {
  content: "\E300";
}
.glyphicons-microphone:before {
  content: "\E301";
}
.glyphicons-webcam:before {
  content: "\E302";
}
.glyphicons-temple-christianity-church:before {
  content: "\E303";
}
.glyphicons-temple-islam:before {
  content: "\E304";
}
.glyphicons-temple-hindu:before {
  content: "\E305";
}
.glyphicons-temple-buddhist:before {
  content: "\E306";
}
.glyphicons-bicycle:before {
  content: "\E307";
}
.glyphicons-life-preserver:before {
  content: "\E308";
}
.glyphicons-share-alt:before {
  content: "\E309";
}
.glyphicons-comments:before {
  content: "\E310";
}
.glyphicons-flower:before {
  content: "\2698";
}
.glyphicons-baseball:before {
  content: "\26BE";
}
.glyphicons-rugby:before {
  content: "\E313";
}
.glyphicons-ax:before {
  content: "\E314";
}
.glyphicons-table-tennis:before {
  content: "\E315";
}
.glyphicons-bowling:before {
  content: "\E316";
}
.glyphicons-tree-conifer:before {
  content: "\E317";
}
.glyphicons-tree-deciduous:before {
  content: "\E318";
}
.glyphicons-more-items:before {
  content: "\E319";
}
.glyphicons-sort:before {
  content: "\E320";
}
.glyphicons-filter:before {
  content: "\E321";
}
.glyphicons-gamepad:before {
  content: "\E322";
}
.glyphicons-playing-dices:before {
  content: "\E323";
}
.glyphicons-calculator:before {
  content: "\E324";
}
.glyphicons-tie:before {
  content: "\E325";
}
.glyphicons-wallet:before {
  content: "\E326";
}
.glyphicons-piano:before {
  content: "\E327";
}
.glyphicons-sampler:before {
  content: "\E328";
}
.glyphicons-podium:before {
  content: "\E329";
}
.glyphicons-soccer-ball:before {
  content: "\E330";
}
.glyphicons-blog:before {
  content: "\E331";
}
.glyphicons-dashboard:before {
  content: "\E332";
}
.glyphicons-certificate:before {
  content: "\E333";
}
.glyphicons-bell:before {
  content: "\E334";
}
.glyphicons-candle:before {
  content: "\E335";
}
.glyphicons-pushpin:before {
  content: "\E336";
}
.glyphicons-iphone-shake:before {
  content: "\E337";
}
.glyphicons-pin-flag:before {
  content: "\E338";
}
.glyphicons-turtle:before {
  content: "\E339";
}
.glyphicons-rabbit:before {
  content: "\E340";
}
.glyphicons-globe:before {
  content: "\E341";
}
.glyphicons-briefcase:before {
  content: "\E342";
}
.glyphicons-hdd:before {
  content: "\E343";
}
.glyphicons-thumbs-up:before {
  content: "\E344";
}
.glyphicons-thumbs-down:before {
  content: "\E345";
}
.glyphicons-hand-right:before {
  content: "\E346";
}
.glyphicons-hand-left:before {
  content: "\E347";
}
.glyphicons-hand-up:before {
  content: "\E348";
}
.glyphicons-hand-down:before {
  content: "\E349";
}
.glyphicons-fullscreen:before {
  content: "\E350";
}
.glyphicons-shopping-bag:before {
  content: "\E351";
}
.glyphicons-book-open:before {
  content: "\E352";
}
.glyphicons-nameplate:before {
  content: "\E353";
}
.glyphicons-nameplate-alt:before {
  content: "\E354";
}
.glyphicons-vases:before {
  content: "\E355";
}
.glyphicons-bullhorn:before {
  content: "\E356";
}
.glyphicons-dumbbell:before {
  content: "\E357";
}
.glyphicons-suitcase:before {
  content: "\E358";
}
.glyphicons-file-import:before {
  content: "\E359";
}
.glyphicons-file-export:before {
  content: "\E360";
}
.glyphicons-bug:before {
  content: "\E361";
}
.glyphicons-crown:before {
  content: "\E362";
}
.glyphicons-smoking:before {
  content: "\E363";
}
.glyphicons-cloud-download:before {
  content: "\E364";
}
.glyphicons-cloud-upload:before {
  content: "\E365";
}
.glyphicons-restart:before {
  content: "\E366";
}
.glyphicons-security-camera:before {
  content: "\E367";
}
.glyphicons-expand:before {
  content: "\E368";
}
.glyphicons-collapse:before {
  content: "\E369";
}
.glyphicons-collapse-top:before {
  content: "\E370";
}
.glyphicons-globe-af:before {
  content: "\E371";
}
.glyphicons-global:before {
  content: "\E372";
}
.glyphicons-spray:before {
  content: "\E373";
}
.glyphicons-nails:before {
  content: "\E374";
}
.glyphicons-claw-hammer:before {
  content: "\E375";
}
.glyphicons-classic-hammer:before {
  content: "\E376";
}
.glyphicons-hand-saw:before {
  content: "\E377";
}
.glyphicons-riflescope:before {
  content: "\E378";
}
.glyphicons-electrical-socket-eu:before {
  content: "\E379";
}
.glyphicons-electrical-socket-us:before {
  content: "\E380";
}
.glyphicons-message-forward:before {
  content: "\E381";
}
.glyphicons-coat-hanger:before {
  content: "\E382";
}
.glyphicons-dress:before {
  content: "\E383";
}
.glyphicons-bathrobe:before {
  content: "\E384";
}
.glyphicons-shirt:before {
  content: "\E385";
}
.glyphicons-underwear:before {
  content: "\E386";
}
.glyphicons-log-in:before {
  content: "\E387";
}
.glyphicons-log-out:before {
  content: "\E388";
}
.glyphicons-exit:before {
  content: "\E389";
}
.glyphicons-new-window-alt:before {
  content: "\E390";
}
.glyphicons-video-sd:before {
  content: "\E391";
}
.glyphicons-video-hd:before {
  content: "\E392";
}
.glyphicons-subtitles:before {
  content: "\E393";
}
.glyphicons-sound-stereo:before {
  content: "\E394";
}
.glyphicons-sound-dolby:before {
  content: "\E395";
}
.glyphicons-sound-5-1:before {
  content: "\E396";
}
.glyphicons-sound-6-1:before {
  content: "\E397";
}
.glyphicons-sound-7-1:before {
  content: "\E398";
}
.glyphicons-copyright-mark:before {
  content: "\E399";
}
.glyphicons-registration-mark:before {
  content: "\E400";
}
.glyphicons-radar:before {
  content: "\E401";
}
.glyphicons-skateboard:before {
  content: "\E402";
}
.glyphicons-golf-course:before {
  content: "\E403";
}
.glyphicons-sorting:before {
  content: "\E404";
}
.glyphicons-sort-by-alphabet:before {
  content: "\E405";
}
.glyphicons-sort-by-alphabet-alt:before {
  content: "\E406";
}
.glyphicons-sort-by-order:before {
  content: "\E407";
}
.glyphicons-sort-by-order-alt:before {
  content: "\E408";
}
.glyphicons-sort-by-attributes:before {
  content: "\E409";
}
.glyphicons-sort-by-attributes-alt:before {
  content: "\E410";
}
.glyphicons-compressed:before {
  content: "\E411";
}
.glyphicons-package:before {
  content: "\E412";
}
.glyphicons-cloud-plus:before {
  content: "\E413";
}
.glyphicons-cloud-minus:before {
  content: "\E414";
}
.glyphicons-disk-save:before {
  content: "\E415";
}
.glyphicons-disk-open:before {
  content: "\E416";
}
.glyphicons-disk-saved:before {
  content: "\E417";
}
.glyphicons-disk-remove:before {
  content: "\E418";
}
.glyphicons-disk-import:before {
  content: "\E419";
}
.glyphicons-disk-export:before {
  content: "\E420";
}
.glyphicons-tower:before {
  content: "\E421";
}
.glyphicons-send:before {
  content: "\E422";
}
.glyphicons-git-branch:before {
  content: "\E423";
}
.glyphicons-git-create:before {
  content: "\E424";
}
.glyphicons-git-private:before {
  content: "\E425";
}
.glyphicons-git-delete:before {
  content: "\E426";
}
.glyphicons-git-merge:before {
  content: "\E427";
}
.glyphicons-git-pull-request:before {
  content: "\E428";
}
.glyphicons-git-compare:before {
  content: "\E429";
}
.glyphicons-git-commit:before {
  content: "\E430";
}
.glyphicons-construction-cone:before {
  content: "\E431";
}
.glyphicons-shoe-steps:before {
  content: "\E432";
}
.glyphicons-plus:before {
  content: "\002B";
}
.glyphicons-minus:before {
  content: "\2212";
}
.glyphicons-redo:before {
  content: "\E435";
}
.glyphicons-undo:before {
  content: "\E436";
}
.glyphicons-golf:before {
  content: "\E437";
}
.glyphicons-hockey:before {
  content: "\E438";
}
.glyphicons-pipe:before {
  content: "\E439";
}
.glyphicons-wrench:before {
  content: "\E440";
}
.glyphicons-folder-closed:before {
  content: "\E441";
}
.glyphicons-phone-alt:before {
  content: "\E442";
}
.glyphicons-earphone:before {
  content: "\E443";
}
.glyphicons-floppy-disk:before {
  content: "\E444";
}
.glyphicons-floppy-saved:before {
  content: "\E445";
}
.glyphicons-floppy-remove:before {
  content: "\E446";
}
.glyphicons-floppy-save:before {
  content: "\E447";
}
.glyphicons-floppy-open:before {
  content: "\E448";
}
.glyphicons-translate:before {
  content: "\E449";
}
.glyphicons-fax:before {
  content: "\E450";
}
.glyphicons-factory:before {
  content: "\E451";
}
.glyphicons-shop-window:before {
  content: "\E452";
}
.glyphicons-shop:before {
  content: "\E453";
}
.glyphicons-kiosk:before {
  content: "\E454";
}
.glyphicons-kiosk-wheels:before {
  content: "\E455";
}
.glyphicons-kiosk-light:before {
  content: "\E456";
}
.glyphicons-kiosk-food:before {
  content: "\E457";
}
.glyphicons-transfer:before {
  content: "\E458";
}
.glyphicons-money:before {
  content: "\E459";
}
.glyphicons-header:before {
  content: "\E460";
}
.glyphicons-blacksmith:before {
  content: "\E461";
}
.glyphicons-saw-blade:before {
  content: "\E462";
}
.glyphicons-basketball:before {
  content: "\E463";
}
.glyphicons-server:before {
  content: "\E464";
}
.glyphicons-server-plus:before {
  content: "\E465";
}
.glyphicons-server-minus:before {
  content: "\E466";
}
.glyphicons-server-ban:before {
  content: "\E467";
}
.glyphicons-server-flag:before {
  content: "\E468";
}
.glyphicons-server-lock:before {
  content: "\E469";
}
.glyphicons-server-new:before {
  content: "\E470";
}
.glyphicons-charging-station:before {
  content: "\F471";
}
.glyphicons-gas-station:before {
  content: "\E472";
}
.glyphicons-target:before {
  content: "\E473";
}
.glyphicons-bed-alt:before {
  content: "\E474";
}
.glyphicons-mosquito-net:before {
  content: "\E475";
}
.glyphicons-dining-set:before {
  content: "\E476";
}
.glyphicons-plate-of-food:before {
  content: "\E477";
}
.glyphicons-hygiene-kit:before {
  content: "\E478";
}
.glyphicons-blackboard:before {
  content: "\E479";
}
.glyphicons-marriage:before {
  content: "\E480";
}
.glyphicons-bucket:before {
  content: "\E481";
}
.glyphicons-none-color-swatch:before {
  content: "\E482";
}
.glyphicons-bring-forward:before {
  content: "\E483";
}
.glyphicons-bring-to-front:before {
  content: "\E484";
}
.glyphicons-send-backward:before {
  content: "\E485";
}
.glyphicons-send-to-back:before {
  content: "\E486";
}
.glyphicons-fit-frame-to-image:before {
  content: "\E487";
}
.glyphicons-fit-image-to-frame:before {
  content: "\E488";
}
.glyphicons-multiple-displays:before {
  content: "\E489";
}
.glyphicons-handshake:before {
  content: "\E490";
}
.glyphicons-child:before {
  content: "\E491";
}
.glyphicons-baby-formula:before {
  content: "\E492";
}
.glyphicons-medicine:before {
  content: "\E493";
}
.glyphicons-atv-vehicle:before {
  content: "\E494";
}
.glyphicons-motorcycle:before {
  content: "\E495";
}
.glyphicons-bed:before {
  content: "\E496";
}
.glyphicons-tent:before {
  content: "\26FA";
}
.glyphicons-glasses:before {
  content: "\E498";
}
.glyphicons-sunglasses:before {
  content: "\E499";
}
.glyphicons-family:before {
  content: "\E500";
}
.glyphicons-education:before {
  content: "\E501";
}
.glyphicons-shoes:before {
  content: "\E502";
}
.glyphicons-map:before {
  content: "\E503";
}
.glyphicons-cd:before {
  content: "\E504";
}
.glyphicons-alert:before {
  content: "\E505";
}
.glyphicons-piggy-bank:before {
  content: "\E506";
}
.glyphicons-star-half:before {
  content: "\E507";
}
.glyphicons-cluster:before {
  content: "\E508";
}
.glyphicons-flowchart:before {
  content: "\E509";
}
.glyphicons-commodities:before {
  content: "\E510";
}
.glyphicons-duplicate:before {
  content: "\E511";
}
.glyphicons-copy:before {
  content: "\E512";
}
.glyphicons-paste:before {
  content: "\E513";
}
.glyphicons-bath-bathtub:before {
  content: "\E514";
}
.glyphicons-bath-shower:before {
  content: "\E515";
}
.glyphicons-shower:before {
  content: "\1F6BF";
}
.glyphicons-menu-hamburger:before {
  content: "\E517";
}
.glyphicons-option-vertical:before {
  content: "\E518";
}
.glyphicons-option-horizontal:before {
  content: "\E519";
}
.glyphicons-currency-conversion:before {
  content: "\E520";
}
.glyphicons-user-ban:before {
  content: "\E521";
}
.glyphicons-user-lock:before {
  content: "\E522";
}
.glyphicons-user-flag:before {
  content: "\E523";
}
.glyphicons-user-asterisk:before {
  content: "\E524";
}
.glyphicons-user-alert:before {
  content: "\E525";
}
.glyphicons-user-key:before {
  content: "\E526";
}
.glyphicons-user-conversation:before {
  content: "\E527";
}
.glyphicons-database:before {
  content: "\E528";
}
.glyphicons-database-search:before {
  content: "\E529";
}
.glyphicons-list-alt:before {
  content: "\E530";
}
.glyphicons-hazard-sign:before {
  content: "\E531";
}
.glyphicons-hazard:before {
  content: "\E532";
}
.glyphicons-stop-sign:before {
  content: "\E533";
}
.glyphicons-lab:before {
  content: "\E534";
}
.glyphicons-lab-alt:before {
  content: "\E535";
}
.glyphicons-ice-cream:before {
  content: "\E536";
}
.glyphicons-ice-lolly:before {
  content: "\E537";
}
.glyphicons-ice-lolly-tasted:before {
  content: "\E538";
}
.glyphicons-invoice:before {
  content: "\E539";
}
.glyphicons-cart-tick:before {
  content: "\E540";
}
.glyphicons-hourglass:before {
  content: "\231B";
}
.glyphicons-cat:before {
  content: "\1F408";
}
.glyphicons-lamp:before {
  content: "\E543";
}
.glyphicons-scale-classic:before {
  content: "\E544";
}
.glyphicons-eye-plus:before {
  content: "\E545";
}
.glyphicons-eye-minus:before {
  content: "\E546";
}
.glyphicons-quote:before {
  content: "\E547";
}
.glyphicons-bitcoin:before {
  content: "\E548";
}
.glyphicons-yen:before {
  content: "\00A5";
}
.glyphicons-ruble:before {
  content: "\20BD";
}
.glyphicons-erase:before {
  content: "\E551";
}
.glyphicons-podcast:before {
  content: "\E552";
}
.glyphicons-firework:before {
  content: "\E553";
}
.glyphicons-scale:before {
  content: "\E554";
}
.glyphicons-king:before {
  content: "\E555";
}
.glyphicons-queen:before {
  content: "\E556";
}
.glyphicons-pawn:before {
  content: "\E557";
}
.glyphicons-bishop:before {
  content: "\E558";
}
.glyphicons-knight:before {
  content: "\E559";
}
.glyphicons-mic-mute:before {
  content: "\E560";
}
.glyphicons-voicemail:before {
  content: "\E561";
}
.glyphicons-paragraph:before {
  content: "\00B6";
}
.glyphicons-person-walking:before {
  content: "\E563";
}
.glyphicons-person-wheelchair:before {
  content: "\E564";
}
.glyphicons-underground:before {
  content: "\E565";
}
.glyphicons-car-hov:before {
  content: "\E566";
}
.glyphicons-car-rental:before {
  content: "\E567";
}
.glyphicons-transport:before {
  content: "\E568";
}
.glyphicons-taxi:before {
  content: "\1F695";
}
.glyphicons-ice-cream-no:before {
  content: "\E570";
}
.glyphicons-uk-rat-u:before {
  content: "\E571";
}
.glyphicons-uk-rat-pg:before {
  content: "\E572";
}
.glyphicons-uk-rat-12a:before {
  content: "\E573";
}
.glyphicons-uk-rat-12:before {
  content: "\E574";
}
.glyphicons-uk-rat-15:before {
  content: "\E575";
}
.glyphicons-uk-rat-18:before {
  content: "\E576";
}
.glyphicons-uk-rat-r18:before {
  content: "\E577";
}
.glyphicons-tv:before {
  content: "\E578";
}
.glyphicons-sms:before {
  content: "\E579";
}
.glyphicons-mms:before {
  content: "\E580";
}
.glyphicons-us-rat-g:before {
  content: "\E581";
}
.glyphicons-us-rat-pg:before {
  content: "\E582";
}
.glyphicons-us-rat-pg-13:before {
  content: "\E583";
}
.glyphicons-us-rat-restricted:before {
  content: "\E584";
}
.glyphicons-us-rat-no-one-17:before {
  content: "\E585";
}
.glyphicons-equalizer:before {
  content: "\E586";
}
.glyphicons-speakers:before {
  content: "\E587";
}
.glyphicons-remote-control:before {
  content: "\E588";
}
.glyphicons-remote-control-tv:before {
  content: "\E589";
}
.glyphicons-shredder:before {
  content: "\E590";
}
.glyphicons-folder-heart:before {
  content: "\E591";
}
.glyphicons-person-running:before {
  content: "\E592";
}
.glyphicons-person:before {
  content: "\E593";
}
.glyphicons-voice:before {
  content: "\E594";
}
.glyphicons-stethoscope:before {
  content: "\E595";
}
.glyphicons-hotspot:before {
  content: "\E596";
}
.glyphicons-activity:before {
  content: "\E597";
}
.glyphicons-watch:before {
  content: "\231A";
}
.glyphicons-scissors-alt:before {
  content: "\E599";
}
.glyphicons-car-wheel:before {
  content: "\E600";
}
.glyphicons-chevron-up:before {
  content: "\E601";
}
.glyphicons-chevron-down:before {
  content: "\E602";
}
.glyphicons-superscript:before {
  content: "\E603";
}
.glyphicons-subscript:before {
  content: "\E604";
}
.glyphicons-text-size:before {
  content: "\E605";
}
.glyphicons-text-color:before {
  content: "\E606";
}
.glyphicons-text-background:before {
  content: "\E607";
}
.glyphicons-modal-window:before {
  content: "\E608";
}
.glyphicons-newspaper:before {
  content: "\1F4F0";
}
.glyphicons-tractor:before {
  content: "\1F69C";
}
.animated {
  -webkit-animation-duration: 1s;
  animation-duration: 1s;
  -webkit-animation-fill-mode: both;
  animation-fill-mode: both;
  -webkit-animation-timing-function: ease-in-out;
  animation-timing-function: ease-in-out;
  animation-iteration-count: infinite;
  -webkit-animation-iteration-count: infinite;
}
@-webkit-keyframes pulse {
  0% {
    -webkit-transform: scale(1);
  }
  50% {
    -webkit-transform: scale(1.1);
  }
  100% {
    -webkit-transform: scale(1);
  }
}
@keyframes pulse {
  0% {
    transform: scale(1);
  }
  50% {
    transform: scale(1.1);
  }
  100% {
    transform: scale(1);
  }
}
.pulse {
  -webkit-animation-name: pulse;
  animation-name: pulse;
}
@-webkit-keyframes rotateIn {
  0% {
    -webkit-transform-origin: center center;
    -webkit-transform: rotate(-200deg);
    opacity: 0;
  }
  100% {
    -webkit-transform-origin: center center;
    -webkit-transform: rotate(0);
    opacity: 1;
  }
}
@keyframes rotateIn {
  0% {
    transform-origin: center center;
    transform: rotate(-200deg);
    opacity: 0;
  }
  100% {
    transform-origin: center center;
    transform: rotate(0);
    opacity: 1;
  }
}
.rotateIn {
  -webkit-animation-name: rotateIn;
  animation-name: rotateIn;
}
@-webkit-keyframes bounce {
  0%,
  20%,
  50%,
  80%,
  100% {
    -webkit-transform: translateY(0);
  }
  40% {
    -webkit-transform: translateY(-30px);
  }
  60% {
    -webkit-transform: translateY(-15px);
  }
}
@keyframes bounce {
  0%,
  20%,
  50%,
  80%,
  100% {
    transform: translateY(0);
  }
  40% {
    transform: translateY(-30px);
  }
  60% {
    transform: translateY(-15px);
  }
}
.bounce {
  -webkit-animation-name: bounce;
  animation-name: bounce;
}
@-webkit-keyframes swing {
  20%,
  40%,
  60%,
  80%,
  100% {
    -webkit-transform-origin: top center;
  }
  20% {
    -webkit-transform: rotate(15deg);
  }
  40% {
    -webkit-transform: rotate(-10deg);
  }
  60% {
    -webkit-transform: rotate(5deg);
  }
  80% {
    -webkit-transform: rotate(-5deg);
  }
  100% {
    -webkit-transform: rotate(0deg);
  }
}
@keyframes swing {
  20% {
    transform: rotate(15deg);
  }
  40% {
    transform: rotate(-10deg);
  }
  60% {
    transform: rotate(5deg);
  }
  80% {
    transform: rotate(-5deg);
  }
  100% {
    transform: rotate(0deg);
  }
}
.swing {
  -webkit-transform-origin: top center;
  transform-origin: top center;
  -webkit-animation-name: swing;
  animation-name: swing;
}
@-webkit-keyframes tada {
  0% {
    -webkit-transform: scale(1);
  }
  10%,
  20% {
    -webkit-transform: scale(0.9) rotate(-3deg);
  }
  30%,
  50%,
  70%,
  90% {
    -webkit-transform: scale(1.1) rotate(3deg);
  }
  40%,
  60%,
  80% {
    -webkit-transform: scale(1.1) rotate(-3deg);
  }
  100% {
    -webkit-transform: scale(1) rotate(0);
  }
}
@keyframes tada {
  0% {
    transform: scale(1);
  }
  10%,
  20% {
    transform: scale(0.9) rotate(-3deg);
  }
  30%,
  50%,
  70%,
  90% {
    transform: scale(1.1) rotate(3deg);
  }
  40%,
  60%,
  80% {
    transform: scale(1.1) rotate(-3deg);
  }
  100% {
    transform: scale(1) rotate(0);
  }
}
.tada {
  -webkit-animation-name: tada;
  animation-name: tada;
}
/**
 * Proxima Nova Family
 */
@font-face {
  font-family: 'Proxima Nova';
  src: url('[[relativeurl]]/public/app/default/assets/core/pyrocms/pyrocms-theme/resources/fonts/proximanova/proximanova-regular-webfont.eot');
  src: local('☺'), url('[[relativeurl]]/public/app/default/assets/core/pyrocms/pyrocms-theme/resources/fonts/proximanova/proximanova-regular-webfont.woff') format('woff'), url('[[relativeurl]]/public/app/default/assets/core/pyrocms/pyrocms-theme/resources/fonts/proximanova/proximanova-regular-webfont.ttf') format('truetype'), url('[[relativeurl]]/public/app/default/assets/core/pyrocms/pyrocms-theme/resources/fonts/proximanova/proximanova-regular-webfont.svg') format('svg');
  font-weight: normal;
  font-style: normal;
}
@font-face {
  font-family: 'Proxima Nova';
  src: url('[[relativeurl]]/public/app/default/assets/core/pyrocms/pyrocms-theme/resources/fonts/proximanova/proximanova-bold-webfont.eot');
  src: local('☺'), url('[[relativeurl]]/public/app/default/assets/core/pyrocms/pyrocms-theme/resources/fonts/proximanova/proximanova-bold-webfont.woff') format('woff'), url('[[relativeurl]]/public/app/default/assets/core/pyrocms/pyrocms-theme/resources/fonts/proximanova/proximanova-bold-webfont.ttf') format('truetype'), url('[[relativeurl]]/public/app/default/assets/core/pyrocms/pyrocms-theme/resources/fonts/proximanova/proximanova-bold-webfont.svg') format('svg');
  font-weight: bold;
  font-style: bold;
}
/*!
 *  Font Awesome 4.3.0 by @davegandy - http://fontawesome.io - @fontawesome
 *  License - http://fontawesome.io/license (Font: SIL OFL 1.1, CSS: MIT License)
 */
/* FONT PATH
 * -------------------------- */
@font-face {
  font-family: 'FontAwesome';
  src: url('[[relativeurl]]/public/app/default/assets/core/pyrocms/pyrocms-theme/resources/fonts/font-awesome/fontawesome-webfont.eot');
  src: url('[[relativeurl]]/public/app/default/assets/core/pyrocms/pyrocms-theme/resources/fonts/font-awesome/fontawesome-webfont.eot?#iefix') format('embedded-opentype'), url('[[relativeurl]]/public/app/default/assets/core/pyrocms/pyrocms-theme/resources/fonts/font-awesome/fontawesome-webfont.woff2') format('woff2'), url('[[relativeurl]]/public/app/default/assets/core/pyrocms/pyrocms-theme/resources/fonts/font-awesome/fontawesome-webfont.woff') format('woff'), url('[[relativeurl]]/public/app/default/assets/core/pyrocms/pyrocms-theme/resources/fonts/font-awesome/fontawesome-webfont.ttf') format('truetype'), url('[[relativeurl]]/public/app/default/assets/core/pyrocms/pyrocms-theme/resources/fonts/font-awesome/fontawesome-webfont.svg#fontawesome') format('svg');
  font-weight: normal;
  font-style: normal;
}
.fa {
  display: inline-block;
  font: normal normal normal 14px/1 FontAwesome;
  font-size: inherit;
  text-rendering: auto;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  transform: translate(0, 0);
}
/* makes the font 33% larger relative to the icon container */
.fa-lg {
  font-size: 1.33333333em;
  vertical-align: -5%;
  line-height: 0.75em;
}
.fa-2x {
  font-size: 2em;
}
.fa-3x {
  font-size: 3em;
}
.fa-4x {
  font-size: 4em;
}
.fa-5x {
  font-size: 5em;
}
.fa-fw {
  width: 1.28571429em;
  text-align: center;
}
.fa-ul {
  padding-left: 0;
  margin-left: 2.14285714em;
  list-style-type: none;
}
.fa-ul > li {
  position: relative;
}
.fa-li {
  position: absolute;
  left: -2.14285714em;
  width: 2.14285714em;
  top: 0.14285714em;
  text-align: center;
}
.fa-li.fa-lg {
  left: -1.85714286em;
}
.fa-border {
  padding: .2em .25em .15em;
  border: solid 0.08em #eeeeee;
  border-radius: .1em;
}
.pull-right {
  float: right;
}
.pull-left {
  float: left;
}
.fa.pull-left {
  margin-right: .3em;
}
.fa.pull-right {
  margin-left: .3em;
}
.fa-spin {
  -webkit-animation: fa-spin 2s infinite linear;
  animation: fa-spin 2s infinite linear;
}
.fa-pulse {
  -webkit-animation: fa-spin 1s infinite steps(8);
  animation: fa-spin 1s infinite steps(8);
}
@-webkit-keyframes fa-spin {
  0% {
    -webkit-transform: rotate(0deg);
    transform: rotate(0deg);
  }
  100% {
    -webkit-transform: rotate(359deg);
    transform: rotate(359deg);
  }
}
@keyframes fa-spin {
  0% {
    -webkit-transform: rotate(0deg);
    transform: rotate(0deg);
  }
  100% {
    -webkit-transform: rotate(359deg);
    transform: rotate(359deg);
  }
}
.fa-rotate-90 {
  filter: progid:DXImageTransform.Microsoft.BasicImage(rotation=1);
  -webkit-transform: rotate(90deg);
  -ms-transform: rotate(90deg);
  transform: rotate(90deg);
}
.fa-rotate-180 {
  filter: progid:DXImageTransform.Microsoft.BasicImage(rotation=2);
  -webkit-transform: rotate(180deg);
  -ms-transform: rotate(180deg);
  transform: rotate(180deg);
}
.fa-rotate-270 {
  filter: progid:DXImageTransform.Microsoft.BasicImage(rotation=3);
  -webkit-transform: rotate(270deg);
  -ms-transform: rotate(270deg);
  transform: rotate(270deg);
}
.fa-flip-horizontal {
  filter: progid:DXImageTransform.Microsoft.BasicImage(rotation=0, mirror=1);
  -webkit-transform: scale(-1, 1);
  -ms-transform: scale(-1, 1);
  transform: scale(-1, 1);
}
.fa-flip-vertical {
  filter: progid:DXImageTransform.Microsoft.BasicImage(rotation=2, mirror=1);
  -webkit-transform: scale(1, -1);
  -ms-transform: scale(1, -1);
  transform: scale(1, -1);
}
:root .fa-rotate-90,
:root .fa-rotate-180,
:root .fa-rotate-270,
:root .fa-flip-horizontal,
:root .fa-flip-vertical {
  filter: none;
}
.fa-stack {
  position: relative;
  display: inline-block;
  width: 2em;
  height: 2em;
  line-height: 2em;
  vertical-align: middle;
}
.fa-stack-1x,
.fa-stack-2x {
  position: absolute;
  left: 0;
  width: 100%;
  text-align: center;
}
.fa-stack-1x {
  line-height: inherit;
}
.fa-stack-2x {
  font-size: 2em;
}
.fa-inverse {
  color: #ffffff;
}
/* Font Awesome uses the Unicode Private Use Area (PUA) to ensure screen
   readers do not read off random characters that represent icons */
.fa-glass:before {
  content: "\f000";
}
.fa-music:before {
  content: "\f001";
}
.fa-search:before {
  content: "\f002";
}
.fa-envelope-o:before {
  content: "\f003";
}
.fa-heart:before {
  content: "\f004";
}
.fa-star:before {
  content: "\f005";
}
.fa-star-o:before {
  content: "\f006";
}
.fa-user:before {
  content: "\f007";
}
.fa-film:before {
  content: "\f008";
}
.fa-th-large:before {
  content: "\f009";
}
.fa-th:before {
  content: "\f00a";
}
.fa-th-list:before {
  content: "\f00b";
}
.fa-check:before {
  content: "\f00c";
}
.fa-remove:before,
.fa-close:before,
.fa-times:before {
  content: "\f00d";
}
.fa-search-plus:before {
  content: "\f00e";
}
.fa-search-minus:before {
  content: "\f010";
}
.fa-power-off:before {
  content: "\f011";
}
.fa-signal:before {
  content: "\f012";
}
.fa-gear:before,
.fa-cog:before {
  content: "\f013";
}
.fa-trash-o:before {
  content: "\f014";
}
.fa-home:before {
  content: "\f015";
}
.fa-file-o:before {
  content: "\f016";
}
.fa-clock-o:before {
  content: "\f017";
}
.fa-road:before {
  content: "\f018";
}
.fa-download:before {
  content: "\f019";
}
.fa-arrow-circle-o-down:before {
  content: "\f01a";
}
.fa-arrow-circle-o-up:before {
  content: "\f01b";
}
.fa-inbox:before {
  content: "\f01c";
}
.fa-play-circle-o:before {
  content: "\f01d";
}
.fa-rotate-right:before,
.fa-repeat:before {
  content: "\f01e";
}
.fa-refresh:before {
  content: "\f021";
}
.fa-list-alt:before {
  content: "\f022";
}
.fa-lock:before {
  content: "\f023";
}
.fa-flag:before {
  content: "\f024";
}
.fa-headphones:before {
  content: "\f025";
}
.fa-volume-off:before {
  content: "\f026";
}
.fa-volume-down:before {
  content: "\f027";
}
.fa-volume-up:before {
  content: "\f028";
}
.fa-qrcode:before {
  content: "\f029";
}
.fa-barcode:before {
  content: "\f02a";
}
.fa-tag:before {
  content: "\f02b";
}
.fa-tags:before {
  content: "\f02c";
}
.fa-book:before {
  content: "\f02d";
}
.fa-bookmark:before {
  content: "\f02e";
}
.fa-print:before {
  content: "\f02f";
}
.fa-camera:before {
  content: "\f030";
}
.fa-font:before {
  content: "\f031";
}
.fa-bold:before {
  content: "\f032";
}
.fa-italic:before {
  content: "\f033";
}
.fa-text-height:before {
  content: "\f034";
}
.fa-text-width:before {
  content: "\f035";
}
.fa-align-left:before {
  content: "\f036";
}
.fa-align-center:before {
  content: "\f037";
}
.fa-align-right:before {
  content: "\f038";
}
.fa-align-justify:before {
  content: "\f039";
}
.fa-list:before {
  content: "\f03a";
}
.fa-dedent:before,
.fa-outdent:before {
  content: "\f03b";
}
.fa-indent:before {
  content: "\f03c";
}
.fa-video-camera:before {
  content: "\f03d";
}
.fa-photo:before,
.fa-image:before,
.fa-picture-o:before {
  content: "\f03e";
}
.fa-pencil:before {
  content: "\f040";
}
.fa-map-marker:before {
  content: "\f041";
}
.fa-adjust:before {
  content: "\f042";
}
.fa-tint:before {
  content: "\f043";
}
.fa-edit:before,
.fa-pencil-square-o:before {
  content: "\f044";
}
.fa-share-square-o:before {
  content: "\f045";
}
.fa-check-square-o:before {
  content: "\f046";
}
.fa-arrows:before {
  content: "\f047";
}
.fa-step-backward:before {
  content: "\f048";
}
.fa-fast-backward:before {
  content: "\f049";
}
.fa-backward:before {
  content: "\f04a";
}
.fa-play:before {
  content: "\f04b";
}
.fa-pause:before {
  content: "\f04c";
}
.fa-stop:before {
  content: "\f04d";
}
.fa-forward:before {
  content: "\f04e";
}
.fa-fast-forward:before {
  content: "\f050";
}
.fa-step-forward:before {
  content: "\f051";
}
.fa-eject:before {
  content: "\f052";
}
.fa-chevron-left:before {
  content: "\f053";
}
.fa-chevron-right:before {
  content: "\f054";
}
.fa-plus-circle:before {
  content: "\f055";
}
.fa-minus-circle:before {
  content: "\f056";
}
.fa-times-circle:before {
  content: "\f057";
}
.fa-check-circle:before {
  content: "\f058";
}
.fa-question-circle:before {
  content: "\f059";
}
.fa-info-circle:before {
  content: "\f05a";
}
.fa-crosshairs:before {
  content: "\f05b";
}
.fa-times-circle-o:before {
  content: "\f05c";
}
.fa-check-circle-o:before {
  content: "\f05d";
}
.fa-ban:before {
  content: "\f05e";
}
.fa-arrow-left:before {
  content: "\f060";
}
.fa-arrow-right:before {
  content: "\f061";
}
.fa-arrow-up:before {
  content: "\f062";
}
.fa-arrow-down:before {
  content: "\f063";
}
.fa-mail-forward:before,
.fa-share:before {
  content: "\f064";
}
.fa-expand:before {
  content: "\f065";
}
.fa-compress:before {
  content: "\f066";
}
.fa-plus:before {
  content: "\f067";
}
.fa-minus:before {
  content: "\f068";
}
.fa-asterisk:before {
  content: "\f069";
}
.fa-exclamation-circle:before {
  content: "\f06a";
}
.fa-gift:before {
  content: "\f06b";
}
.fa-leaf:before {
  content: "\f06c";
}
.fa-fire:before {
  content: "\f06d";
}
.fa-eye:before {
  content: "\f06e";
}
.fa-eye-slash:before {
  content: "\f070";
}
.fa-warning:before,
.fa-exclamation-triangle:before {
  content: "\f071";
}
.fa-plane:before {
  content: "\f072";
}
.fa-calendar:before {
  content: "\f073";
}
.fa-random:before {
  content: "\f074";
}
.fa-comment:before {
  content: "\f075";
}
.fa-magnet:before {
  content: "\f076";
}
.fa-chevron-up:before {
  content: "\f077";
}
.fa-chevron-down:before {
  content: "\f078";
}
.fa-retweet:before {
  content: "\f079";
}
.fa-shopping-cart:before {
  content: "\f07a";
}
.fa-folder:before {
  content: "\f07b";
}
.fa-folder-open:before {
  content: "\f07c";
}
.fa-arrows-v:before {
  content: "\f07d";
}
.fa-arrows-h:before {
  content: "\f07e";
}
.fa-bar-chart-o:before,
.fa-bar-chart:before {
  content: "\f080";
}
.fa-twitter-square:before {
  content: "\f081";
}
.fa-facebook-square:before {
  content: "\f082";
}
.fa-camera-retro:before {
  content: "\f083";
}
.fa-key:before {
  content: "\f084";
}
.fa-gears:before,
.fa-cogs:before {
  content: "\f085";
}
.fa-comments:before {
  content: "\f086";
}
.fa-thumbs-o-up:before {
  content: "\f087";
}
.fa-thumbs-o-down:before {
  content: "\f088";
}
.fa-star-half:before {
  content: "\f089";
}
.fa-heart-o:before {
  content: "\f08a";
}
.fa-sign-out:before {
  content: "\f08b";
}
.fa-linkedin-square:before {
  content: "\f08c";
}
.fa-thumb-tack:before {
  content: "\f08d";
}
.fa-external-link:before {
  content: "\f08e";
}
.fa-sign-in:before {
  content: "\f090";
}
.fa-trophy:before {
  content: "\f091";
}
.fa-github-square:before {
  content: "\f092";
}
.fa-upload:before {
  content: "\f093";
}
.fa-lemon-o:before {
  content: "\f094";
}
.fa-phone:before {
  content: "\f095";
}
.fa-square-o:before {
  content: "\f096";
}
.fa-bookmark-o:before {
  content: "\f097";
}
.fa-phone-square:before {
  content: "\f098";
}
.fa-twitter:before {
  content: "\f099";
}
.fa-facebook-f:before,
.fa-facebook:before {
  content: "\f09a";
}
.fa-github:before {
  content: "\f09b";
}
.fa-unlock:before {
  content: "\f09c";
}
.fa-credit-card:before {
  content: "\f09d";
}
.fa-rss:before {
  content: "\f09e";
}
.fa-hdd-o:before {
  content: "\f0a0";
}
.fa-bullhorn:before {
  content: "\f0a1";
}
.fa-bell:before {
  content: "\f0f3";
}
.fa-certificate:before {
  content: "\f0a3";
}
.fa-hand-o-right:before {
  content: "\f0a4";
}
.fa-hand-o-left:before {
  content: "\f0a5";
}
.fa-hand-o-up:before {
  content: "\f0a6";
}
.fa-hand-o-down:before {
  content: "\f0a7";
}
.fa-arrow-circle-left:before {
  content: "\f0a8";
}
.fa-arrow-circle-right:before {
  content: "\f0a9";
}
.fa-arrow-circle-up:before {
  content: "\f0aa";
}
.fa-arrow-circle-down:before {
  content: "\f0ab";
}
.fa-globe:before {
  content: "\f0ac";
}
.fa-wrench:before {
  content: "\f0ad";
}
.fa-tasks:before {
  content: "\f0ae";
}
.fa-filter:before {
  content: "\f0b0";
}
.fa-briefcase:before {
  content: "\f0b1";
}
.fa-arrows-alt:before {
  content: "\f0b2";
}
.fa-group:before,
.fa-users:before {
  content: "\f0c0";
}
.fa-chain:before,
.fa-link:before {
  content: "\f0c1";
}
.fa-cloud:before {
  content: "\f0c2";
}
.fa-flask:before {
  content: "\f0c3";
}
.fa-cut:before,
.fa-scissors:before {
  content: "\f0c4";
}
.fa-copy:before,
.fa-files-o:before {
  content: "\f0c5";
}
.fa-paperclip:before {
  content: "\f0c6";
}
.fa-save:before,
.fa-floppy-o:before {
  content: "\f0c7";
}
.fa-square:before {
  content: "\f0c8";
}
.fa-navicon:before,
.fa-reorder:before,
.fa-bars:before {
  content: "\f0c9";
}
.fa-list-ul:before {
  content: "\f0ca";
}
.fa-list-ol:before {
  content: "\f0cb";
}
.fa-strikethrough:before {
  content: "\f0cc";
}
.fa-underline:before {
  content: "\f0cd";
}
.fa-table:before {
  content: "\f0ce";
}
.fa-magic:before {
  content: "\f0d0";
}
.fa-truck:before {
  content: "\f0d1";
}
.fa-pinterest:before {
  content: "\f0d2";
}
.fa-pinterest-square:before {
  content: "\f0d3";
}
.fa-google-plus-square:before {
  content: "\f0d4";
}
.fa-google-plus:before {
  content: "\f0d5";
}
.fa-money:before {
  content: "\f0d6";
}
.fa-caret-down:before {
  content: "\f0d7";
}
.fa-caret-up:before {
  content: "\f0d8";
}
.fa-caret-left:before {
  content: "\f0d9";
}
.fa-caret-right:before {
  content: "\f0da";
}
.fa-columns:before {
  content: "\f0db";
}
.fa-unsorted:before,
.fa-sort:before {
  content: "\f0dc";
}
.fa-sort-down:before,
.fa-sort-desc:before {
  content: "\f0dd";
}
.fa-sort-up:before,
.fa-sort-asc:before {
  content: "\f0de";
}
.fa-envelope:before {
  content: "\f0e0";
}
.fa-linkedin:before {
  content: "\f0e1";
}
.fa-rotate-left:before,
.fa-undo:before {
  content: "\f0e2";
}
.fa-legal:before,
.fa-gavel:before {
  content: "\f0e3";
}
.fa-dashboard:before,
.fa-tachometer:before {
  content: "\f0e4";
}
.fa-comment-o:before {
  content: "\f0e5";
}
.fa-comments-o:before {
  content: "\f0e6";
}
.fa-flash:before,
.fa-bolt:before {
  content: "\f0e7";
}
.fa-sitemap:before {
  content: "\f0e8";
}
.fa-umbrella:before {
  content: "\f0e9";
}
.fa-paste:before,
.fa-clipboard:before {
  content: "\f0ea";
}
.fa-lightbulb-o:before {
  content: "\f0eb";
}
.fa-exchange:before {
  content: "\f0ec";
}
.fa-cloud-download:before {
  content: "\f0ed";
}
.fa-cloud-upload:before {
  content: "\f0ee";
}
.fa-user-md:before {
  content: "\f0f0";
}
.fa-stethoscope:before {
  content: "\f0f1";
}
.fa-suitcase:before {
  content: "\f0f2";
}
.fa-bell-o:before {
  content: "\f0a2";
}
.fa-coffee:before {
  content: "\f0f4";
}
.fa-cutlery:before {
  content: "\f0f5";
}
.fa-file-text-o:before {
  content: "\f0f6";
}
.fa-building-o:before {
  content: "\f0f7";
}
.fa-hospital-o:before {
  content: "\f0f8";
}
.fa-ambulance:before {
  content: "\f0f9";
}
.fa-medkit:before {
  content: "\f0fa";
}
.fa-fighter-jet:before {
  content: "\f0fb";
}
.fa-beer:before {
  content: "\f0fc";
}
.fa-h-square:before {
  content: "\f0fd";
}
.fa-plus-square:before {
  content: "\f0fe";
}
.fa-angle-double-left:before {
  content: "\f100";
}
.fa-angle-double-right:before {
  content: "\f101";
}
.fa-angle-double-up:before {
  content: "\f102";
}
.fa-angle-double-down:before {
  content: "\f103";
}
.fa-angle-left:before {
  content: "\f104";
}
.fa-angle-right:before {
  content: "\f105";
}
.fa-angle-up:before {
  content: "\f106";
}
.fa-angle-down:before {
  content: "\f107";
}
.fa-desktop:before {
  content: "\f108";
}
.fa-laptop:before {
  content: "\f109";
}
.fa-tablet:before {
  content: "\f10a";
}
.fa-mobile-phone:before,
.fa-mobile:before {
  content: "\f10b";
}
.fa-circle-o:before {
  content: "\f10c";
}
.fa-quote-left:before {
  content: "\f10d";
}
.fa-quote-right:before {
  content: "\f10e";
}
.fa-spinner:before {
  content: "\f110";
}
.fa-circle:before {
  content: "\f111";
}
.fa-mail-reply:before,
.fa-reply:before {
  content: "\f112";
}
.fa-github-alt:before {
  content: "\f113";
}
.fa-folder-o:before {
  content: "\f114";
}
.fa-folder-open-o:before {
  content: "\f115";
}
.fa-smile-o:before {
  content: "\f118";
}
.fa-frown-o:before {
  content: "\f119";
}
.fa-meh-o:before {
  content: "\f11a";
}
.fa-gamepad:before {
  content: "\f11b";
}
.fa-keyboard-o:before {
  content: "\f11c";
}
.fa-flag-o:before {
  content: "\f11d";
}
.fa-flag-checkered:before {
  content: "\f11e";
}
.fa-terminal:before {
  content: "\f120";
}
.fa-code:before {
  content: "\f121";
}
.fa-mail-reply-all:before,
.fa-reply-all:before {
  content: "\f122";
}
.fa-star-half-empty:before,
.fa-star-half-full:before,
.fa-star-half-o:before {
  content: "\f123";
}
.fa-location-arrow:before {
  content: "\f124";
}
.fa-crop:before {
  content: "\f125";
}
.fa-code-fork:before {
  content: "\f126";
}
.fa-unlink:before,
.fa-chain-broken:before {
  content: "\f127";
}
.fa-question:before {
  content: "\f128";
}
.fa-info:before {
  content: "\f129";
}
.fa-exclamation:before {
  content: "\f12a";
}
.fa-superscript:before {
  content: "\f12b";
}
.fa-subscript:before {
  content: "\f12c";
}
.fa-eraser:before {
  content: "\f12d";
}
.fa-puzzle-piece:before {
  content: "\f12e";
}
.fa-microphone:before {
  content: "\f130";
}
.fa-microphone-slash:before {
  content: "\f131";
}
.fa-shield:before {
  content: "\f132";
}
.fa-calendar-o:before {
  content: "\f133";
}
.fa-fire-extinguisher:before {
  content: "\f134";
}
.fa-rocket:before {
  content: "\f135";
}
.fa-maxcdn:before {
  content: "\f136";
}
.fa-chevron-circle-left:before {
  content: "\f137";
}
.fa-chevron-circle-right:before {
  content: "\f138";
}
.fa-chevron-circle-up:before {
  content: "\f139";
}
.fa-chevron-circle-down:before {
  content: "\f13a";
}
.fa-html5:before {
  content: "\f13b";
}
.fa-css3:before {
  content: "\f13c";
}
.fa-anchor:before {
  content: "\f13d";
}
.fa-unlock-alt:before {
  content: "\f13e";
}
.fa-bullseye:before {
  content: "\f140";
}
.fa-ellipsis-h:before {
  content: "\f141";
}
.fa-ellipsis-v:before {
  content: "\f142";
}
.fa-rss-square:before {
  content: "\f143";
}
.fa-play-circle:before {
  content: "\f144";
}
.fa-ticket:before {
  content: "\f145";
}
.fa-minus-square:before {
  content: "\f146";
}
.fa-minus-square-o:before {
  content: "\f147";
}
.fa-level-up:before {
  content: "\f148";
}
.fa-level-down:before {
  content: "\f149";
}
.fa-check-square:before {
  content: "\f14a";
}
.fa-pencil-square:before {
  content: "\f14b";
}
.fa-external-link-square:before {
  content: "\f14c";
}
.fa-share-square:before {
  content: "\f14d";
}
.fa-compass:before {
  content: "\f14e";
}
.fa-toggle-down:before,
.fa-caret-square-o-down:before {
  content: "\f150";
}
.fa-toggle-up:before,
.fa-caret-square-o-up:before {
  content: "\f151";
}
.fa-toggle-right:before,
.fa-caret-square-o-right:before {
  content: "\f152";
}
.fa-euro:before,
.fa-eur:before {
  content: "\f153";
}
.fa-gbp:before {
  content: "\f154";
}
.fa-dollar:before,
.fa-usd:before {
  content: "\f155";
}
.fa-rupee:before,
.fa-inr:before {
  content: "\f156";
}
.fa-cny:before,
.fa-rmb:before,
.fa-yen:before,
.fa-jpy:before {
  content: "\f157";
}
.fa-ruble:before,
.fa-rouble:before,
.fa-rub:before {
  content: "\f158";
}
.fa-won:before,
.fa-krw:before {
  content: "\f159";
}
.fa-bitcoin:before,
.fa-btc:before {
  content: "\f15a";
}
.fa-file:before {
  content: "\f15b";
}
.fa-file-text:before {
  content: "\f15c";
}
.fa-sort-alpha-asc:before {
  content: "\f15d";
}
.fa-sort-alpha-desc:before {
  content: "\f15e";
}
.fa-sort-amount-asc:before {
  content: "\f160";
}
.fa-sort-amount-desc:before {
  content: "\f161";
}
.fa-sort-numeric-asc:before {
  content: "\f162";
}
.fa-sort-numeric-desc:before {
  content: "\f163";
}
.fa-thumbs-up:before {
  content: "\f164";
}
.fa-thumbs-down:before {
  content: "\f165";
}
.fa-youtube-square:before {
  content: "\f166";
}
.fa-youtube:before {
  content: "\f167";
}
.fa-xing:before {
  content: "\f168";
}
.fa-xing-square:before {
  content: "\f169";
}
.fa-youtube-play:before {
  content: "\f16a";
}
.fa-dropbox:before {
  content: "\f16b";
}
.fa-stack-overflow:before {
  content: "\f16c";
}
.fa-instagram:before {
  content: "\f16d";
}
.fa-flickr:before {
  content: "\f16e";
}
.fa-adn:before {
  content: "\f170";
}
.fa-bitbucket:before {
  content: "\f171";
}
.fa-bitbucket-square:before {
  content: "\f172";
}
.fa-tumblr:before {
  content: "\f173";
}
.fa-tumblr-square:before {
  content: "\f174";
}
.fa-long-arrow-down:before {
  content: "\f175";
}
.fa-long-arrow-up:before {
  content: "\f176";
}
.fa-long-arrow-left:before {
  content: "\f177";
}
.fa-long-arrow-right:before {
  content: "\f178";
}
.fa-apple:before {
  content: "\f179";
}
.fa-windows:before {
  content: "\f17a";
}
.fa-android:before {
  content: "\f17b";
}
.fa-linux:before {
  content: "\f17c";
}
.fa-dribbble:before {
  content: "\f17d";
}
.fa-skype:before {
  content: "\f17e";
}
.fa-foursquare:before {
  content: "\f180";
}
.fa-trello:before {
  content: "\f181";
}
.fa-female:before {
  content: "\f182";
}
.fa-male:before {
  content: "\f183";
}
.fa-gittip:before,
.fa-gratipay:before {
  content: "\f184";
}
.fa-sun-o:before {
  content: "\f185";
}
.fa-moon-o:before {
  content: "\f186";
}
.fa-archive:before {
  content: "\f187";
}
.fa-bug:before {
  content: "\f188";
}
.fa-vk:before {
  content: "\f189";
}
.fa-weibo:before {
  content: "\f18a";
}
.fa-renren:before {
  content: "\f18b";
}
.fa-pagelines:before {
  content: "\f18c";
}
.fa-stack-exchange:before {
  content: "\f18d";
}
.fa-arrow-circle-o-right:before {
  content: "\f18e";
}
.fa-arrow-circle-o-left:before {
  content: "\f190";
}
.fa-toggle-left:before,
.fa-caret-square-o-left:before {
  content: "\f191";
}
.fa-dot-circle-o:before {
  content: "\f192";
}
.fa-wheelchair:before {
  content: "\f193";
}
.fa-vimeo-square:before {
  content: "\f194";
}
.fa-turkish-lira:before,
.fa-try:before {
  content: "\f195";
}
.fa-plus-square-o:before {
  content: "\f196";
}
.fa-space-shuttle:before {
  content: "\f197";
}
.fa-slack:before {
  content: "\f198";
}
.fa-envelope-square:before {
  content: "\f199";
}
.fa-wordpress:before {
  content: "\f19a";
}
.fa-openid:before {
  content: "\f19b";
}
.fa-institution:before,
.fa-bank:before,
.fa-university:before {
  content: "\f19c";
}
.fa-mortar-board:before,
.fa-graduation-cap:before {
  content: "\f19d";
}
.fa-yahoo:before {
  content: "\f19e";
}
.fa-google:before {
  content: "\f1a0";
}
.fa-reddit:before {
  content: "\f1a1";
}
.fa-reddit-square:before {
  content: "\f1a2";
}
.fa-stumbleupon-circle:before {
  content: "\f1a3";
}
.fa-stumbleupon:before {
  content: "\f1a4";
}
.fa-delicious:before {
  content: "\f1a5";
}
.fa-digg:before {
  content: "\f1a6";
}
.fa-pied-piper:before {
  content: "\f1a7";
}
.fa-pied-piper-alt:before {
  content: "\f1a8";
}
.fa-drupal:before {
  content: "\f1a9";
}
.fa-joomla:before {
  content: "\f1aa";
}
.fa-language:before {
  content: "\f1ab";
}
.fa-fax:before {
  content: "\f1ac";
}
.fa-building:before {
  content: "\f1ad";
}
.fa-child:before {
  content: "\f1ae";
}
.fa-paw:before {
  content: "\f1b0";
}
.fa-spoon:before {
  content: "\f1b1";
}
.fa-cube:before {
  content: "\f1b2";
}
.fa-cubes:before {
  content: "\f1b3";
}
.fa-behance:before {
  content: "\f1b4";
}
.fa-behance-square:before {
  content: "\f1b5";
}
.fa-steam:before {
  content: "\f1b6";
}
.fa-steam-square:before {
  content: "\f1b7";
}
.fa-recycle:before {
  content: "\f1b8";
}
.fa-automobile:before,
.fa-car:before {
  content: "\f1b9";
}
.fa-cab:before,
.fa-taxi:before {
  content: "\f1ba";
}
.fa-tree:before {
  content: "\f1bb";
}
.fa-spotify:before {
  content: "\f1bc";
}
.fa-deviantart:before {
  content: "\f1bd";
}
.fa-soundcloud:before {
  content: "\f1be";
}
.fa-database:before {
  content: "\f1c0";
}
.fa-file-pdf-o:before {
  content: "\f1c1";
}
.fa-file-word-o:before {
  content: "\f1c2";
}
.fa-file-excel-o:before {
  content: "\f1c3";
}
.fa-file-powerpoint-o:before {
  content: "\f1c4";
}
.fa-file-photo-o:before,
.fa-file-picture-o:before,
.fa-file-image-o:before {
  content: "\f1c5";
}
.fa-file-zip-o:before,
.fa-file-archive-o:before {
  content: "\f1c6";
}
.fa-file-sound-o:before,
.fa-file-audio-o:before {
  content: "\f1c7";
}
.fa-file-movie-o:before,
.fa-file-video-o:before {
  content: "\f1c8";
}
.fa-file-code-o:before {
  content: "\f1c9";
}
.fa-vine:before {
  content: "\f1ca";
}
.fa-codepen:before {
  content: "\f1cb";
}
.fa-jsfiddle:before {
  content: "\f1cc";
}
.fa-life-bouy:before,
.fa-life-buoy:before,
.fa-life-saver:before,
.fa-support:before,
.fa-life-ring:before {
  content: "\f1cd";
}
.fa-circle-o-notch:before {
  content: "\f1ce";
}
.fa-ra:before,
.fa-rebel:before {
  content: "\f1d0";
}
.fa-ge:before,
.fa-empire:before {
  content: "\f1d1";
}
.fa-git-square:before {
  content: "\f1d2";
}
.fa-git:before {
  content: "\f1d3";
}
.fa-hacker-news:before {
  content: "\f1d4";
}
.fa-tencent-weibo:before {
  content: "\f1d5";
}
.fa-qq:before {
  content: "\f1d6";
}
.fa-wechat:before,
.fa-weixin:before {
  content: "\f1d7";
}
.fa-send:before,
.fa-paper-plane:before {
  content: "\f1d8";
}
.fa-send-o:before,
.fa-paper-plane-o:before {
  content: "\f1d9";
}
.fa-history:before {
  content: "\f1da";
}
.fa-genderless:before,
.fa-circle-thin:before {
  content: "\f1db";
}
.fa-header:before {
  content: "\f1dc";
}
.fa-paragraph:before {
  content: "\f1dd";
}
.fa-sliders:before {
  content: "\f1de";
}
.fa-share-alt:before {
  content: "\f1e0";
}
.fa-share-alt-square:before {
  content: "\f1e1";
}
.fa-bomb:before {
  content: "\f1e2";
}
.fa-soccer-ball-o:before,
.fa-futbol-o:before {
  content: "\f1e3";
}
.fa-tty:before {
  content: "\f1e4";
}
.fa-binoculars:before {
  content: "\f1e5";
}
.fa-plug:before {
  content: "\f1e6";
}
.fa-slideshare:before {
  content: "\f1e7";
}
.fa-twitch:before {
  content: "\f1e8";
}
.fa-yelp:before {
  content: "\f1e9";
}
.fa-newspaper-o:before {
  content: "\f1ea";
}
.fa-wifi:before {
  content: "\f1eb";
}
.fa-calculator:before {
  content: "\f1ec";
}
.fa-paypal:before {
  content: "\f1ed";
}
.fa-google-wallet:before {
  content: "\f1ee";
}
.fa-cc-visa:before {
  content: "\f1f0";
}
.fa-cc-mastercard:before {
  content: "\f1f1";
}
.fa-cc-discover:before {
  content: "\f1f2";
}
.fa-cc-amex:before {
  content: "\f1f3";
}
.fa-cc-paypal:before {
  content: "\f1f4";
}
.fa-cc-stripe:before {
  content: "\f1f5";
}
.fa-bell-slash:before {
  content: "\f1f6";
}
.fa-bell-slash-o:before {
  content: "\f1f7";
}
.fa-trash:before {
  content: "\f1f8";
}
.fa-copyright:before {
  content: "\f1f9";
}
.fa-at:before {
  content: "\f1fa";
}
.fa-eyedropper:before {
  content: "\f1fb";
}
.fa-paint-brush:before {
  content: "\f1fc";
}
.fa-birthday-cake:before {
  content: "\f1fd";
}
.fa-area-chart:before {
  content: "\f1fe";
}
.fa-pie-chart:before {
  content: "\f200";
}
.fa-line-chart:before {
  content: "\f201";
}
.fa-lastfm:before {
  content: "\f202";
}
.fa-lastfm-square:before {
  content: "\f203";
}
.fa-toggle-off:before {
  content: "\f204";
}
.fa-toggle-on:before {
  content: "\f205";
}
.fa-bicycle:before {
  content: "\f206";
}
.fa-bus:before {
  content: "\f207";
}
.fa-ioxhost:before {
  content: "\f208";
}
.fa-angellist:before {
  content: "\f209";
}
.fa-cc:before {
  content: "\f20a";
}
.fa-shekel:before,
.fa-sheqel:before,
.fa-ils:before {
  content: "\f20b";
}
.fa-meanpath:before {
  content: "\f20c";
}
.fa-buysellads:before {
  content: "\f20d";
}
.fa-connectdevelop:before {
  content: "\f20e";
}
.fa-dashcube:before {
  content: "\f210";
}
.fa-forumbee:before {
  content: "\f211";
}
.fa-leanpub:before {
  content: "\f212";
}
.fa-sellsy:before {
  content: "\f213";
}
.fa-shirtsinbulk:before {
  content: "\f214";
}
.fa-simplybuilt:before {
  content: "\f215";
}
.fa-skyatlas:before {
  content: "\f216";
}
.fa-cart-plus:before {
  content: "\f217";
}
.fa-cart-arrow-down:before {
  content: "\f218";
}
.fa-diamond:before {
  content: "\f219";
}
.fa-ship:before {
  content: "\f21a";
}
.fa-user-secret:before {
  content: "\f21b";
}
.fa-motorcycle:before {
  content: "\f21c";
}
.fa-street-view:before {
  content: "\f21d";
}
.fa-heartbeat:before {
  content: "\f21e";
}
.fa-venus:before {
  content: "\f221";
}
.fa-mars:before {
  content: "\f222";
}
.fa-mercury:before {
  content: "\f223";
}
.fa-transgender:before {
  content: "\f224";
}
.fa-transgender-alt:before {
  content: "\f225";
}
.fa-venus-double:before {
  content: "\f226";
}
.fa-mars-double:before {
  content: "\f227";
}
.fa-venus-mars:before {
  content: "\f228";
}
.fa-mars-stroke:before {
  content: "\f229";
}
.fa-mars-stroke-v:before {
  content: "\f22a";
}
.fa-mars-stroke-h:before {
  content: "\f22b";
}
.fa-neuter:before {
  content: "\f22c";
}
.fa-facebook-official:before {
  content: "\f230";
}
.fa-pinterest-p:before {
  content: "\f231";
}
.fa-whatsapp:before {
  content: "\f232";
}
.fa-server:before {
  content: "\f233";
}
.fa-user-plus:before {
  content: "\f234";
}
.fa-user-times:before {
  content: "\f235";
}
.fa-hotel:before,
.fa-bed:before {
  content: "\f236";
}
.fa-viacoin:before {
  content: "\f237";
}
.fa-train:before {
  content: "\f238";
}
.fa-subway:before {
  content: "\f239";
}
.fa-medium:before {
  content: "\f23a";
}

@charset "UTF-8";
/*!
 * Bootstrap v4.0.0-alpha.2 (http://getbootstrap.com)
 * Copyright 2011-2015 Twitter, Inc.
 * Licensed under MIT (https://github.com/twbs/bootstrap/blob/master/LICENSE)
 */
/*@import "variables";*/
/*! normalize.css v3.0.3 | MIT License | github.com/necolas/normalize.css */
html {
  font-family: sans-serif;
  -ms-text-size-adjust: 100%;
  -webkit-text-size-adjust: 100%; }

body {
  margin: 0; }

article, aside, details, figcaption, figure, footer, header, hgroup, main, menu, nav, section, summary {
  display: block; }

audio, canvas, progress, video {
  display: inline-block;
  vertical-align: baseline; }

audio:not([controls]) {
  display: none;
  height: 0; }

[hidden], template {
  display: none; }

a {
  background-color: transparent; }

a:active {
  outline: 0; }
  a:hover {
    outline: 0; }

abbr[title] {
  border-bottom: 1px dotted; }

b, strong {
  font-weight: bold; }

dfn {
  font-style: italic; }

h1 {
  font-size: 2em;
  margin: 0.67em 0; }

mark {
  background: #ff0;
  color: #000; }

small {
  font-size: 80%; }

sub, sup {
  font-size: 75%;
  line-height: 0;
  position: relative;
  vertical-align: baseline; }

sup {
  top: -0.5em; }

sub {
  bottom: -0.25em; }

img {
  border: 0; }

svg:not(:root) {
  overflow: hidden; }

figure {
  margin: 1em 40px; }

hr {
  box-sizing: content-box;
  height: 0; }

pre {
  overflow: auto; }

code, kbd, pre, samp {
  font-family: monospace, monospace;
  font-size: 1em; }

button, input, optgroup, select, textarea {
  color: inherit;
  font: inherit;
  margin: 0; }

button {
  overflow: visible; }

button, select {
  text-transform: none; }

button, html input[type="button"], input[type="reset"], input[type="submit"] {
  -webkit-appearance: button;
  cursor: pointer; }

button[disabled], html input[disabled] {
  cursor: default; }

button::-moz-focus-inner, input::-moz-focus-inner {
  border: 0;
  padding: 0; }

input {
  line-height: normal; }

input[type="checkbox"], input[type="radio"] {
  box-sizing: border-box;
  padding: 0; }

input[type="number"]::-webkit-inner-spin-button, input[type="number"]::-webkit-outer-spin-button {
  height: auto; }

input[type="search"] {
  -webkit-appearance: textfield;
  box-sizing: content-box; }

input[type="search"]::-webkit-search-cancel-button, input[type="search"]::-webkit-search-decoration {
  -webkit-appearance: none; }

fieldset {
  border: 1px solid #c0c0c0;
  margin: 0 2px;
  padding: 0.35em 0.625em 0.75em; }

legend {
  border: 0;
  padding: 0; }

textarea {
  overflow: auto; }

optgroup {
  font-weight: bold; }

table {
  border-collapse: collapse;
  border-spacing: 0; }

td, th {
  padding: 0; }

@media print {
  *, *::before, *::after {
    text-shadow: none !important;
    box-shadow: none !important; }

  a, a:visited {
    text-decoration: underline; }

  abbr[title]::after {
    content: " (" attr(title) ")"; }

  pre, blockquote {
    border: 1px solid #999;
    page-break-inside: avoid; }

  thead {
    display: table-header-group; }

  tr, img {
    page-break-inside: avoid; }

  img {
    max-width: 100% !important; }

  p, h2, h3 {
    orphans: 3;
    widows: 3; }

  h2, h3 {
    page-break-after: avoid; }

  .navbar {
    display: none; }

  .btn > .caret, .dropup > .btn > .caret {
    border-top-color: #000 !important; }

  .label {
    border: 1px solid #000; }

  .table {
    border-collapse: collapse !important; }
    .table td, .table th {
      background-color: #fff !important; }

  .table-bordered th, .table-bordered td {
    border: 1px solid #ddd !important; } }

html {
  box-sizing: border-box; }

*, *::before, *::after {
  box-sizing: inherit; }
  @-moz-viewport {
    width: device-width; }
    @-ms-viewport {
      width: device-width; }
    @-o-viewport {
      width: device-width; }
    @-webkit-viewport {
      width: device-width; }
    @viewport {
      width: device-width; }

html {
  font-size: 16px;
  -webkit-tap-highlight-color: rgba(0, 0, 0, 0); }

body {
  font-family: "Proxima Nova", "Helvetica Neue", Helvetica, Arial, sans-serif;
  font-size: 1rem;
  line-height: 1.5;
  color: #353535;
  background-color: #f1f2f3; }

[tabindex="-1"]:focus {
  outline: none !important; }

h1, h2, h3, h4, h5, h6 {
  margin-top: 0;
  margin-bottom: 0.5rem; }

p {
  margin-top: 0;
  margin-bottom: 1rem; }

abbr[title], abbr[data-original-title] {
  cursor: help;
  border-bottom: 1px dotted #818a91; }

address {
  margin-bottom: 1rem;
  font-style: normal;
  line-height: inherit; }

ol, ul, dl {
  margin-top: 0;
  margin-bottom: 1rem; }

ol ol, ul ul, ol ul, ul ol {
  margin-bottom: 0; }

dt {
  font-weight: bold; }

dd {
  margin-bottom: 0.5rem;
  margin-left: 0; }

blockquote {
  margin: 0 0 1rem; }

a {
  color: #38b5e6;
  text-decoration: none; }
  a:focus, a:hover {
    color: #21ade3;
    text-decoration: underline; }
  a:focus {
    outline: thin dotted;
    outline: 5px auto -webkit-focus-ring-color;
    outline-offset: -2px; }

pre {
  margin-top: 0;
  margin-bottom: 1rem; }

figure {
  margin: 0 0 1rem; }

img {
  vertical-align: middle; }

[role="button"] {
  cursor: pointer; }

a, area, button, [role="button"], input, label, select, summary, textarea {
  touch-action: manipulation; }

table {
  background-color: transparent; }

caption {
  padding-top: 0.75rem;
  padding-bottom: 0.75rem;
  color: #818a91;
  text-align: left;
  caption-side: bottom; }

th {
  text-align: left; }

label {
  display: inline-block;
  margin-bottom: 0.5rem; }

button:focus {
  outline: 1px dotted;
  outline: 5px auto -webkit-focus-ring-color; }

input, button, select, textarea {
  margin: 0;
  line-height: inherit;
  border-radius: 0; }

textarea {
  resize: vertical; }

fieldset {
  min-width: 0;
  padding: 0;
  margin: 0;
  border: 0; }

legend {
  display: block;
  width: 100%;
  padding: 0;
  margin-bottom: 0.5rem;
  font-size: 1.5rem;
  line-height: inherit; }

input[type="search"] {
  box-sizing: inherit;
  -webkit-appearance: none; }

output {
  display: inline-block; }

[hidden] {
  display: none !important; }

h1, h2, h3, h4, h5, h6, .h1, .h2, .h3, .h4, .h5, .h6 {
  margin-bottom: 0.5rem;
  font-family: inherit;
  font-weight: 500;
  line-height: 1.1;
  color: inherit; }

h1 {
  font-size: 2.25rem; }

h2 {
  font-size: 1.75rem; }

h3 {
  font-size: 1.5rem; }

h4 {
  font-size: 1.25rem; }

h5 {
  font-size: 1.1rem; }

h6 {
  font-size: 1rem; }

.h1 {
  font-size: 2.25rem; }

.h2 {
  font-size: 1.75rem; }

.h3 {
  font-size: 1.5rem; }

.h4 {
  font-size: 1.25rem; }

.h5 {
  font-size: 1.1rem; }

.h6 {
  font-size: 1rem; }

.lead {
  font-size: 1.25rem;
  font-weight: 300; }

.display-1 {
  font-size: 6rem;
  font-weight: 300; }

.display-2 {
  font-size: 5.5rem;
  font-weight: 300; }

.display-3 {
  font-size: 4.5rem;
  font-weight: 300; }

.display-4 {
  font-size: 3.5rem;
  font-weight: 300; }

hr {
  margin-top: 1rem;
  margin-bottom: 1rem;
  border: 0;
  border-top: 1px solid rgba(0, 0, 0, .1); }

small, .small {
  font-size: 80%;
  font-weight: normal; }

mark, .mark {
  padding: 0.2em;
  background-color: #f48714; }

.list-unstyled {
  padding-left: 0;
  list-style: none; }

.list-inline {
  padding-left: 0;
  list-style: none; }

.list-inline-item {
  display: inline-block; }
  .list-inline-item:not(:last-child) {
    margin-right: 5px; }

.dl-horizontal {
  margin-right: -1.875rem;
  margin-left: -1.875rem; }
  .dl-horizontal::after {
    content: "";
    display: table;
    clear: both; }

.initialism {
  font-size: 90%;
  text-transform: uppercase; }

.blockquote {
  padding: 0.5rem 1rem;
  margin-bottom: 1rem;
  font-size: 1.25rem;
  border-left: 0.25rem solid #eceeef; }

.blockquote-footer {
  display: block;
  font-size: 80%;
  line-height: 1.5;
  color: #818a91; }
  .blockquote-footer::before {
    content: "\2014 \00A0"; }

.blockquote-reverse {
  padding-right: 1rem;
  padding-left: 0;
  text-align: right;
  border-right: 0.25rem solid #eceeef;
  border-left: 0; }

.blockquote-reverse .blockquote-footer::before {
  content: ""; }
  .blockquote-reverse .blockquote-footer::after {
    content: "\00A0 \2014"; }

.img-fluid, .carousel-inner > .carousel-item > img, .carousel-inner > .carousel-item > a > img {
  display: block;
  max-width: 100%;
  height: auto; }

.img-rounded {
  border-radius: 0; }

.img-thumbnail {
  padding: 0.25rem;
  line-height: 1.5;
  background-color: #f1f2f3;
  border: 1px solid #ddd;
  border-radius: 0;
  transition: all 0.2s ease-in-out;
  display: inline-block;
  max-width: 100%;
  height: auto; }

.img-circle {
  border-radius: 50%; }

.figure {
  display: inline-block; }

.figure-img {
  margin-bottom: 0.5rem;
  line-height: 1; }

.figure-caption {
  font-size: 90%;
  color: #818a91; }

code, kbd, pre, samp {
  font-family: Menlo, Monaco, Consolas, "Courier New", monospace; }

code {
  padding: 0.2rem 0.4rem;
  font-size: 90%;
  color: #bd4147;
  background-color: #f7f7f9;
  border-radius: 0; }

kbd {
  padding: 0.2rem 0.4rem;
  font-size: 90%;
  color: #fff;
  background-color: #333;
  border-radius: 0; }
  kbd kbd {
    padding: 0;
    font-size: 100%;
    font-weight: bold; }

pre {
  display: block;
  margin-top: 0;
  margin-bottom: 1rem;
  font-size: 90%;
  line-height: 1.5;
  color: #353535; }
  pre code {
    padding: 0;
    font-size: inherit;
    color: inherit;
    background-color: transparent;
    border-radius: 0; }

.pre-scrollable {
  max-height: 340px;
  overflow-y: scroll; }

.container {
  margin-left: auto;
  margin-right: auto;
  padding-left: 0.9375rem;
  padding-right: 0.9375rem; }
  .container::after {
    content: "";
    display: table;
    clear: both; }
    @media (min-width: 544px) {
  .container {
    max-width: 576px; } }
    @media (min-width: 768px) {
  .container {
    max-width: 720px; } }
    @media (min-width: 992px) {
  .container {
    max-width: 940px; } }
    @media (min-width: 1200px) {
  .container {
    max-width: 1140px; } }

.container-fluid {
  margin-left: auto;
  margin-right: auto;
  padding-left: 0.9375rem;
  padding-right: 0.9375rem; }
  .container-fluid::after {
    content: "";
    display: table;
    clear: both; }

.row {
  margin-left: -0.9375rem;
  margin-right: -0.9375rem; }
  .row::after {
    content: "";
    display: table;
    clear: both; }

.col-xs-1, .col-xs-2, .col-xs-3, .col-xs-4, .col-xs-5, .col-xs-6, .col-xs-7, .col-xs-8, .col-xs-9, .col-xs-10, .col-xs-11, .col-xs-12, .col-xs-13, .col-xs-14, .col-xs-15, .col-xs-16, .col-xs-17, .col-xs-18, .col-xs-19, .col-xs-20, .col-xs-21, .col-xs-22, .col-xs-23, .col-xs-24, .col-sm-1, .col-sm-2, .col-sm-3, .col-sm-4, .col-sm-5, .col-sm-6, .col-sm-7, .col-sm-8, .col-sm-9, .col-sm-10, .col-sm-11, .col-sm-12, .col-sm-13, .col-sm-14, .col-sm-15, .col-sm-16, .col-sm-17, .col-sm-18, .col-sm-19, .col-sm-20, .col-sm-21, .col-sm-22, .col-sm-23, .col-sm-24, .col-md-1, .col-md-2, .col-md-3, .col-md-4, .col-md-5, .col-md-6, .col-md-7, .col-md-8, .col-md-9, .col-md-10, .col-md-11, .col-md-12, .col-md-13, .col-md-14, .col-md-15, .col-md-16, .col-md-17, .col-md-18, .col-md-19, .col-md-20, .col-md-21, .col-md-22, .col-md-23, .col-md-24, .col-lg-1, .col-lg-2, .col-lg-3, .col-lg-4, .col-lg-5, .col-lg-6, .col-lg-7, .col-lg-8, .col-lg-9, .col-lg-10, .col-lg-11, .col-lg-12, .col-lg-13, .col-lg-14, .col-lg-15, .col-lg-16, .col-lg-17, .col-lg-18, .col-lg-19, .col-lg-20, .col-lg-21, .col-lg-22, .col-lg-23, .col-lg-24, .col-xl-1, .col-xl-2, .col-xl-3, .col-xl-4, .col-xl-5, .col-xl-6, .col-xl-7, .col-xl-8, .col-xl-9, .col-xl-10, .col-xl-11, .col-xl-12, .col-xl-13, .col-xl-14, .col-xl-15, .col-xl-16, .col-xl-17, .col-xl-18, .col-xl-19, .col-xl-20, .col-xl-21, .col-xl-22, .col-xl-23, .col-xl-24 {
  position: relative;
  min-height: 1px;
  padding-left: 0.9375rem;
  padding-right: 0.9375rem; }
  .col-xs-1, .col-xs-2, .col-xs-3, .col-xs-4, .col-xs-5, .col-xs-6, .col-xs-7, .col-xs-8, .col-xs-9, .col-xs-10, .col-xs-11, .col-xs-12, .col-xs-13, .col-xs-14, .col-xs-15, .col-xs-16, .col-xs-17, .col-xs-18, .col-xs-19, .col-xs-20, .col-xs-21, .col-xs-22, .col-xs-23, .col-xs-24 {
    float: left; }
  .col-xs-1 {
    width: 4.16667%; }
  .col-xs-2 {
    width: 8.33333%; }
  .col-xs-3 {
    width: 12.5%; }
  .col-xs-4 {
    width: 16.66667%; }
  .col-xs-5 {
    width: 20.83333%; }
  .col-xs-6 {
    width: 25%; }
  .col-xs-7 {
    width: 29.16667%; }
  .col-xs-8 {
    width: 33.33333%; }
  .col-xs-9 {
    width: 37.5%; }
  .col-xs-10 {
    width: 41.66667%; }
  .col-xs-11 {
    width: 45.83333%; }
  .col-xs-12 {
    width: 50%; }
  .col-xs-13 {
    width: 54.16667%; }
  .col-xs-14 {
    width: 58.33333%; }
  .col-xs-15 {
    width: 62.5%; }
  .col-xs-16 {
    width: 66.66667%; }
  .col-xs-17 {
    width: 70.83333%; }
  .col-xs-18 {
    width: 75%; }
  .col-xs-19 {
    width: 79.16667%; }
  .col-xs-20 {
    width: 83.33333%; }
  .col-xs-21 {
    width: 87.5%; }
  .col-xs-22 {
    width: 91.66667%; }
  .col-xs-23 {
    width: 95.83333%; }
  .col-xs-24 {
    width: 100%; }
    .col-xs-pull-0 {
      right: auto; }
    .col-xs-pull-1 {
      right: 4.16667%; }
    .col-xs-pull-2 {
      right: 8.33333%; }
    .col-xs-pull-3 {
      right: 12.5%; }
    .col-xs-pull-4 {
      right: 16.66667%; }
    .col-xs-pull-5 {
      right: 20.83333%; }
    .col-xs-pull-6 {
      right: 25%; }
    .col-xs-pull-7 {
      right: 29.16667%; }
    .col-xs-pull-8 {
      right: 33.33333%; }
    .col-xs-pull-9 {
      right: 37.5%; }
    .col-xs-pull-10 {
      right: 41.66667%; }
    .col-xs-pull-11 {
      right: 45.83333%; }
    .col-xs-pull-12 {
      right: 50%; }
    .col-xs-pull-13 {
      right: 54.16667%; }
    .col-xs-pull-14 {
      right: 58.33333%; }
    .col-xs-pull-15 {
      right: 62.5%; }
    .col-xs-pull-16 {
      right: 66.66667%; }
    .col-xs-pull-17 {
      right: 70.83333%; }
    .col-xs-pull-18 {
      right: 75%; }
    .col-xs-pull-19 {
      right: 79.16667%; }
    .col-xs-pull-20 {
      right: 83.33333%; }
    .col-xs-pull-21 {
      right: 87.5%; }
    .col-xs-pull-22 {
      right: 91.66667%; }
    .col-xs-pull-23 {
      right: 95.83333%; }
    .col-xs-pull-24 {
      right: 100%; }
    .col-xs-push-0 {
      left: auto; }
    .col-xs-push-1 {
      left: 4.16667%; }
    .col-xs-push-2 {
      left: 8.33333%; }
    .col-xs-push-3 {
      left: 12.5%; }
    .col-xs-push-4 {
      left: 16.66667%; }
    .col-xs-push-5 {
      left: 20.83333%; }
    .col-xs-push-6 {
      left: 25%; }
    .col-xs-push-7 {
      left: 29.16667%; }
    .col-xs-push-8 {
      left: 33.33333%; }
    .col-xs-push-9 {
      left: 37.5%; }
    .col-xs-push-10 {
      left: 41.66667%; }
    .col-xs-push-11 {
      left: 45.83333%; }
    .col-xs-push-12 {
      left: 50%; }
    .col-xs-push-13 {
      left: 54.16667%; }
    .col-xs-push-14 {
      left: 58.33333%; }
    .col-xs-push-15 {
      left: 62.5%; }
    .col-xs-push-16 {
      left: 66.66667%; }
    .col-xs-push-17 {
      left: 70.83333%; }
    .col-xs-push-18 {
      left: 75%; }
    .col-xs-push-19 {
      left: 79.16667%; }
    .col-xs-push-20 {
      left: 83.33333%; }
    .col-xs-push-21 {
      left: 87.5%; }
    .col-xs-push-22 {
      left: 91.66667%; }
    .col-xs-push-23 {
      left: 95.83333%; }
    .col-xs-push-24 {
      left: 100%; }
    .col-xs-offset-0 {
      margin-left: 0%; }
    .col-xs-offset-1 {
      margin-left: 4.16667%; }
    .col-xs-offset-2 {
      margin-left: 8.33333%; }
    .col-xs-offset-3 {
      margin-left: 12.5%; }
    .col-xs-offset-4 {
      margin-left: 16.66667%; }
    .col-xs-offset-5 {
      margin-left: 20.83333%; }
    .col-xs-offset-6 {
      margin-left: 25%; }
    .col-xs-offset-7 {
      margin-left: 29.16667%; }
    .col-xs-offset-8 {
      margin-left: 33.33333%; }
    .col-xs-offset-9 {
      margin-left: 37.5%; }
    .col-xs-offset-10 {
      margin-left: 41.66667%; }
    .col-xs-offset-11 {
      margin-left: 45.83333%; }
    .col-xs-offset-12 {
      margin-left: 50%; }
    .col-xs-offset-13 {
      margin-left: 54.16667%; }
    .col-xs-offset-14 {
      margin-left: 58.33333%; }
    .col-xs-offset-15 {
      margin-left: 62.5%; }
    .col-xs-offset-16 {
      margin-left: 66.66667%; }
    .col-xs-offset-17 {
      margin-left: 70.83333%; }
    .col-xs-offset-18 {
      margin-left: 75%; }
    .col-xs-offset-19 {
      margin-left: 79.16667%; }
    .col-xs-offset-20 {
      margin-left: 83.33333%; }
    .col-xs-offset-21 {
      margin-left: 87.5%; }
    .col-xs-offset-22 {
      margin-left: 91.66667%; }
    .col-xs-offset-23 {
      margin-left: 95.83333%; }
    .col-xs-offset-24 {
      margin-left: 100%; }
  @media (min-width: 544px) {
  .col-sm-1, .col-sm-2, .col-sm-3, .col-sm-4, .col-sm-5, .col-sm-6, .col-sm-7, .col-sm-8, .col-sm-9, .col-sm-10, .col-sm-11, .col-sm-12, .col-sm-13, .col-sm-14, .col-sm-15, .col-sm-16, .col-sm-17, .col-sm-18, .col-sm-19, .col-sm-20, .col-sm-21, .col-sm-22, .col-sm-23, .col-sm-24 {
    float: left; }
    .col-sm-1 {
      width: 4.16667%; }

    .col-sm-2 {
      width: 8.33333%; }

    .col-sm-3 {
      width: 12.5%; }

    .col-sm-4 {
      width: 16.66667%; }

    .col-sm-5 {
      width: 20.83333%; }

    .col-sm-6 {
      width: 25%; }

    .col-sm-7 {
      width: 29.16667%; }

    .col-sm-8 {
      width: 33.33333%; }

    .col-sm-9 {
      width: 37.5%; }

    .col-sm-10 {
      width: 41.66667%; }

    .col-sm-11 {
      width: 45.83333%; }

    .col-sm-12 {
      width: 50%; }

    .col-sm-13 {
      width: 54.16667%; }

    .col-sm-14 {
      width: 58.33333%; }

    .col-sm-15 {
      width: 62.5%; }

    .col-sm-16 {
      width: 66.66667%; }

    .col-sm-17 {
      width: 70.83333%; }

    .col-sm-18 {
      width: 75%; }

    .col-sm-19 {
      width: 79.16667%; }

    .col-sm-20 {
      width: 83.33333%; }

    .col-sm-21 {
      width: 87.5%; }

    .col-sm-22 {
      width: 91.66667%; }

    .col-sm-23 {
      width: 95.83333%; }

    .col-sm-24 {
      width: 100%; }
      .col-sm-pull-0 {
        right: auto; }
      .col-sm-pull-1 {
        right: 4.16667%; }
      .col-sm-pull-2 {
        right: 8.33333%; }
      .col-sm-pull-3 {
        right: 12.5%; }
      .col-sm-pull-4 {
        right: 16.66667%; }
      .col-sm-pull-5 {
        right: 20.83333%; }
      .col-sm-pull-6 {
        right: 25%; }
      .col-sm-pull-7 {
        right: 29.16667%; }
      .col-sm-pull-8 {
        right: 33.33333%; }
      .col-sm-pull-9 {
        right: 37.5%; }
      .col-sm-pull-10 {
        right: 41.66667%; }
      .col-sm-pull-11 {
        right: 45.83333%; }
      .col-sm-pull-12 {
        right: 50%; }
      .col-sm-pull-13 {
        right: 54.16667%; }
      .col-sm-pull-14 {
        right: 58.33333%; }
      .col-sm-pull-15 {
        right: 62.5%; }
      .col-sm-pull-16 {
        right: 66.66667%; }
      .col-sm-pull-17 {
        right: 70.83333%; }
      .col-sm-pull-18 {
        right: 75%; }
      .col-sm-pull-19 {
        right: 79.16667%; }
      .col-sm-pull-20 {
        right: 83.33333%; }
      .col-sm-pull-21 {
        right: 87.5%; }
      .col-sm-pull-22 {
        right: 91.66667%; }
      .col-sm-pull-23 {
        right: 95.83333%; }
      .col-sm-pull-24 {
        right: 100%; }
      .col-sm-push-0 {
        left: auto; }
      .col-sm-push-1 {
        left: 4.16667%; }
      .col-sm-push-2 {
        left: 8.33333%; }
      .col-sm-push-3 {
        left: 12.5%; }
      .col-sm-push-4 {
        left: 16.66667%; }
      .col-sm-push-5 {
        left: 20.83333%; }
      .col-sm-push-6 {
        left: 25%; }
      .col-sm-push-7 {
        left: 29.16667%; }
      .col-sm-push-8 {
        left: 33.33333%; }
      .col-sm-push-9 {
        left: 37.5%; }
      .col-sm-push-10 {
        left: 41.66667%; }
      .col-sm-push-11 {
        left: 45.83333%; }
      .col-sm-push-12 {
        left: 50%; }
      .col-sm-push-13 {
        left: 54.16667%; }
      .col-sm-push-14 {
        left: 58.33333%; }
      .col-sm-push-15 {
        left: 62.5%; }
      .col-sm-push-16 {
        left: 66.66667%; }
      .col-sm-push-17 {
        left: 70.83333%; }
      .col-sm-push-18 {
        left: 75%; }
      .col-sm-push-19 {
        left: 79.16667%; }
      .col-sm-push-20 {
        left: 83.33333%; }
      .col-sm-push-21 {
        left: 87.5%; }
      .col-sm-push-22 {
        left: 91.66667%; }
      .col-sm-push-23 {
        left: 95.83333%; }
      .col-sm-push-24 {
        left: 100%; }
      .col-sm-offset-0 {
        margin-left: 0%; }
      .col-sm-offset-1 {
        margin-left: 4.16667%; }
      .col-sm-offset-2 {
        margin-left: 8.33333%; }
      .col-sm-offset-3 {
        margin-left: 12.5%; }
      .col-sm-offset-4 {
        margin-left: 16.66667%; }
      .col-sm-offset-5 {
        margin-left: 20.83333%; }
      .col-sm-offset-6 {
        margin-left: 25%; }
      .col-sm-offset-7 {
        margin-left: 29.16667%; }
      .col-sm-offset-8 {
        margin-left: 33.33333%; }
      .col-sm-offset-9 {
        margin-left: 37.5%; }
      .col-sm-offset-10 {
        margin-left: 41.66667%; }
      .col-sm-offset-11 {
        margin-left: 45.83333%; }
      .col-sm-offset-12 {
        margin-left: 50%; }
      .col-sm-offset-13 {
        margin-left: 54.16667%; }
      .col-sm-offset-14 {
        margin-left: 58.33333%; }
      .col-sm-offset-15 {
        margin-left: 62.5%; }
      .col-sm-offset-16 {
        margin-left: 66.66667%; }
      .col-sm-offset-17 {
        margin-left: 70.83333%; }
      .col-sm-offset-18 {
        margin-left: 75%; }
      .col-sm-offset-19 {
        margin-left: 79.16667%; }
      .col-sm-offset-20 {
        margin-left: 83.33333%; }
      .col-sm-offset-21 {
        margin-left: 87.5%; }
      .col-sm-offset-22 {
        margin-left: 91.66667%; }
      .col-sm-offset-23 {
        margin-left: 95.83333%; }
      .col-sm-offset-24 {
        margin-left: 100%; } }
  @media (min-width: 768px) {
  .col-md-1, .col-md-2, .col-md-3, .col-md-4, .col-md-5, .col-md-6, .col-md-7, .col-md-8, .col-md-9, .col-md-10, .col-md-11, .col-md-12, .col-md-13, .col-md-14, .col-md-15, .col-md-16, .col-md-17, .col-md-18, .col-md-19, .col-md-20, .col-md-21, .col-md-22, .col-md-23, .col-md-24 {
    float: left; }
    .col-md-1 {
      width: 4.16667%; }

    .col-md-2 {
      width: 8.33333%; }

    .col-md-3 {
      width: 12.5%; }

    .col-md-4 {
      width: 16.66667%; }

    .col-md-5 {
      width: 20.83333%; }

    .col-md-6 {
      width: 25%; }

    .col-md-7 {
      width: 29.16667%; }

    .col-md-8 {
      width: 33.33333%; }

    .col-md-9 {
      width: 37.5%; }

    .col-md-10 {
      width: 41.66667%; }

    .col-md-11 {
      width: 45.83333%; }

    .col-md-12 {
      width: 50%; }

    .col-md-13 {
      width: 54.16667%; }

    .col-md-14 {
      width: 58.33333%; }

    .col-md-15 {
      width: 62.5%; }

    .col-md-16 {
      width: 66.66667%; }

    .col-md-17 {
      width: 70.83333%; }

    .col-md-18 {
      width: 75%; }

    .col-md-19 {
      width: 79.16667%; }

    .col-md-20 {
      width: 83.33333%; }

    .col-md-21 {
      width: 87.5%; }

    .col-md-22 {
      width: 91.66667%; }

    .col-md-23 {
      width: 95.83333%; }

    .col-md-24 {
      width: 100%; }
      .col-md-pull-0 {
        right: auto; }
      .col-md-pull-1 {
        right: 4.16667%; }
      .col-md-pull-2 {
        right: 8.33333%; }
      .col-md-pull-3 {
        right: 12.5%; }
      .col-md-pull-4 {
        right: 16.66667%; }
      .col-md-pull-5 {
        right: 20.83333%; }
      .col-md-pull-6 {
        right: 25%; }
      .col-md-pull-7 {
        right: 29.16667%; }
      .col-md-pull-8 {
        right: 33.33333%; }
      .col-md-pull-9 {
        right: 37.5%; }
      .col-md-pull-10 {
        right: 41.66667%; }
      .col-md-pull-11 {
        right: 45.83333%; }
      .col-md-pull-12 {
        right: 50%; }
      .col-md-pull-13 {
        right: 54.16667%; }
      .col-md-pull-14 {
        right: 58.33333%; }
      .col-md-pull-15 {
        right: 62.5%; }
      .col-md-pull-16 {
        right: 66.66667%; }
      .col-md-pull-17 {
        right: 70.83333%; }
      .col-md-pull-18 {
        right: 75%; }
      .col-md-pull-19 {
        right: 79.16667%; }
      .col-md-pull-20 {
        right: 83.33333%; }
      .col-md-pull-21 {
        right: 87.5%; }
      .col-md-pull-22 {
        right: 91.66667%; }
      .col-md-pull-23 {
        right: 95.83333%; }
      .col-md-pull-24 {
        right: 100%; }
      .col-md-push-0 {
        left: auto; }
      .col-md-push-1 {
        left: 4.16667%; }
      .col-md-push-2 {
        left: 8.33333%; }
      .col-md-push-3 {
        left: 12.5%; }
      .col-md-push-4 {
        left: 16.66667%; }
      .col-md-push-5 {
        left: 20.83333%; }
      .col-md-push-6 {
        left: 25%; }
      .col-md-push-7 {
        left: 29.16667%; }
      .col-md-push-8 {
        left: 33.33333%; }
      .col-md-push-9 {
        left: 37.5%; }
      .col-md-push-10 {
        left: 41.66667%; }
      .col-md-push-11 {
        left: 45.83333%; }
      .col-md-push-12 {
        left: 50%; }
      .col-md-push-13 {
        left: 54.16667%; }
      .col-md-push-14 {
        left: 58.33333%; }
      .col-md-push-15 {
        left: 62.5%; }
      .col-md-push-16 {
        left: 66.66667%; }
      .col-md-push-17 {
        left: 70.83333%; }
      .col-md-push-18 {
        left: 75%; }
      .col-md-push-19 {
        left: 79.16667%; }
      .col-md-push-20 {
        left: 83.33333%; }
      .col-md-push-21 {
        left: 87.5%; }
      .col-md-push-22 {
        left: 91.66667%; }
      .col-md-push-23 {
        left: 95.83333%; }
      .col-md-push-24 {
        left: 100%; }
      .col-md-offset-0 {
        margin-left: 0%; }
      .col-md-offset-1 {
        margin-left: 4.16667%; }
      .col-md-offset-2 {
        margin-left: 8.33333%; }
      .col-md-offset-3 {
        margin-left: 12.5%; }
      .col-md-offset-4 {
        margin-left: 16.66667%; }
      .col-md-offset-5 {
        margin-left: 20.83333%; }
      .col-md-offset-6 {
        margin-left: 25%; }
      .col-md-offset-7 {
        margin-left: 29.16667%; }
      .col-md-offset-8 {
        margin-left: 33.33333%; }
      .col-md-offset-9 {
        margin-left: 37.5%; }
      .col-md-offset-10 {
        margin-left: 41.66667%; }
      .col-md-offset-11 {
        margin-left: 45.83333%; }
      .col-md-offset-12 {
        margin-left: 50%; }
      .col-md-offset-13 {
        margin-left: 54.16667%; }
      .col-md-offset-14 {
        margin-left: 58.33333%; }
      .col-md-offset-15 {
        margin-left: 62.5%; }
      .col-md-offset-16 {
        margin-left: 66.66667%; }
      .col-md-offset-17 {
        margin-left: 70.83333%; }
      .col-md-offset-18 {
        margin-left: 75%; }
      .col-md-offset-19 {
        margin-left: 79.16667%; }
      .col-md-offset-20 {
        margin-left: 83.33333%; }
      .col-md-offset-21 {
        margin-left: 87.5%; }
      .col-md-offset-22 {
        margin-left: 91.66667%; }
      .col-md-offset-23 {
        margin-left: 95.83333%; }
      .col-md-offset-24 {
        margin-left: 100%; } }
  @media (min-width: 992px) {
  .col-lg-1, .col-lg-2, .col-lg-3, .col-lg-4, .col-lg-5, .col-lg-6, .col-lg-7, .col-lg-8, .col-lg-9, .col-lg-10, .col-lg-11, .col-lg-12, .col-lg-13, .col-lg-14, .col-lg-15, .col-lg-16, .col-lg-17, .col-lg-18, .col-lg-19, .col-lg-20, .col-lg-21, .col-lg-22, .col-lg-23, .col-lg-24 {
    float: left; }
    .col-lg-1 {
      width: 4.16667%; }

    .col-lg-2 {
      width: 8.33333%; }

    .col-lg-3 {
      width: 12.5%; }

    .col-lg-4 {
      width: 16.66667%; }

    .col-lg-5 {
      width: 20.83333%; }

    .col-lg-6 {
      width: 25%; }

    .col-lg-7 {
      width: 29.16667%; }

    .col-lg-8 {
      width: 33.33333%; }

    .col-lg-9 {
      width: 37.5%; }

    .col-lg-10 {
      width: 41.66667%; }

    .col-lg-11 {
      width: 45.83333%; }

    .col-lg-12 {
      width: 50%; }

    .col-lg-13 {
      width: 54.16667%; }

    .col-lg-14 {
      width: 58.33333%; }

    .col-lg-15 {
      width: 62.5%; }

    .col-lg-16 {
      width: 66.66667%; }

    .col-lg-17 {
      width: 70.83333%; }

    .col-lg-18 {
      width: 75%; }

    .col-lg-19 {
      width: 79.16667%; }

    .col-lg-20 {
      width: 83.33333%; }

    .col-lg-21 {
      width: 87.5%; }

    .col-lg-22 {
      width: 91.66667%; }

    .col-lg-23 {
      width: 95.83333%; }

    .col-lg-24 {
      width: 100%; }
      .col-lg-pull-0 {
        right: auto; }
      .col-lg-pull-1 {
        right: 4.16667%; }
      .col-lg-pull-2 {
        right: 8.33333%; }
      .col-lg-pull-3 {
        right: 12.5%; }
      .col-lg-pull-4 {
        right: 16.66667%; }
      .col-lg-pull-5 {
        right: 20.83333%; }
      .col-lg-pull-6 {
        right: 25%; }
      .col-lg-pull-7 {
        right: 29.16667%; }
      .col-lg-pull-8 {
        right: 33.33333%; }
      .col-lg-pull-9 {
        right: 37.5%; }
      .col-lg-pull-10 {
        right: 41.66667%; }
      .col-lg-pull-11 {
        right: 45.83333%; }
      .col-lg-pull-12 {
        right: 50%; }
      .col-lg-pull-13 {
        right: 54.16667%; }
      .col-lg-pull-14 {
        right: 58.33333%; }
      .col-lg-pull-15 {
        right: 62.5%; }
      .col-lg-pull-16 {
        right: 66.66667%; }
      .col-lg-pull-17 {
        right: 70.83333%; }
      .col-lg-pull-18 {
        right: 75%; }
      .col-lg-pull-19 {
        right: 79.16667%; }
      .col-lg-pull-20 {
        right: 83.33333%; }
      .col-lg-pull-21 {
        right: 87.5%; }
      .col-lg-pull-22 {
        right: 91.66667%; }
      .col-lg-pull-23 {
        right: 95.83333%; }
      .col-lg-pull-24 {
        right: 100%; }
      .col-lg-push-0 {
        left: auto; }
      .col-lg-push-1 {
        left: 4.16667%; }
      .col-lg-push-2 {
        left: 8.33333%; }
      .col-lg-push-3 {
        left: 12.5%; }
      .col-lg-push-4 {
        left: 16.66667%; }
      .col-lg-push-5 {
        left: 20.83333%; }
      .col-lg-push-6 {
        left: 25%; }
      .col-lg-push-7 {
        left: 29.16667%; }
      .col-lg-push-8 {
        left: 33.33333%; }
      .col-lg-push-9 {
        left: 37.5%; }
      .col-lg-push-10 {
        left: 41.66667%; }
      .col-lg-push-11 {
        left: 45.83333%; }
      .col-lg-push-12 {
        left: 50%; }
      .col-lg-push-13 {
        left: 54.16667%; }
      .col-lg-push-14 {
        left: 58.33333%; }
      .col-lg-push-15 {
        left: 62.5%; }
      .col-lg-push-16 {
        left: 66.66667%; }
      .col-lg-push-17 {
        left: 70.83333%; }
      .col-lg-push-18 {
        left: 75%; }
      .col-lg-push-19 {
        left: 79.16667%; }
      .col-lg-push-20 {
        left: 83.33333%; }
      .col-lg-push-21 {
        left: 87.5%; }
      .col-lg-push-22 {
        left: 91.66667%; }
      .col-lg-push-23 {
        left: 95.83333%; }
      .col-lg-push-24 {
        left: 100%; }
      .col-lg-offset-0 {
        margin-left: 0%; }
      .col-lg-offset-1 {
        margin-left: 4.16667%; }
      .col-lg-offset-2 {
        margin-left: 8.33333%; }
      .col-lg-offset-3 {
        margin-left: 12.5%; }
      .col-lg-offset-4 {
        margin-left: 16.66667%; }
      .col-lg-offset-5 {
        margin-left: 20.83333%; }
      .col-lg-offset-6 {
        margin-left: 25%; }
      .col-lg-offset-7 {
        margin-left: 29.16667%; }
      .col-lg-offset-8 {
        margin-left: 33.33333%; }
      .col-lg-offset-9 {
        margin-left: 37.5%; }
      .col-lg-offset-10 {
        margin-left: 41.66667%; }
      .col-lg-offset-11 {
        margin-left: 45.83333%; }
      .col-lg-offset-12 {
        margin-left: 50%; }
      .col-lg-offset-13 {
        margin-left: 54.16667%; }
      .col-lg-offset-14 {
        margin-left: 58.33333%; }
      .col-lg-offset-15 {
        margin-left: 62.5%; }
      .col-lg-offset-16 {
        margin-left: 66.66667%; }
      .col-lg-offset-17 {
        margin-left: 70.83333%; }
      .col-lg-offset-18 {
        margin-left: 75%; }
      .col-lg-offset-19 {
        margin-left: 79.16667%; }
      .col-lg-offset-20 {
        margin-left: 83.33333%; }
      .col-lg-offset-21 {
        margin-left: 87.5%; }
      .col-lg-offset-22 {
        margin-left: 91.66667%; }
      .col-lg-offset-23 {
        margin-left: 95.83333%; }
      .col-lg-offset-24 {
        margin-left: 100%; } }
  @media (min-width: 1200px) {
  .col-xl-1, .col-xl-2, .col-xl-3, .col-xl-4, .col-xl-5, .col-xl-6, .col-xl-7, .col-xl-8, .col-xl-9, .col-xl-10, .col-xl-11, .col-xl-12, .col-xl-13, .col-xl-14, .col-xl-15, .col-xl-16, .col-xl-17, .col-xl-18, .col-xl-19, .col-xl-20, .col-xl-21, .col-xl-22, .col-xl-23, .col-xl-24 {
    float: left; }
    .col-xl-1 {
      width: 4.16667%; }

    .col-xl-2 {
      width: 8.33333%; }

    .col-xl-3 {
      width: 12.5%; }

    .col-xl-4 {
      width: 16.66667%; }

    .col-xl-5 {
      width: 20.83333%; }

    .col-xl-6 {
      width: 25%; }

    .col-xl-7 {
      width: 29.16667%; }

    .col-xl-8 {
      width: 33.33333%; }

    .col-xl-9 {
      width: 37.5%; }

    .col-xl-10 {
      width: 41.66667%; }

    .col-xl-11 {
      width: 45.83333%; }

    .col-xl-12 {
      width: 50%; }

    .col-xl-13 {
      width: 54.16667%; }

    .col-xl-14 {
      width: 58.33333%; }

    .col-xl-15 {
      width: 62.5%; }

    .col-xl-16 {
      width: 66.66667%; }

    .col-xl-17 {
      width: 70.83333%; }

    .col-xl-18 {
      width: 75%; }

    .col-xl-19 {
      width: 79.16667%; }

    .col-xl-20 {
      width: 83.33333%; }

    .col-xl-21 {
      width: 87.5%; }

    .col-xl-22 {
      width: 91.66667%; }

    .col-xl-23 {
      width: 95.83333%; }

    .col-xl-24 {
      width: 100%; }
      .col-xl-pull-0 {
        right: auto; }
      .col-xl-pull-1 {
        right: 4.16667%; }
      .col-xl-pull-2 {
        right: 8.33333%; }
      .col-xl-pull-3 {
        right: 12.5%; }
      .col-xl-pull-4 {
        right: 16.66667%; }
      .col-xl-pull-5 {
        right: 20.83333%; }
      .col-xl-pull-6 {
        right: 25%; }
      .col-xl-pull-7 {
        right: 29.16667%; }
      .col-xl-pull-8 {
        right: 33.33333%; }
      .col-xl-pull-9 {
        right: 37.5%; }
      .col-xl-pull-10 {
        right: 41.66667%; }
      .col-xl-pull-11 {
        right: 45.83333%; }
      .col-xl-pull-12 {
        right: 50%; }
      .col-xl-pull-13 {
        right: 54.16667%; }
      .col-xl-pull-14 {
        right: 58.33333%; }
      .col-xl-pull-15 {
        right: 62.5%; }
      .col-xl-pull-16 {
        right: 66.66667%; }
      .col-xl-pull-17 {
        right: 70.83333%; }
      .col-xl-pull-18 {
        right: 75%; }
      .col-xl-pull-19 {
        right: 79.16667%; }
      .col-xl-pull-20 {
        right: 83.33333%; }
      .col-xl-pull-21 {
        right: 87.5%; }
      .col-xl-pull-22 {
        right: 91.66667%; }
      .col-xl-pull-23 {
        right: 95.83333%; }
      .col-xl-pull-24 {
        right: 100%; }
      .col-xl-push-0 {
        left: auto; }
      .col-xl-push-1 {
        left: 4.16667%; }
      .col-xl-push-2 {
        left: 8.33333%; }
      .col-xl-push-3 {
        left: 12.5%; }
      .col-xl-push-4 {
        left: 16.66667%; }
      .col-xl-push-5 {
        left: 20.83333%; }
      .col-xl-push-6 {
        left: 25%; }
      .col-xl-push-7 {
        left: 29.16667%; }
      .col-xl-push-8 {
        left: 33.33333%; }
      .col-xl-push-9 {
        left: 37.5%; }
      .col-xl-push-10 {
        left: 41.66667%; }
      .col-xl-push-11 {
        left: 45.83333%; }
      .col-xl-push-12 {
        left: 50%; }
      .col-xl-push-13 {
        left: 54.16667%; }
      .col-xl-push-14 {
        left: 58.33333%; }
      .col-xl-push-15 {
        left: 62.5%; }
      .col-xl-push-16 {
        left: 66.66667%; }
      .col-xl-push-17 {
        left: 70.83333%; }
      .col-xl-push-18 {
        left: 75%; }
      .col-xl-push-19 {
        left: 79.16667%; }
      .col-xl-push-20 {
        left: 83.33333%; }
      .col-xl-push-21 {
        left: 87.5%; }
      .col-xl-push-22 {
        left: 91.66667%; }
      .col-xl-push-23 {
        left: 95.83333%; }
      .col-xl-push-24 {
        left: 100%; }
      .col-xl-offset-0 {
        margin-left: 0%; }
      .col-xl-offset-1 {
        margin-left: 4.16667%; }
      .col-xl-offset-2 {
        margin-left: 8.33333%; }
      .col-xl-offset-3 {
        margin-left: 12.5%; }
      .col-xl-offset-4 {
        margin-left: 16.66667%; }
      .col-xl-offset-5 {
        margin-left: 20.83333%; }
      .col-xl-offset-6 {
        margin-left: 25%; }
      .col-xl-offset-7 {
        margin-left: 29.16667%; }
      .col-xl-offset-8 {
        margin-left: 33.33333%; }
      .col-xl-offset-9 {
        margin-left: 37.5%; }
      .col-xl-offset-10 {
        margin-left: 41.66667%; }
      .col-xl-offset-11 {
        margin-left: 45.83333%; }
      .col-xl-offset-12 {
        margin-left: 50%; }
      .col-xl-offset-13 {
        margin-left: 54.16667%; }
      .col-xl-offset-14 {
        margin-left: 58.33333%; }
      .col-xl-offset-15 {
        margin-left: 62.5%; }
      .col-xl-offset-16 {
        margin-left: 66.66667%; }
      .col-xl-offset-17 {
        margin-left: 70.83333%; }
      .col-xl-offset-18 {
        margin-left: 75%; }
      .col-xl-offset-19 {
        margin-left: 79.16667%; }
      .col-xl-offset-20 {
        margin-left: 83.33333%; }
      .col-xl-offset-21 {
        margin-left: 87.5%; }
      .col-xl-offset-22 {
        margin-left: 91.66667%; }
      .col-xl-offset-23 {
        margin-left: 95.83333%; }
      .col-xl-offset-24 {
        margin-left: 100%; } }

.table {
  width: 100%;
  max-width: 100%;
  margin-bottom: 1rem; }
  .table th, .table td {
    padding: 0.75rem;
    line-height: 1.5;
    vertical-align: top;
    border-top: 1px solid #eceeef; }
  .table thead th {
    vertical-align: bottom;
    border-bottom: 2px solid #eceeef; }
  .table tbody + tbody {
    border-top: 2px solid #eceeef; }
  .table .table {
    background-color: #f1f2f3; }

.table-sm th, .table-sm td {
  padding: 0.3rem; }

.table-bordered {
  border: 1px solid #eceeef; }
  .table-bordered th, .table-bordered td {
    border: 1px solid #eceeef; }
  .table-bordered thead th, .table-bordered thead td {
    border-bottom-width: 2px; }

.table-striped tbody tr:nth-of-type(odd) {
  background-color: #f9f9f9; }

.table-hover tbody tr:hover {
  background-color: #f5f5f5; }

.table-active, .table-active > th, .table-active > td {
  background-color: #f5f5f5; }

.table-hover .table-active:hover {
  background-color: #e8e8e8; }
  .table-hover .table-active:hover > td, .table-hover .table-active:hover > th {
    background-color: #e8e8e8; }

.table-success, .table-success > th, .table-success > td {
  background-color: #24ce7b; }

.table-hover .table-success:hover {
  background-color: #20b86e; }
  .table-hover .table-success:hover > td, .table-hover .table-success:hover > th {
    background-color: #20b86e; }

.table-info, .table-info > th, .table-info > td {
  background-color: #38b5e6; }

.table-hover .table-info:hover {
  background-color: #21ade3; }
  .table-hover .table-info:hover > td, .table-hover .table-info:hover > th {
    background-color: #21ade3; }

.table-warning, .table-warning > th, .table-warning > td {
  background-color: #f48714; }

.table-hover .table-warning:hover {
  background-color: #e47a0b; }
  .table-hover .table-warning:hover > td, .table-hover .table-warning:hover > th {
    background-color: #e47a0b; }

.table-danger, .table-danger > th, .table-danger > td {
  background-color: #f6303e; }

.table-hover .table-danger:hover {
  background-color: #f51827; }
  .table-hover .table-danger:hover > td, .table-hover .table-danger:hover > th {
    background-color: #f51827; }

.table-responsive {
  display: block;
  width: 100%;
  min-height: 0.01%;
  overflow-x: auto; }

.thead-inverse th {
  color: #fff;
  background-color: #353535; }

.thead-default th {
  color: #3e3e3e;
  background-color: #eceeef; }

.table-inverse {
  color: #eceeef;
  background-color: #353535; }
  .table-inverse.table-bordered {
    border: 0; }
  .table-inverse th, .table-inverse td, .table-inverse thead th {
    border-color: #3e3e3e; }

.table-reflow thead {
  float: left; }
  .table-reflow tbody {
    display: block;
    white-space: nowrap; }
  .table-reflow th, .table-reflow td {
    border-top: 1px solid #eceeef;
    border-left: 1px solid #eceeef; }
  .table-reflow th:last-child, .table-reflow td:last-child {
    border-right: 1px solid #eceeef; }
  .table-reflow thead:last-child tr:last-child th, .table-reflow tbody:last-child tr:last-child th, .table-reflow tfoot:last-child tr:last-child th, .table-reflow thead:last-child tr:last-child td, .table-reflow tbody:last-child tr:last-child td, .table-reflow tfoot:last-child tr:last-child td {
    border-bottom: 1px solid #eceeef; }
  .table-reflow tr {
    float: left; }
  .table-reflow tr th, .table-reflow tr td {
    display: block !important;
    border: 1px solid #eceeef; }

.form-control {
  display: block;
  width: 100%;
  padding: 0.375rem 0.75rem;
  font-size: 1rem;
  line-height: 1.5;
  color: #3e3e3e;
  background-color: #fff;
  background-image: none;
  border: 1px solid #ccc;
  border-radius: 0; }
  .form-control::-ms-expand {
    background-color: transparent;
    border: 0; }
  .form-control:focus {
    border-color: #38b5e6;
    outline: none; }
  .form-control::placeholder {
    color: #999;
    opacity: 1; }
  .form-control:disabled, .form-control[readonly] {
    background-color: #eceeef;
    opacity: 1; }
  .form-control:disabled {
    cursor: not-allowed; }

.form-control-file, .form-control-range {
  display: block; }

.form-control-label {
  padding: 0.375rem 0.75rem;
  margin-bottom: 0; }

@media screen and (-webkit-min-device-pixel-ratio: 0) {
  input[type="date"].form-control, input[type="time"].form-control, input[type="datetime-local"].form-control, input[type="month"].form-control {
    line-height: 2.25rem; }
    input[type="date"].input-sm, input[type="time"].input-sm, input[type="datetime-local"].input-sm, input[type="month"].input-sm, .input-group-sm input[type="date"].form-control, .input-group-sm input[type="time"].form-control, .input-group-sm input[type="datetime-local"].form-control, .input-group-sm input[type="month"].form-control {
      line-height: 1.8625rem; }
    input[type="date"].input-lg, input[type="time"].input-lg, input[type="datetime-local"].input-lg, input[type="month"].input-lg, .input-group-lg input[type="date"].form-control, .input-group-lg input[type="time"].form-control, .input-group-lg input[type="datetime-local"].form-control, .input-group-lg input[type="month"].form-control {
      line-height: 3.16667rem; } }

.form-control-static {
  min-height: 2.25rem;
  padding-top: 0.375rem;
  padding-bottom: 0.375rem;
  margin-bottom: 0; }
  .form-control-static.form-control-sm, .input-group-sm > .form-control.form-control-static, .input-group-sm > .input-group-addon.form-control-static, .input-group-sm > .input-group-btn > .btn.form-control-static, .form-control-static.form-control-lg, .input-group-lg > .form-control.form-control-static, .input-group-lg > .input-group-addon.form-control-static, .input-group-lg > .input-group-btn > .btn.form-control-static {
    padding-right: 0;
    padding-left: 0; }

.form-control-sm, .input-group-sm > .form-control, .input-group-sm > .input-group-addon, .input-group-sm > .input-group-btn > .btn {
  padding: 0.275rem 0.75rem;
  font-size: 0.875rem;
  line-height: 1.5;
  border-radius: 0; }

.form-control-lg, .input-group-lg > .form-control, .input-group-lg > .input-group-addon, .input-group-lg > .input-group-btn > .btn {
  padding: 0.75rem 1.25rem;
  font-size: 1.25rem;
  line-height: 1.33333;
  border-radius: 0; }

.form-group {
  margin-bottom: 1rem; }

.radio, .checkbox {
  position: relative;
  display: block;
  margin-bottom: 0.75rem; }
  .radio label, .checkbox label {
    padding-left: 1.25rem;
    margin-bottom: 0;
    font-weight: normal;
    cursor: pointer; }
  .radio label input:only-child, .checkbox label input:only-child {
    position: static; }

.radio input[type="radio"], .radio-inline input[type="radio"], .checkbox input[type="checkbox"], .checkbox-inline input[type="checkbox"] {
  position: absolute;
  margin-top: 0.25rem;
  margin-left: -1.25rem; }

.radio + .radio, .checkbox + .checkbox {
  margin-top: -0.25rem; }

.radio-inline, .checkbox-inline {
  position: relative;
  display: inline-block;
  padding-left: 1.25rem;
  margin-bottom: 0;
  font-weight: normal;
  vertical-align: middle;
  cursor: pointer; }

.radio-inline + .radio-inline, .checkbox-inline + .checkbox-inline {
  margin-top: 0;
  margin-left: 0.75rem; }

input[type="radio"]:disabled, input[type="checkbox"]:disabled, input[type="radio"].disabled, input[type="checkbox"].disabled {
  cursor: not-allowed; }

.radio-inline.disabled, .checkbox-inline.disabled {
  cursor: not-allowed; }

.radio.disabled label, .checkbox.disabled label {
  cursor: not-allowed; }

.form-control-success, .form-control-warning, .form-control-danger {
  padding-right: 2.25rem;
  background-repeat: no-repeat;
  background-position: center right 0.5625rem;
  background-size: 1.4625rem 1.4625rem; }

.has-success .text-help, .has-success .form-control-label, .has-success .radio, .has-success .checkbox, .has-success .radio-inline, .has-success .checkbox-inline, .has-success.radio label, .has-success.checkbox label, .has-success.radio-inline label, .has-success.checkbox-inline label {
  color: #24ce7b; }
  .has-success .form-control {
    border-color: #24ce7b; }
  .has-success .input-group-addon {
    color: #24ce7b;
    border-color: #24ce7b;
    background-color: #c9f5e0; }
  .has-success .form-control-feedback {
    color: #24ce7b; }
  .has-success .form-control-success {
    background-image: url("data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHZpZXdCb3g9IjAgMCA2MTIgNzkyIj48cGF0aCBmaWxsPSIjNWNiODVjIiBkPSJNMjMzLjggNjEwYy0xMy4zIDAtMjYtNi0zNC0xNi44TDkwLjUgNDQ4LjhDNzYuMyA0MzAgODAgNDAzLjMgOTguOCAzODljMTguOC0xNC4yIDQ1LjUtMTAuNCA1OS44IDguNGw3MiA5NUw0NTEuMyAyNDJjMTIuNS0yMCAzOC44LTI2LjIgNTguOC0xMy43IDIwIDEyLjQgMjYgMzguNyAxMy43IDU4LjhMMjcwIDU5MGMtNy40IDEyLTIwLjIgMTkuNC0zNC4zIDIwaC0yeiIvPjwvc3ZnPg=="); }

.has-warning .text-help, .has-warning .form-control-label, .has-warning .radio, .has-warning .checkbox, .has-warning .radio-inline, .has-warning .checkbox-inline, .has-warning.radio label, .has-warning.checkbox label, .has-warning.radio-inline label, .has-warning.checkbox-inline label {
  color: #f48714; }
  .has-warning .form-control {
    border-color: #f48714; }
  .has-warning .input-group-addon {
    color: #f48714;
    border-color: #f48714;
    background-color: #fdebd7; }
  .has-warning .form-control-feedback {
    color: #f48714; }
  .has-warning .form-control-warning {
    background-image: url("data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHZpZXdCb3g9IjAgMCA2MTIgNzkyIj48cGF0aCBmaWxsPSIjZjBhZDRlIiBkPSJNNjAzIDY0MC4ybC0yNzguNS01MDljLTMuOC02LjYtMTAuOC0xMC42LTE4LjUtMTAuNnMtMTQuNyA0LTE4LjUgMTAuNkw5IDY0MC4yYy0zLjcgNi41LTMuNiAxNC40LjIgMjAuOCAzLjggNi41IDEwLjggMTAuNCAxOC4zIDEwLjRoNTU3YzcuNiAwIDE0LjYtNCAxOC40LTEwLjQgMy41LTYuNCAzLjYtMTQuNCAwLTIwLjh6bS0yNjYuNC0zMGgtNjEuMlY1NDloNjEuMnY2MS4yem0wLTEwN2gtNjEuMlYzMDRoNjEuMnYxOTl6Ii8+PC9zdmc+"); }

.has-danger .text-help, .has-danger .form-control-label, .has-danger .radio, .has-danger .checkbox, .has-danger .radio-inline, .has-danger .checkbox-inline, .has-danger.radio label, .has-danger.checkbox label, .has-danger.radio-inline label, .has-danger.checkbox-inline label {
  color: #f6303e; }
  .has-danger .form-control {
    border-color: #f6303e; }
  .has-danger .input-group-addon {
    color: #f6303e;
    border-color: #f6303e;
    background-color: #fff4f4; }
  .has-danger .form-control-feedback {
    color: #f6303e; }
  .has-danger .form-control-danger {
    background-image: url("data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHZpZXdCb3g9IjAgMCA2MTIgNzkyIj48cGF0aCBmaWxsPSIjZDk1MzRmIiBkPSJNNDQ3IDU0NC40Yy0xNC40IDE0LjQtMzcuNiAxNC40LTUyIDBsLTg5LTkyLjctODkgOTIuN2MtMTQuNSAxNC40LTM3LjcgMTQuNC01MiAwLTE0LjQtMTQuNC0xNC40LTM3LjYgMC01Mmw5Mi40LTk2LjMtOTIuNC05Ni4zYy0xNC40LTE0LjQtMTQuNC0zNy42IDAtNTJzMzcuNi0xNC4zIDUyIDBsODkgOTIuOCA4OS4yLTkyLjdjMTQuNC0xNC40IDM3LjYtMTQuNCA1MiAwIDE0LjMgMTQuNCAxNC4zIDM3LjYgMCA1MkwzNTQuNiAzOTZsOTIuNCA5Ni40YzE0LjQgMTQuNCAxNC40IDM3LjYgMCA1MnoiLz48L3N2Zz4="); }

@media (min-width: 544px) {
    .form-inline .form-group {
      display: inline-block;
      margin-bottom: 0;
      vertical-align: middle; }
      .form-inline .form-control {
        display: inline-block;
        width: auto;
        vertical-align: middle; }
      .form-inline .form-control-static {
        display: inline-block; }
      .form-inline .input-group {
        display: inline-table;
        vertical-align: middle; }
        .form-inline .input-group .input-group-addon, .form-inline .input-group .input-group-btn, .form-inline .input-group .form-control {
          width: auto; }
      .form-inline .input-group > .form-control {
        width: 100%; }
      .form-inline .form-control-label {
        margin-bottom: 0;
        vertical-align: middle; }
      .form-inline .radio, .form-inline .checkbox {
        display: inline-block;
        margin-top: 0;
        margin-bottom: 0;
        vertical-align: middle; }
        .form-inline .radio label, .form-inline .checkbox label {
          padding-left: 0; }
      .form-inline .radio input[type="radio"], .form-inline .checkbox input[type="checkbox"] {
        position: relative;
        margin-left: 0; }
      .form-inline .has-feedback .form-control-feedback {
        top: 0; } }

.btn {
  display: inline-block;
  font-weight: normal;
  text-align: center;
  white-space: nowrap;
  vertical-align: middle;
  cursor: pointer;
  user-select: none;
  border: 1px solid transparent;
  padding: 0.375rem 1rem;
  font-size: 1rem;
  line-height: 1.5;
  border-radius: 0; }
  .btn:focus, .btn:active:focus, .btn.active:focus, .btn.focus, .btn:active.focus, .btn.active.focus {
    outline: thin dotted;
    outline: 5px auto -webkit-focus-ring-color;
    outline-offset: -2px; }
  .btn:focus, .btn:hover {
    text-decoration: none; }
  .btn.focus {
    text-decoration: none; }
  .btn:active, .btn.active {
    background-image: none;
    outline: 0; }
  .btn.disabled, .btn:disabled {
    cursor: not-allowed;
    opacity: 0.65; }

a.btn.disabled, fieldset[disabled] a.btn {
  pointer-events: none; }

.btn-primary {
  color: #fff;
  background-color: #61259e;
  border-color: #61259e; }
  .btn-primary:hover {
    color: #fff;
    background-color: #481b75;
    border-color: #43196c; }
  .btn-primary:focus, .btn-primary.focus {
    color: #fff;
    background-color: #481b75;
    border-color: #43196c; }
  .btn-primary:active, .btn-primary.active, .open > .btn-primary.dropdown-toggle {
    color: #fff;
    background-color: #481b75;
    border-color: #43196c;
    background-image: none; }
  .btn-primary:active:hover, .btn-primary.active:hover, .open > .btn-primary.dropdown-toggle:hover, .btn-primary:active:focus, .btn-primary.active:focus, .open > .btn-primary.dropdown-toggle:focus, .btn-primary:active.focus, .btn-primary.active.focus, .open > .btn-primary.dropdown-toggle.focus {
    color: #fff;
    background-color: #361558;
    border-color: #220d37; }
  .btn-primary.disabled:focus, .btn-primary:disabled:focus, .btn-primary.disabled.focus, .btn-primary:disabled.focus {
    background-color: #61259e;
    border-color: #61259e; }
  .btn-primary.disabled:hover, .btn-primary:disabled:hover {
    background-color: #61259e;
    border-color: #61259e; }

.btn-secondary {
  color: #353535;
  background-color: #fff;
  border-color: #6f6f6f; }
  .btn-secondary:hover {
    color: #353535;
    background-color: #e6e6e6;
    border-color: #505050; }
  .btn-secondary:focus, .btn-secondary.focus {
    color: #353535;
    background-color: #e6e6e6;
    border-color: #505050; }
  .btn-secondary:active, .btn-secondary.active, .open > .btn-secondary.dropdown-toggle {
    color: #353535;
    background-color: #e6e6e6;
    border-color: #505050;
    background-image: none; }
  .btn-secondary:active:hover, .btn-secondary.active:hover, .open > .btn-secondary.dropdown-toggle:hover, .btn-secondary:active:focus, .btn-secondary.active:focus, .open > .btn-secondary.dropdown-toggle:focus, .btn-secondary:active.focus, .btn-secondary.active.focus, .open > .btn-secondary.dropdown-toggle.focus {
    color: #353535;
    background-color: #d4d4d4;
    border-color: #2f2f2f; }
  .btn-secondary.disabled:focus, .btn-secondary:disabled:focus, .btn-secondary.disabled.focus, .btn-secondary:disabled.focus {
    background-color: #fff;
    border-color: #6f6f6f; }
  .btn-secondary.disabled:hover, .btn-secondary:disabled:hover {
    background-color: #fff;
    border-color: #6f6f6f; }

.btn-info {
  color: #fff;
  background-color: #38b5e6;
  border-color: #38b5e6; }
  .btn-info:hover {
    color: #fff;
    background-color: #1a9dd1;
    border-color: #1997c8; }
  .btn-info:focus, .btn-info.focus {
    color: #fff;
    background-color: #1a9dd1;
    border-color: #1997c8; }
  .btn-info:active, .btn-info.active, .open > .btn-info.dropdown-toggle {
    color: #fff;
    background-color: #1a9dd1;
    border-color: #1997c8;
    background-image: none; }
  .btn-info:active:hover, .btn-info.active:hover, .open > .btn-info.dropdown-toggle:hover, .btn-info:active:focus, .btn-info.active:focus, .open > .btn-info.dropdown-toggle:focus, .btn-info:active.focus, .btn-info.active.focus, .open > .btn-info.dropdown-toggle.focus {
    color: #fff;
    background-color: #1685b1;
    border-color: #126a8d; }
  .btn-info.disabled:focus, .btn-info:disabled:focus, .btn-info.disabled.focus, .btn-info:disabled.focus {
    background-color: #38b5e6;
    border-color: #38b5e6; }
  .btn-info.disabled:hover, .btn-info:disabled:hover {
    background-color: #38b5e6;
    border-color: #38b5e6; }

.btn-success {
  color: #fff;
  background-color: #24ce7b;
  border-color: #24ce7b; }
  .btn-success:hover {
    color: #fff;
    background-color: #1ca361;
    border-color: #1b9a5c; }
  .btn-success:focus, .btn-success.focus {
    color: #fff;
    background-color: #1ca361;
    border-color: #1b9a5c; }
  .btn-success:active, .btn-success.active, .open > .btn-success.dropdown-toggle {
    color: #fff;
    background-color: #1ca361;
    border-color: #1b9a5c;
    background-image: none; }
  .btn-success:active:hover, .btn-success.active:hover, .open > .btn-success.dropdown-toggle:hover, .btn-success:active:focus, .btn-success.active:focus, .open > .btn-success.dropdown-toggle:focus, .btn-success:active.focus, .btn-success.active.focus, .open > .btn-success.dropdown-toggle.focus {
    color: #fff;
    background-color: #17844f;
    border-color: #11613a; }
  .btn-success.disabled:focus, .btn-success:disabled:focus, .btn-success.disabled.focus, .btn-success:disabled.focus {
    background-color: #24ce7b;
    border-color: #24ce7b; }
  .btn-success.disabled:hover, .btn-success:disabled:hover {
    background-color: #24ce7b;
    border-color: #24ce7b; }

.btn-warning {
  color: #fff;
  background-color: #f48714;
  border-color: #f48714; }
  .btn-warning:hover {
    color: #fff;
    background-color: #cb6d0a;
    border-color: #c26809; }
  .btn-warning:focus, .btn-warning.focus {
    color: #fff;
    background-color: #cb6d0a;
    border-color: #c26809; }
  .btn-warning:active, .btn-warning.active, .open > .btn-warning.dropdown-toggle {
    color: #fff;
    background-color: #cb6d0a;
    border-color: #c26809;
    background-image: none; }
  .btn-warning:active:hover, .btn-warning.active:hover, .open > .btn-warning.dropdown-toggle:hover, .btn-warning:active:focus, .btn-warning.active:focus, .open > .btn-warning.dropdown-toggle:focus, .btn-warning:active.focus, .btn-warning.active.focus, .open > .btn-warning.dropdown-toggle.focus {
    color: #fff;
    background-color: #a95b08;
    border-color: #824606; }
  .btn-warning.disabled:focus, .btn-warning:disabled:focus, .btn-warning.disabled.focus, .btn-warning:disabled.focus {
    background-color: #f48714;
    border-color: #f48714; }
  .btn-warning.disabled:hover, .btn-warning:disabled:hover {
    background-color: #f48714;
    border-color: #f48714; }

.btn-danger {
  color: #fff;
  background-color: #f6303e;
  border-color: #f6303e; }
  .btn-danger:hover {
    color: #fff;
    background-color: #e90a1a;
    border-color: #df0a19; }
  .btn-danger:focus, .btn-danger.focus {
    color: #fff;
    background-color: #e90a1a;
    border-color: #df0a19; }
  .btn-danger:active, .btn-danger.active, .open > .btn-danger.dropdown-toggle {
    color: #fff;
    background-color: #e90a1a;
    border-color: #df0a19;
    background-image: none; }
  .btn-danger:active:hover, .btn-danger.active:hover, .open > .btn-danger.dropdown-toggle:hover, .btn-danger:active:focus, .btn-danger.active:focus, .open > .btn-danger.dropdown-toggle:focus, .btn-danger:active.focus, .btn-danger.active.focus, .open > .btn-danger.dropdown-toggle.focus {
    color: #fff;
    background-color: #c70916;
    border-color: #a00712; }
  .btn-danger.disabled:focus, .btn-danger:disabled:focus, .btn-danger.disabled.focus, .btn-danger:disabled.focus {
    background-color: #f6303e;
    border-color: #f6303e; }
  .btn-danger.disabled:hover, .btn-danger:disabled:hover {
    background-color: #f6303e;
    border-color: #f6303e; }

.btn-primary-outline {
  color: #61259e;
  background-image: none;
  background-color: transparent;
  border-color: #61259e; }
  .btn-primary-outline:focus, .btn-primary-outline.focus, .btn-primary-outline:active, .btn-primary-outline.active, .open > .btn-primary-outline.dropdown-toggle {
    color: #fff;
    background-color: #61259e;
    border-color: #61259e; }
  .btn-primary-outline:hover {
    color: #fff;
    background-color: #61259e;
    border-color: #61259e; }
  .btn-primary-outline.disabled:focus, .btn-primary-outline:disabled:focus, .btn-primary-outline.disabled.focus, .btn-primary-outline:disabled.focus {
    border-color: #9452d7; }
  .btn-primary-outline.disabled:hover, .btn-primary-outline:disabled:hover {
    border-color: #9452d7; }

.btn-secondary-outline {
  color: #6f6f6f;
  background-image: none;
  background-color: transparent;
  border-color: #6f6f6f; }
  .btn-secondary-outline:focus, .btn-secondary-outline.focus, .btn-secondary-outline:active, .btn-secondary-outline.active, .open > .btn-secondary-outline.dropdown-toggle {
    color: #fff;
    background-color: #6f6f6f;
    border-color: #6f6f6f; }
  .btn-secondary-outline:hover {
    color: #fff;
    background-color: #6f6f6f;
    border-color: #6f6f6f; }
  .btn-secondary-outline.disabled:focus, .btn-secondary-outline:disabled:focus, .btn-secondary-outline.disabled.focus, .btn-secondary-outline:disabled.focus {
    border-color: #a2a2a2; }
  .btn-secondary-outline.disabled:hover, .btn-secondary-outline:disabled:hover {
    border-color: #a2a2a2; }

.btn-info-outline {
  color: #38b5e6;
  background-image: none;
  background-color: transparent;
  border-color: #38b5e6; }
  .btn-info-outline:focus, .btn-info-outline.focus, .btn-info-outline:active, .btn-info-outline.active, .open > .btn-info-outline.dropdown-toggle {
    color: #fff;
    background-color: #38b5e6;
    border-color: #38b5e6; }
  .btn-info-outline:hover {
    color: #fff;
    background-color: #38b5e6;
    border-color: #38b5e6; }
  .btn-info-outline.disabled:focus, .btn-info-outline:disabled:focus, .btn-info-outline.disabled.focus, .btn-info-outline:disabled.focus {
    border-color: #93d7f1; }
  .btn-info-outline.disabled:hover, .btn-info-outline:disabled:hover {
    border-color: #93d7f1; }

.btn-success-outline {
  color: #24ce7b;
  background-image: none;
  background-color: transparent;
  border-color: #24ce7b; }
  .btn-success-outline:focus, .btn-success-outline.focus, .btn-success-outline:active, .btn-success-outline.active, .open > .btn-success-outline.dropdown-toggle {
    color: #fff;
    background-color: #24ce7b;
    border-color: #24ce7b; }
  .btn-success-outline:hover {
    color: #fff;
    background-color: #24ce7b;
    border-color: #24ce7b; }
  .btn-success-outline.disabled:focus, .btn-success-outline:disabled:focus, .btn-success-outline.disabled.focus, .btn-success-outline:disabled.focus {
    border-color: #72e6ad; }
  .btn-success-outline.disabled:hover, .btn-success-outline:disabled:hover {
    border-color: #72e6ad; }

.btn-warning-outline {
  color: #f48714;
  background-image: none;
  background-color: transparent;
  border-color: #f48714; }
  .btn-warning-outline:focus, .btn-warning-outline.focus, .btn-warning-outline:active, .btn-warning-outline.active, .open > .btn-warning-outline.dropdown-toggle {
    color: #fff;
    background-color: #f48714;
    border-color: #f48714; }
  .btn-warning-outline:hover {
    color: #fff;
    background-color: #f48714;
    border-color: #f48714; }
  .btn-warning-outline.disabled:focus, .btn-warning-outline:disabled:focus, .btn-warning-outline.disabled.focus, .btn-warning-outline:disabled.focus {
    border-color: #f9b975; }
  .btn-warning-outline.disabled:hover, .btn-warning-outline:disabled:hover {
    border-color: #f9b975; }

.btn-danger-outline {
  color: #f6303e;
  background-image: none;
  background-color: transparent;
  border-color: #f6303e; }
  .btn-danger-outline:focus, .btn-danger-outline.focus, .btn-danger-outline:active, .btn-danger-outline.active, .open > .btn-danger-outline.dropdown-toggle {
    color: #fff;
    background-color: #f6303e;
    border-color: #f6303e; }
  .btn-danger-outline:hover {
    color: #fff;
    background-color: #f6303e;
    border-color: #f6303e; }
  .btn-danger-outline.disabled:focus, .btn-danger-outline:disabled:focus, .btn-danger-outline.disabled.focus, .btn-danger-outline:disabled.focus {
    border-color: #fa9299; }
  .btn-danger-outline.disabled:hover, .btn-danger-outline:disabled:hover {
    border-color: #fa9299; }

.btn-link {
  font-weight: normal;
  color: #38b5e6;
  border-radius: 0; }
  .btn-link, .btn-link:active, .btn-link.active, .btn-link:disabled {
    background-color: transparent; }
  .btn-link, .btn-link:focus, .btn-link:active {
    border-color: transparent; }
  .btn-link:hover {
    border-color: transparent; }
  .btn-link:focus, .btn-link:hover {
    color: #21ade3;
    text-decoration: underline;
    background-color: transparent; }
  .btn-link:disabled:focus, .btn-link:disabled:hover {
    color: #818a91;
    text-decoration: none; }

.btn-lg, .btn-group-lg > .btn {
  padding: 0.75rem 1.25rem;
  font-size: 1.25rem;
  line-height: 1.33333;
  border-radius: 0; }

.btn-sm, .btn-group-sm > .btn {
  padding: 0.25rem 0.75rem;
  font-size: 0.875rem;
  line-height: 1.5;
  border-radius: 0; }

.btn-block {
  display: block;
  width: 100%; }

.btn-block + .btn-block {
  margin-top: 5px; }

input[type="submit"].btn-block, input[type="reset"].btn-block, input[type="button"].btn-block {
  width: 100%; }

.fade {
  opacity: 0;
  transition: opacity 0.15s linear; }
  .fade.in {
    opacity: 1; }

.collapse {
  display: none; }
  .collapse.in {
    display: block; }

.collapsing {
  position: relative;
  height: 0;
  overflow: hidden;
  transition-timing-function: ease;
  transition-duration: 0.35s;
  transition-property: height; }

.dropup, .dropdown {
  position: relative; }

.dropdown-toggle::after {
  display: inline-block;
  width: 0;
  height: 0;
  margin-right: 0.25rem;
  margin-left: 0.25rem;
  vertical-align: middle;
  content: "";
  border-top: 0.3em solid;
  border-right: 0.3em solid transparent;
  border-left: 0.3em solid transparent; }
  .dropdown-toggle:focus {
    outline: 0; }

.dropup .dropdown-toggle::after {
  border-top: 0;
  border-bottom: 0.3em solid; }

.dropdown-menu {
  position: absolute;
  top: 100%;
  left: 0;
  z-index: 1000;
  display: none;
  float: left;
  min-width: 160px;
  padding: 5px 0;
  margin: 2px 0 0;
  font-size: 1rem;
  color: #353535;
  text-align: left;
  list-style: none;
  background-color: #fff;
  background-clip: padding-box;
  border: 1px solid rgba(0, 0, 0, .15);
  border-radius: 0; }

.dropdown-divider {
  height: 1px;
  margin: 0.5rem 0;
  overflow: hidden;
  background-color: #e5e5e5; }

.dropdown-item {
  display: block;
  width: 100%;
  padding: 3px 20px;
  clear: both;
  font-weight: normal;
  line-height: 1.5;
  color: #353535;
  text-align: inherit;
  white-space: nowrap;
  background: none;
  border: 0; }
  .dropdown-item:focus, .dropdown-item:hover {
    color: #353535;
    text-decoration: none;
    background-color: #f5f5f5; }
  .dropdown-item.active, .dropdown-item.active:focus, .dropdown-item.active:hover {
    color: #fff;
    text-decoration: none;
    background-color: #61259e;
    outline: 0; }
  .dropdown-item.disabled, .dropdown-item.disabled:focus, .dropdown-item.disabled:hover {
    color: #818a91; }
  .dropdown-item.disabled:focus, .dropdown-item.disabled:hover {
    text-decoration: none;
    cursor: not-allowed;
    background-color: transparent;
    background-image: none;
    filter: "progid:DXImageTransform.Microsoft.gradient(enabled = false)"; }

.open > .dropdown-menu {
  display: block; }
  .open > a {
    outline: 0; }

.dropdown-menu-right {
  right: 0;
  left: auto; }

.dropdown-menu-left {
  right: auto;
  left: 0; }

.dropdown-header {
  display: block;
  padding: 3px 20px;
  font-size: 0.875rem;
  line-height: 1.5;
  color: #818a91;
  white-space: nowrap; }

.dropdown-backdrop {
  position: fixed;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
  z-index: 990; }

.pull-right > .dropdown-menu {
  right: 0;
  left: auto; }

.dropup .caret, .navbar-fixed-bottom .dropdown .caret {
  content: "";
  border-top: 0;
  border-bottom: 0.3em solid; }
  .dropup .dropdown-menu, .navbar-fixed-bottom .dropdown .dropdown-menu {
    top: auto;
    bottom: 100%;
    margin-bottom: 2px; }

.btn-group, .btn-group-vertical {
  position: relative;
  display: inline-block;
  vertical-align: middle; }
  .btn-group > .btn, .btn-group-vertical > .btn {
    position: relative;
    float: left; }
  .btn-group > .btn:focus, .btn-group-vertical > .btn:focus, .btn-group > .btn:active, .btn-group-vertical > .btn:active, .btn-group > .btn.active, .btn-group-vertical > .btn.active {
    z-index: 2; }
  .btn-group > .btn:hover, .btn-group-vertical > .btn:hover {
    z-index: 2; }

.btn-group .btn + .btn, .btn-group .btn + .btn-group, .btn-group .btn-group + .btn, .btn-group .btn-group + .btn-group {
  margin-left: -1px; }

.btn-toolbar {
  margin-left: -5px; }
  .btn-toolbar::after {
    content: "";
    display: table;
    clear: both; }
  .btn-toolbar .btn-group, .btn-toolbar .input-group {
    float: left; }
  .btn-toolbar > .btn, .btn-toolbar > .btn-group, .btn-toolbar > .input-group {
    margin-left: 5px; }

.btn-group > .btn:not(:first-child):not(:last-child):not(.dropdown-toggle) {
  border-radius: 0; }

.btn-group > .btn:first-child {
  margin-left: 0; }
  .btn-group > .btn:first-child:not(:last-child):not(.dropdown-toggle) {
    border-bottom-right-radius: 0;
    border-top-right-radius: 0; }

.btn-group > .btn:last-child:not(:first-child), .btn-group > .dropdown-toggle:not(:first-child) {
  border-bottom-left-radius: 0;
  border-top-left-radius: 0; }

.btn-group > .btn-group {
  float: left; }

.btn-group > .btn-group:not(:first-child):not(:last-child) > .btn {
  border-radius: 0; }

.btn-group > .btn-group:first-child:not(:last-child) > .btn:last-child, .btn-group > .btn-group:first-child:not(:last-child) > .dropdown-toggle {
  border-bottom-right-radius: 0;
  border-top-right-radius: 0; }

.btn-group > .btn-group:last-child:not(:first-child) > .btn:first-child {
  border-bottom-left-radius: 0;
  border-top-left-radius: 0; }

.btn-group .dropdown-toggle:active, .btn-group.open .dropdown-toggle {
  outline: 0; }

.btn-group > .btn + .dropdown-toggle {
  padding-right: 8px;
  padding-left: 8px; }

.btn-group > .btn-lg + .dropdown-toggle, .btn-group > .btn-group-lg > .btn + .dropdown-toggle, .btn-group-lg > .btn-group > .btn + .dropdown-toggle {
  padding-right: 12px;
  padding-left: 12px; }

.btn .caret {
  margin-left: 0; }

.btn-lg .caret, .btn-group-lg > .btn .caret {
  border-width: 0.3em 0.3em 0;
  border-bottom-width: 0; }

.dropup .btn-lg .caret, .dropup .btn-group-lg > .btn .caret, .btn-group-lg > .dropup .btn .caret {
  border-width: 0 0.3em 0.3em; }

.btn-group-vertical > .btn, .btn-group-vertical > .btn-group, .btn-group-vertical > .btn-group > .btn {
  display: block;
  float: none;
  width: 100%;
  max-width: 100%; }
  .btn-group-vertical > .btn-group::after {
    content: "";
    display: table;
    clear: both; }
  .btn-group-vertical > .btn-group > .btn {
    float: none; }
  .btn-group-vertical > .btn + .btn, .btn-group-vertical > .btn + .btn-group, .btn-group-vertical > .btn-group + .btn, .btn-group-vertical > .btn-group + .btn-group {
    margin-top: -1px;
    margin-left: 0; }

.btn-group-vertical > .btn:not(:first-child):not(:last-child) {
  border-radius: 0; }
  .btn-group-vertical > .btn:first-child:not(:last-child) {
    border-top-right-radius: 0;
    border-bottom-right-radius: 0;
    border-bottom-left-radius: 0; }
  .btn-group-vertical > .btn:last-child:not(:first-child) {
    border-bottom-left-radius: 0;
    border-top-right-radius: 0;
    border-top-left-radius: 0; }

.btn-group-vertical > .btn-group:not(:first-child):not(:last-child) > .btn {
  border-radius: 0; }

.btn-group-vertical > .btn-group:first-child:not(:last-child) > .btn:last-child, .btn-group-vertical > .btn-group:first-child:not(:last-child) > .dropdown-toggle {
  border-bottom-right-radius: 0;
  border-bottom-left-radius: 0; }

.btn-group-vertical > .btn-group:last-child:not(:first-child) > .btn:first-child {
  border-top-right-radius: 0;
  border-top-left-radius: 0; }

[data-toggle="buttons"] > .btn input[type="radio"], [data-toggle="buttons"] > .btn-group > .btn input[type="radio"], [data-toggle="buttons"] > .btn input[type="checkbox"], [data-toggle="buttons"] > .btn-group > .btn input[type="checkbox"] {
  position: absolute;
  clip: rect(0, 0, 0, 0);
  pointer-events: none; }

.input-group {
  position: relative;
  display: table;
  border-collapse: separate; }
  .input-group .form-control {
    position: relative;
    z-index: 2;
    float: left;
    width: 100%;
    margin-bottom: 0; }
  .input-group .form-control:focus, .input-group .form-control:active, .input-group .form-control:hover {
    z-index: 3; }

.input-group-addon, .input-group-btn, .input-group .form-control {
  display: table-cell; }
  .input-group-addon:not(:first-child):not(:last-child), .input-group-btn:not(:first-child):not(:last-child), .input-group .form-control:not(:first-child):not(:last-child) {
    border-radius: 0; }

.input-group-addon, .input-group-btn {
  width: 1%;
  white-space: nowrap;
  vertical-align: middle; }

.input-group-addon {
  padding: 0.375rem 0.75rem;
  font-size: 1rem;
  font-weight: normal;
  line-height: 1;
  color: #3e3e3e;
  text-align: center;
  background-color: #eceeef;
  border: 1px solid #ccc;
  border-radius: 0; }
  .input-group-addon.form-control-sm, .input-group-sm > .form-control.input-group-addon, .input-group-sm > .input-group-addon.input-group-addon, .input-group-sm > .input-group-btn > .btn.input-group-addon {
    padding: 0.275rem 0.75rem;
    font-size: 0.875rem;
    border-radius: 0; }
  .input-group-addon.form-control-lg, .input-group-lg > .form-control.input-group-addon, .input-group-lg > .input-group-addon.input-group-addon, .input-group-lg > .input-group-btn > .btn.input-group-addon {
    padding: 0.75rem 1.25rem;
    font-size: 1.25rem;
    border-radius: 0; }
  .input-group-addon input[type="radio"], .input-group-addon input[type="checkbox"] {
    margin-top: 0; }

.input-group .form-control:first-child, .input-group-addon:first-child, .input-group-btn:first-child > .btn, .input-group-btn:first-child > .btn-group > .btn, .input-group-btn:first-child > .dropdown-toggle, .input-group-btn:last-child > .btn:not(:last-child):not(.dropdown-toggle), .input-group-btn:last-child > .btn-group:not(:last-child) > .btn {
  border-bottom-right-radius: 0;
  border-top-right-radius: 0; }

.input-group-addon:first-child {
  border-right: 0; }

.input-group .form-control:last-child, .input-group-addon:last-child, .input-group-btn:last-child > .btn, .input-group-btn:last-child > .btn-group > .btn, .input-group-btn:last-child > .dropdown-toggle, .input-group-btn:first-child > .btn:not(:first-child), .input-group-btn:first-child > .btn-group:not(:first-child) > .btn {
  border-bottom-left-radius: 0;
  border-top-left-radius: 0; }

.input-group-addon:last-child {
  border-left: 0; }

.input-group-btn {
  position: relative;
  font-size: 0;
  white-space: nowrap; }
  .input-group-btn > .btn {
    position: relative; }
  .input-group-btn > .btn + .btn {
    margin-left: -1px; }
  .input-group-btn > .btn:focus, .input-group-btn > .btn:active, .input-group-btn > .btn:hover {
    z-index: 3; }
  .input-group-btn:first-child > .btn, .input-group-btn:first-child > .btn-group {
    margin-right: -1px; }
  .input-group-btn:last-child > .btn, .input-group-btn:last-child > .btn-group {
    z-index: 2;
    margin-left: -1px; }
  .input-group-btn:last-child > .btn:focus, .input-group-btn:last-child > .btn-group:focus, .input-group-btn:last-child > .btn:active, .input-group-btn:last-child > .btn-group:active, .input-group-btn:last-child > .btn:hover, .input-group-btn:last-child > .btn-group:hover {
    z-index: 3; }

.c-input {
  position: relative;
  display: inline;
  padding-left: 1.5rem;
  color: #555;
  cursor: pointer; }
  .c-input > input {
    position: absolute;
    z-index: -1;
    opacity: 0; }
  .c-input > input:checked ~ .c-indicator {
    color: #fff;
    background-color: #0074d9; }
  .c-input > input:focus ~ .c-indicator {
    box-shadow: 0 0 0 0.075rem #fff, 0 0 0 0.2rem #0074d9; }
  .c-input > input:active ~ .c-indicator {
    color: #fff;
    background-color: #84c6ff; }
  .c-input + .c-input {
    margin-left: 1rem; }

.c-indicator {
  position: absolute;
  top: 0;
  left: 0;
  display: block;
  width: 1rem;
  height: 1rem;
  font-size: 65%;
  line-height: 1rem;
  color: #eee;
  text-align: center;
  user-select: none;
  background-color: #eee;
  background-repeat: no-repeat;
  background-position: center center;
  background-size: 50% 50%; }

.c-checkbox .c-indicator {
  border-radius: 0.25rem; }
  .c-checkbox input:checked ~ .c-indicator {
    background-image: url(data:image/svg+xml;base64,PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0idXRmLTgiPz4NCjwhLS0gR2VuZXJhdG9yOiBBZG9iZSBJbGx1c3RyYXRvciAxNy4xLjAsIFNWRyBFeHBvcnQgUGx1Zy1JbiAuIFNWRyBWZXJzaW9uOiA2LjAwIEJ1aWxkIDApICAtLT4NCjwhRE9DVFlQRSBzdmcgUFVCTElDICItLy9XM0MvL0RURCBTVkcgMS4xLy9FTiIgImh0dHA6Ly93d3cudzMub3JnL0dyYXBoaWNzL1NWRy8xLjEvRFREL3N2ZzExLmR0ZCI+DQo8c3ZnIHZlcnNpb249IjEuMSIgaWQ9IkxheWVyXzEiIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyIgeG1sbnM6eGxpbms9Imh0dHA6Ly93d3cudzMub3JnLzE5OTkveGxpbmsiIHg9IjBweCIgeT0iMHB4Ig0KCSB2aWV3Qm94PSIwIDAgOCA4IiBlbmFibGUtYmFja2dyb3VuZD0ibmV3IDAgMCA4IDgiIHhtbDpzcGFjZT0icHJlc2VydmUiPg0KPHBhdGggZmlsbD0iI0ZGRkZGRiIgZD0iTTYuNCwxTDUuNywxLjdMMi45LDQuNUwyLjEsMy43TDEuNCwzTDAsNC40bDAuNywwLjdsMS41LDEuNWwwLjcsMC43bDAuNy0wLjdsMy41LTMuNWwwLjctMC43TDYuNCwxTDYuNCwxeiINCgkvPg0KPC9zdmc+DQo=); }
  .c-checkbox input:indeterminate ~ .c-indicator {
    background-color: #0074d9;
    background-image: url(data:image/svg+xml;base64,PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0idXRmLTgiPz4NCjwhLS0gR2VuZXJhdG9yOiBBZG9iZSBJbGx1c3RyYXRvciAxNy4xLjAsIFNWRyBFeHBvcnQgUGx1Zy1JbiAuIFNWRyBWZXJzaW9uOiA2LjAwIEJ1aWxkIDApICAtLT4NCjwhRE9DVFlQRSBzdmcgUFVCTElDICItLy9XM0MvL0RURCBTVkcgMS4xLy9FTiIgImh0dHA6Ly93d3cudzMub3JnL0dyYXBoaWNzL1NWRy8xLjEvRFREL3N2ZzExLmR0ZCI+DQo8c3ZnIHZlcnNpb249IjEuMSIgaWQ9IkxheWVyXzEiIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyIgeG1sbnM6eGxpbms9Imh0dHA6Ly93d3cudzMub3JnLzE5OTkveGxpbmsiIHg9IjBweCIgeT0iMHB4Ig0KCSB3aWR0aD0iOHB4IiBoZWlnaHQ9IjhweCIgdmlld0JveD0iMCAwIDggOCIgZW5hYmxlLWJhY2tncm91bmQ9Im5ldyAwIDAgOCA4IiB4bWw6c3BhY2U9InByZXNlcnZlIj4NCjxwYXRoIGZpbGw9IiNGRkZGRkYiIGQ9Ik0wLDN2Mmg4VjNIMHoiLz4NCjwvc3ZnPg0K); }

.c-radio .c-indicator {
  border-radius: 50%; }
  .c-radio input:checked ~ .c-indicator {
    background-image: url(data:image/svg+xml;base64,PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0idXRmLTgiPz4NCjwhLS0gR2VuZXJhdG9yOiBBZG9iZSBJbGx1c3RyYXRvciAxNy4xLjAsIFNWRyBFeHBvcnQgUGx1Zy1JbiAuIFNWRyBWZXJzaW9uOiA2LjAwIEJ1aWxkIDApICAtLT4NCjwhRE9DVFlQRSBzdmcgUFVCTElDICItLy9XM0MvL0RURCBTVkcgMS4xLy9FTiIgImh0dHA6Ly93d3cudzMub3JnL0dyYXBoaWNzL1NWRy8xLjEvRFREL3N2ZzExLmR0ZCI+DQo8c3ZnIHZlcnNpb249IjEuMSIgaWQ9IkxheWVyXzEiIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyIgeG1sbnM6eGxpbms9Imh0dHA6Ly93d3cudzMub3JnLzE5OTkveGxpbmsiIHg9IjBweCIgeT0iMHB4Ig0KCSB2aWV3Qm94PSIwIDAgOCA4IiBlbmFibGUtYmFja2dyb3VuZD0ibmV3IDAgMCA4IDgiIHhtbDpzcGFjZT0icHJlc2VydmUiPg0KPHBhdGggZmlsbD0iI0ZGRkZGRiIgZD0iTTQsMUMyLjMsMSwxLDIuMywxLDRzMS4zLDMsMywzczMtMS4zLDMtM1M1LjcsMSw0LDF6Ii8+DQo8L3N2Zz4NCg==); }

.c-inputs-stacked .c-input {
  display: inline; }
  .c-inputs-stacked .c-input::after {
    display: block;
    margin-bottom: 0.25rem;
    content: ""; }
  .c-inputs-stacked .c-input + .c-input {
    margin-left: 0; }

.c-select {
  display: inline-block;
  max-width: 100%;
  padding: 0.375rem 1.75rem 0.375rem 0.75rem;
  padding-right: 0.75rem \9;
  color: #3e3e3e;
  vertical-align: middle;
  background: #fff url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABAAAAAUCAMAAACzvE1FAAAADFBMVEUzMzMzMzMzMzMzMzMKAG/3AAAAA3RSTlMAf4C/aSLHAAAAPElEQVR42q3NMQ4AIAgEQTn//2cLdRKppSGzBYwzVXvznNWs8C58CiussPJj8h6NwgorrKRdTvuV9v16Afn0AYFOB7aYAAAAAElFTkSuQmCC) no-repeat right 0.75rem center;
  background-image: none \9;
  background-size: 8px 10px;
  border: 1px solid #ccc;
  -moz-appearance: none;
  -webkit-appearance: none; }
  .c-select:focus {
    border-color: #51a7e8;
    outline: none; }
  .c-select::-ms-expand {
    opacity: 0; }

.c-select-sm {
  padding-top: 3px;
  padding-bottom: 3px;
  font-size: 12px; }
  .c-select-sm:not([multiple]) {
    height: 26px;
    min-height: 26px; }

.file {
  position: relative;
  display: inline-block;
  height: 2.5rem;
  cursor: pointer; }

.file input {
  min-width: 14rem;
  margin: 0;
  filter: alpha(opacity=0);
  opacity: 0; }

.file-custom {
  position: absolute;
  top: 0;
  right: 0;
  left: 0;
  z-index: 5;
  height: 2.5rem;
  padding: 0.5rem 1rem;
  line-height: 1.5;
  color: #555;
  user-select: none;
  background-color: #fff;
  border: 1px solid #ddd;
  border-radius: 0.25rem; }

.file-custom::after {
  content: "Choose file..."; }

.file-custom::before {
  position: absolute;
  top: -0.075rem;
  right: -0.075rem;
  bottom: -0.075rem;
  z-index: 6;
  display: block;
  height: 2.5rem;
  padding: 0.5rem 1rem;
  line-height: 1.5;
  color: #555;
  content: "Browse";
  background-color: #eee;
  border: 1px solid #ddd;
  border-radius: 0 0.25rem 0.25rem 0; }

.nav {
  padding-left: 0;
  margin-bottom: 0;
  list-style: none; }

.nav-link {
  display: inline-block; }
  .nav-link:focus, .nav-link:hover {
    text-decoration: none; }
  .nav-link.disabled {
    color: #818a91; }
  .nav-link.disabled, .nav-link.disabled:focus, .nav-link.disabled:hover {
    color: #818a91;
    cursor: not-allowed;
    background-color: transparent; }

.nav-inline .nav-item {
  display: inline-block; }
  .nav-inline .nav-item + .nav-item, .nav-inline .nav-link + .nav-link {
    margin-left: 1rem; }

.nav-tabs {
  border-bottom: 1px solid #ddd; }
  .nav-tabs::after {
    content: "";
    display: table;
    clear: both; }
  .nav-tabs .nav-item {
    float: left;
    margin-bottom: -1px; }
  .nav-tabs .nav-item + .nav-item {
    margin-left: 0.2rem; }
  .nav-tabs .nav-link {
    display: block;
    padding: 0.5em 1em;
    border: 1px solid transparent;
    border-radius: 0 0 0 0; }
  .nav-tabs .nav-link:focus, .nav-tabs .nav-link:hover {
    border-color: #eceeef #eceeef #ddd; }
  .nav-tabs .nav-link.disabled, .nav-tabs .nav-link.disabled:focus, .nav-tabs .nav-link.disabled:hover {
    color: #818a91;
    background-color: transparent;
    border-color: transparent; }
  .nav-tabs .nav-link.active, .nav-tabs .nav-item.open .nav-link, .nav-tabs .nav-link.active:focus, .nav-tabs .nav-item.open .nav-link:focus, .nav-tabs .nav-link.active:hover, .nav-tabs .nav-item.open .nav-link:hover {
    color: #3e3e3e;
    background-color: #f1f2f3;
    border-color: #ddd #ddd transparent; }

.nav-pills::after {
  content: "";
  display: table;
  clear: both; }
  .nav-pills .nav-item {
    float: left; }
  .nav-pills .nav-item + .nav-item {
    margin-left: 0.2rem; }
  .nav-pills .nav-link {
    display: block;
    padding: 0.5em 1em;
    border-radius: 0; }
  .nav-pills .nav-link.active, .nav-pills .nav-item.open .nav-link, .nav-pills .nav-link.active:focus, .nav-pills .nav-item.open .nav-link:focus, .nav-pills .nav-link.active:hover, .nav-pills .nav-item.open .nav-link:hover {
    color: #fff;
    cursor: default;
    background-color: #61259e; }

.nav-stacked .nav-item {
  display: block;
  float: none; }
  .nav-stacked .nav-item + .nav-item {
    margin-top: 0.2rem;
    margin-left: 0; }

.tab-content > .tab-pane {
  display: none; }
  .tab-content > .active {
    display: block; }

.nav-tabs .dropdown-menu {
  margin-top: -1px;
  border-top-right-radius: 0;
  border-top-left-radius: 0; }

.navbar {
  position: relative;
  padding: 0.5rem 1rem; }
  .navbar::after {
    content: "";
    display: table;
    clear: both; }
  @media (min-width: 544px) {
  .navbar {
    border-radius: 0; } }

.navbar-full {
  z-index: 1000; }
  @media (min-width: 544px) {
  .navbar-full {
    border-radius: 0; } }

.navbar-fixed-top, .navbar-fixed-bottom {
  position: fixed;
  right: 0;
  left: 0;
  z-index: 1030; }
  @media (min-width: 544px) {
  .navbar-fixed-top, .navbar-fixed-bottom {
    border-radius: 0; } }

.navbar-fixed-top {
  top: 0; }

.navbar-fixed-bottom {
  bottom: 0; }

.navbar-sticky-top {
  position: sticky;
  top: 0;
  z-index: 1030;
  width: 100%; }
  @media (min-width: 544px) {
  .navbar-sticky-top {
    border-radius: 0; } }

.navbar-brand {
  float: left;
  padding-top: 0.25rem;
  padding-bottom: 0.25rem;
  margin-right: 1rem;
  font-size: 1.25rem; }
  .navbar-brand:focus, .navbar-brand:hover {
    text-decoration: none; }
  .navbar-brand > img {
    display: block; }

.navbar-divider {
  float: left;
  width: 1px;
  padding-top: 0.425rem;
  padding-bottom: 0.425rem;
  margin-right: 1rem;
  margin-left: 1rem;
  overflow: hidden; }
  .navbar-divider::before {
    content: "\00a0"; }

.navbar-toggler {
  padding: 0.5rem 0.75rem;
  font-size: 1.25rem;
  line-height: 1;
  background: none;
  border: 1px solid transparent;
  border-radius: 0; }
  .navbar-toggler:focus, .navbar-toggler:hover {
    text-decoration: none; }

@media (min-width: 544px) {
      .navbar-toggleable-xs {
        display: block !important; } }
  @media (min-width: 768px) {
    .navbar-toggleable-sm {
      display: block !important; } }
  @media (min-width: 992px) {
    .navbar-toggleable-md {
      display: block !important; } }

.navbar-nav .nav-item {
  float: left; }
  .navbar-nav .nav-link {
    display: block;
    padding-top: 0.425rem;
    padding-bottom: 0.425rem; }
  .navbar-nav .nav-link + .nav-link {
    margin-left: 1rem; }
  .navbar-nav .nav-item + .nav-item {
    margin-left: 1rem; }

.navbar-light .navbar-brand {
  color: rgba(0, 0, 0, .8); }
  .navbar-light .navbar-brand:focus, .navbar-light .navbar-brand:hover {
    color: rgba(0, 0, 0, .8); }
  .navbar-light .navbar-nav .nav-link {
    color: rgba(0, 0, 0, .3); }
  .navbar-light .navbar-nav .nav-link:focus, .navbar-light .navbar-nav .nav-link:hover {
    color: rgba(0, 0, 0, .6); }
  .navbar-light .navbar-nav .open > .nav-link, .navbar-light .navbar-nav .active > .nav-link, .navbar-light .navbar-nav .nav-link.open, .navbar-light .navbar-nav .nav-link.active, .navbar-light .navbar-nav .open > .nav-link:focus, .navbar-light .navbar-nav .active > .nav-link:focus, .navbar-light .navbar-nav .nav-link.open:focus, .navbar-light .navbar-nav .nav-link.active:focus, .navbar-light .navbar-nav .open > .nav-link:hover, .navbar-light .navbar-nav .active > .nav-link:hover, .navbar-light .navbar-nav .nav-link.open:hover, .navbar-light .navbar-nav .nav-link.active:hover {
    color: rgba(0, 0, 0, .8); }
  .navbar-light .navbar-divider {
    background-color: rgba(0, 0, 0, .075); }

.navbar-dark .navbar-brand {
  color: rgba(255, 255, 255, 1); }
  .navbar-dark .navbar-brand:focus, .navbar-dark .navbar-brand:hover {
    color: rgba(255, 255, 255, 1); }
  .navbar-dark .navbar-nav .nav-link {
    color: rgba(255, 255, 255, .5); }
  .navbar-dark .navbar-nav .nav-link:focus, .navbar-dark .navbar-nav .nav-link:hover {
    color: rgba(255, 255, 255, .75); }
  .navbar-dark .navbar-nav .open > .nav-link, .navbar-dark .navbar-nav .active > .nav-link, .navbar-dark .navbar-nav .nav-link.open, .navbar-dark .navbar-nav .nav-link.active, .navbar-dark .navbar-nav .open > .nav-link:focus, .navbar-dark .navbar-nav .active > .nav-link:focus, .navbar-dark .navbar-nav .nav-link.open:focus, .navbar-dark .navbar-nav .nav-link.active:focus, .navbar-dark .navbar-nav .open > .nav-link:hover, .navbar-dark .navbar-nav .active > .nav-link:hover, .navbar-dark .navbar-nav .nav-link.open:hover, .navbar-dark .navbar-nav .nav-link.active:hover {
    color: rgba(255, 255, 255, 1); }
  .navbar-dark .navbar-divider {
    background-color: rgba(255, 255, 255, .075); }

.card {
  position: relative;
  display: block;
  margin-bottom: 1.5rem;
  background-color: #fff;
  border: 1px solid #e5e5e5;
  border-radius: 0; }

.card-block {
  padding: 1.25rem; }

.card-title {
  margin-bottom: 1.5rem; }

.card-subtitle {
  margin-top: -0.75rem;
  margin-bottom: 0; }

.card-text:last-child {
  margin-bottom: 0; }

.card-link:hover {
  text-decoration: none; }
  .card-link + .card-link {
    margin-left: 1.25rem; }

.card > .list-group:first-child .list-group-item:first-child {
  border-radius: 0 0 0 0; }
  .card > .list-group:last-child .list-group-item:last-child {
    border-radius: 0 0 0 0; }

.card-header {
  padding: 1.5rem 1.25rem;
  background-color: #f8f8f8;
  border-bottom: 1px solid #e5e5e5; }
  .card-header:first-child {
    border-radius: 0 0 0 0; }

.card-footer {
  padding: 1.5rem 1.25rem;
  background-color: #f8f8f8;
  border-top: 1px solid #e5e5e5; }
  .card-footer:last-child {
    border-radius: 0 0 0 0; }

.card-primary {
  background-color: #61259e;
  border-color: #61259e; }

.card-success {
  background-color: #24ce7b;
  border-color: #24ce7b; }

.card-info {
  background-color: #38b5e6;
  border-color: #38b5e6; }

.card-warning {
  background-color: #f48714;
  border-color: #f48714; }

.card-danger {
  background-color: #f6303e;
  border-color: #f6303e; }

.card-primary-outline {
  background-color: transparent;
  border-color: #61259e; }

.card-secondary-outline {
  background-color: transparent;
  border-color: #6f6f6f; }

.card-info-outline {
  background-color: transparent;
  border-color: #38b5e6; }

.card-success-outline {
  background-color: transparent;
  border-color: #24ce7b; }

.card-warning-outline {
  background-color: transparent;
  border-color: #f48714; }

.card-danger-outline {
  background-color: transparent;
  border-color: #f6303e; }

.card-inverse .card-header, .card-inverse .card-footer {
  border-bottom: 1px solid rgba(255, 255, 255, .2); }
  .card-inverse .card-header, .card-inverse .card-footer, .card-inverse .card-title, .card-inverse .card-blockquote {
    color: #fff; }
  .card-inverse .card-link, .card-inverse .card-text, .card-inverse .card-blockquote > footer {
    color: rgba(255, 255, 255, .65); }
  .card-inverse .card-link:focus, .card-inverse .card-link:hover {
    color: #fff; }

.card-blockquote {
  padding: 0;
  margin-bottom: 0;
  border-left: 0; }

.card-img {
  border-radius: 0.25rem; }

.card-img-overlay {
  position: absolute;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
  padding: 1.25rem; }

.card-img-top {
  border-radius: 0 0 0 0; }

.card-img-bottom {
  border-radius: 0 0 0 0; }

@media (min-width: 544px) {
  .card-deck {
    display: table;
    table-layout: fixed;
    border-spacing: 1.25rem 0; }
    .card-deck .card {
      display: table-cell;
      width: 1%;
      vertical-align: top; }
    .card-deck-wrapper {
      margin-right: -1.25rem;
      margin-left: -1.25rem; } }

@media (min-width: 544px) {
  .card-group {
    display: table;
    width: 100%;
    table-layout: fixed; }
    .card-group .card {
      display: table-cell;
      vertical-align: top; }
      .card-group .card + .card {
        margin-left: 0;
        border-left: 0; }
      .card-group .card:first-child {
        border-bottom-right-radius: 0;
        border-top-right-radius: 0; }
        .card-group .card:first-child .card-img-top {
          border-top-right-radius: 0; }
        .card-group .card:first-child .card-img-bottom {
          border-bottom-right-radius: 0; }
      .card-group .card:last-child {
        border-bottom-left-radius: 0;
        border-top-left-radius: 0; }
        .card-group .card:last-child .card-img-top {
          border-top-left-radius: 0; }
        .card-group .card:last-child .card-img-bottom {
          border-bottom-left-radius: 0; }
      .card-group .card:not(:first-child):not(:last-child) {
        border-radius: 0; }
        .card-group .card:not(:first-child):not(:last-child) .card-img-top, .card-group .card:not(:first-child):not(:last-child) .card-img-bottom {
          border-radius: 0; } }

@media (min-width: 544px) {
  .card-columns {
    column-count: 3;
    column-gap: 1.25rem; }
    .card-columns .card {
      display: inline-block;
      width: 100%; } }

.breadcrumb {
  padding: 0.75rem 1rem;
  margin-bottom: 1rem;
  list-style: none;
  background-color: transparent;
  border-radius: 0; }
  .breadcrumb::after {
    content: "";
    display: table;
    clear: both; }
  .breadcrumb > li {
    float: left; }
  .breadcrumb > li + li::before {
    padding-right: 0.5rem;
    padding-left: 0.5rem;
    color: #818a91;
    content: "›"; }
  .breadcrumb > .active {
    color: #38b5e6; }

.pagination {
  display: inline-block;
  padding-left: 0;
  list-style-type: none;
  margin: 1rem auto 1rem auto;
  border-radius: 0; }
  .pagination li {
    display: inline;
    padding: 5px 10px; }

.page-item {
  display: inline; }
  .page-item:first-child .page-link {
    margin-left: 0;
    border-bottom-left-radius: 0;
    border-top-left-radius: 0; }
  .page-item:last-child .page-link {
    border-bottom-right-radius: 0;
    border-top-right-radius: 0; }
  .page-item.active .page-link, .page-item.active .page-link:focus, .page-item.active .page-link:hover {
    z-index: 2;
    color: #fff;
    cursor: default;
    background-color: #61259e;
    border-color: #61259e; }
  .page-item.disabled .page-link, .page-item.disabled .page-link:focus, .page-item.disabled .page-link:hover {
    color: #818a91;
    cursor: not-allowed;
    background-color: #fff;
    border-color: #ddd; }

.page-link {
  position: relative;
  float: left;
  padding: 0.5rem 0.75rem;
  margin-left: -1px;
  line-height: 1.5;
  color: #38b5e6;
  text-decoration: none;
  background-color: #fff;
  border: 1px solid #ddd; }
  .page-link:focus, .page-link:hover {
    color: #21ade3;
    background-color: #eceeef;
    border-color: #ddd; }

.pagination-lg .page-link {
  padding: 0.75rem 1.5rem;
  font-size: 1.25rem;
  line-height: 1.33333; }
  .pagination-lg .page-item:first-child .page-link {
    border-bottom-left-radius: 0;
    border-top-left-radius: 0; }
  .pagination-lg .page-item:last-child .page-link {
    border-bottom-right-radius: 0;
    border-top-right-radius: 0; }

.pagination-sm .page-link {
  padding: 0.275rem 0.75rem;
  font-size: 0.875rem;
  line-height: 1.5; }
  .pagination-sm .page-item:first-child .page-link {
    border-bottom-left-radius: 0;
    border-top-left-radius: 0; }
  .pagination-sm .page-item:last-child .page-link {
    border-bottom-right-radius: 0;
    border-top-right-radius: 0; }

.pager {
  padding-left: 0;
  margin-top: 1rem;
  margin-bottom: 1rem;
  text-align: center;
  list-style: none; }
  .pager::after {
    content: "";
    display: table;
    clear: both; }
  .pager li {
    display: inline; }
  .pager li > a, .pager li > span {
    display: inline-block;
    padding: 5px 14px;
    background-color: #fff;
    border: 1px solid #ddd;
    border-radius: 15px; }
  .pager li > a:focus, .pager li > a:hover {
    text-decoration: none;
    background-color: #eceeef; }
  .pager .disabled > a, .pager .disabled > a:focus, .pager .disabled > a:hover {
    color: #818a91;
    cursor: not-allowed;
    background-color: #fff; }
  .pager .disabled > span {
    color: #818a91;
    cursor: not-allowed;
    background-color: #fff; }

.pager-next > a, .pager-next > span {
  float: right; }

.pager-prev > a, .pager-prev > span {
  float: left; }

.label {
  display: inline-block;
  padding: 0.25em 0.4em;
  font-size: 75%;
  font-weight: bold;
  line-height: 1;
  color: #fff;
  text-align: center;
  white-space: nowrap;
  vertical-align: baseline;
  border-radius: 0; }
  .label:empty {
    display: none; }

.btn .label {
  position: relative;
  top: -1px; }

a.label:focus, a.label:hover {
  color: #fff;
  text-decoration: none;
  cursor: pointer; }

.label-pill {
  padding-right: 0.6em;
  padding-left: 0.6em;
  border-radius: 10rem; }

.label-default {
  background-color: #818a91; }
  .label-default[href]:focus, .label-default[href]:hover {
    background-color: #687077; }

.label-primary {
  background-color: #61259e; }
  .label-primary[href]:focus, .label-primary[href]:hover {
    background-color: #481b75; }

.label-success {
  background-color: #24ce7b; }
  .label-success[href]:focus, .label-success[href]:hover {
    background-color: #1ca361; }

.label-info {
  background-color: #38b5e6; }
  .label-info[href]:focus, .label-info[href]:hover {
    background-color: #1a9dd1; }

.label-warning {
  background-color: #f48714; }
  .label-warning[href]:focus, .label-warning[href]:hover {
    background-color: #cb6d0a; }

.label-danger {
  background-color: #f6303e; }
  .label-danger[href]:focus, .label-danger[href]:hover {
    background-color: #e90a1a; }

.jumbotron {
  padding: 2rem 1rem;
  margin-bottom: 2rem;
  background-color: #dee2e3;
  border-radius: 0; }
  @media (min-width: 544px) {
  .jumbotron {
    padding: 4rem 2rem; } }

.jumbotron-hr {
  border-top-color: #c2cacc; }

.jumbotron-fluid {
  padding-right: 0;
  padding-left: 0;
  border-radius: 0; }

.alert {
  padding: 15px;
  margin-bottom: 1rem;
  border: 1px solid transparent;
  border-radius: 0; }
  .alert > p, .alert > ul {
    margin-bottom: 0; }
  .alert > p + p {
    margin-top: 5px; }

.alert-heading {
  color: inherit; }

.alert-link {
  font-weight: bold; }

.alert-dismissible {
  padding-right: 35px; }
  .alert-dismissible .close {
    position: relative;
    top: -2px;
    right: -21px;
    color: inherit; }

.alert-success {
  background-color: #24ce7b;
  border-color: #24ce7b;
  color: #fff; }
  .alert-success hr {
    border-top-color: #20b86e; }
  .alert-success .alert-link {
    color: #e6e6e6; }

.alert-info {
  background-color: #38b5e6;
  border-color: #38b5e6;
  color: #fff; }
  .alert-info hr {
    border-top-color: #21ade3; }
  .alert-info .alert-link {
    color: #e6e6e6; }

.alert-warning {
  background-color: #f48714;
  border-color: #f48714;
  color: #fff; }
  .alert-warning hr {
    border-top-color: #e47a0b; }
  .alert-warning .alert-link {
    color: #e6e6e6; }

.alert-danger {
  background-color: #f6303e;
  border-color: #f6303e;
  color: #fff; }
  .alert-danger hr {
    border-top-color: #f51827; }
  .alert-danger .alert-link {
    color: #e6e6e6; }

@keyframes progress-bar-stripes {
  from {
    background-position: 1rem 0; }

  to {
    background-position: 0 0; } }

.progress {
  display: block;
  width: 100%;
  height: 1rem;
  margin-bottom: 1rem; }

.progress[value] {
  color: #0074d9;
  border: 0;
  appearance: none; }

.progress[value]::-webkit-progress-bar {
  background-color: #eee;
  border-radius: 0; }

.progress[value]::-webkit-progress-value::before {
  content: attr(value); }

.progress[value]::-webkit-progress-value {
  background-color: #0074d9;
  border-top-left-radius: 0;
  border-bottom-left-radius: 0; }

.progress[value="100"]::-webkit-progress-value {
  border-top-right-radius: 0;
  border-bottom-right-radius: 0; }

@media screen and (min-width: 0 \0
) {
  .progress {
    background-color: #eee;
    border-radius: 0; }

  .progress-bar {
    display: inline-block;
    height: 1rem;
    text-indent: -999rem;
    background-color: #0074d9;
    border-top-left-radius: 0;
    border-bottom-left-radius: 0; }

  .progress[width^="0"] {
    min-width: 2rem;
    color: #818a91;
    background-color: transparent;
    background-image: none; }

  .progress[width="100%"] {
    border-top-right-radius: 0;
    border-bottom-right-radius: 0; } }

.progress-striped[value]::-webkit-progress-value {
  background-image: linear-gradient(45deg, rgba(255, 255, 255, .15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, .15) 50%, rgba(255, 255, 255, .15) 75%, transparent 75%, transparent);
  background-size: 1rem 1rem; }

.progress-striped[value]::-moz-progress-bar {
  background-image: linear-gradient(45deg, rgba(255, 255, 255, .15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, .15) 50%, rgba(255, 255, 255, .15) 75%, transparent 75%, transparent);
  background-size: 1rem 1rem; }

@media screen and (min-width: 0 \0
) {
  .progress-bar-striped {
    background-image: linear-gradient(45deg, rgba(255, 255, 255, .15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, .15) 50%, rgba(255, 255, 255, .15) 75%, transparent 75%, transparent);
    background-size: 1rem 1rem; } }

.progress-animated[value]::-webkit-progress-value {
  animation: progress-bar-stripes 2s linear infinite; }

.progress-animated[value]::-moz-progress-bar {
  animation: progress-bar-stripes 2s linear infinite; }

@media screen and (min-width: 0 \0
) {
  .progress-animated .progress-bar-striped {
    animation: progress-bar-stripes 2s linear infinite; } }

.progress-success[value]::-webkit-progress-value {
  background-color: #24ce7b; }
  .progress-success[value]::-moz-progress-bar {
    background-color: #24ce7b; }
  @media screen and (min-width: 0 \0
    ) {
  .progress-success .progress-bar {
    background-color: #24ce7b; } }

.progress-info[value]::-webkit-progress-value {
  background-color: #38b5e6; }
  .progress-info[value]::-moz-progress-bar {
    background-color: #38b5e6; }
  @media screen and (min-width: 0 \0
    ) {
  .progress-info .progress-bar {
    background-color: #38b5e6; } }

.progress-warning[value]::-webkit-progress-value {
  background-color: #f48714; }
  .progress-warning[value]::-moz-progress-bar {
    background-color: #f48714; }
  @media screen and (min-width: 0 \0
    ) {
  .progress-warning .progress-bar {
    background-color: #f48714; } }

.progress-danger[value]::-webkit-progress-value {
  background-color: #f6303e; }
  .progress-danger[value]::-moz-progress-bar {
    background-color: #f6303e; }
  @media screen and (min-width: 0 \0
    ) {
  .progress-danger .progress-bar {
    background-color: #f6303e; } }

.media {
  margin-top: 15px; }
  .media:first-child {
    margin-top: 0; }

.media, .media-body {
  overflow: hidden;
  zoom: 1; }

.media-body {
  width: 10000px; }

.media-left, .media-right, .media-body {
  display: table-cell;
  vertical-align: top; }

.media-middle {
  vertical-align: middle; }

.media-bottom {
  vertical-align: bottom; }

.media-object {
  display: block; }
  .media-object.img-thumbnail {
    max-width: none; }

.media-right {
  padding-left: 10px; }

.media-left {
  padding-right: 10px; }

.media-heading {
  margin-top: 0;
  margin-bottom: 5px; }

.media-list {
  padding-left: 0;
  list-style: none; }

.list-group {
  padding-left: 0;
  margin-bottom: 0; }

.list-group-item {
  position: relative;
  display: block;
  padding: 0.75rem 1.25rem;
  margin-bottom: -1px;
  background-color: #fff;
  border: 1px solid #ddd; }
  .list-group-item:first-child {
    border-top-right-radius: 0;
    border-top-left-radius: 0; }
  .list-group-item:last-child {
    margin-bottom: 0;
    border-bottom-right-radius: 0;
    border-bottom-left-radius: 0; }

.list-group-flush .list-group-item {
  border-width: 1px 0;
  border-radius: 0; }
  .list-group-flush:first-child .list-group-item:first-child {
    border-top: 0; }
  .list-group-flush:last-child .list-group-item:last-child {
    border-bottom: 0; }

a.list-group-item, button.list-group-item {
  width: 100%;
  color: #555;
  text-align: inherit; }
  a.list-group-item .list-group-item-heading, button.list-group-item .list-group-item-heading {
    color: #333; }
  a.list-group-item:focus, button.list-group-item:focus, a.list-group-item:hover, button.list-group-item:hover {
    color: #555;
    text-decoration: none;
    background-color: #f5f5f5; }

.list-group-item.disabled, .list-group-item.disabled:focus, .list-group-item.disabled:hover {
  color: #818a91;
  cursor: not-allowed;
  background-color: #eceeef; }
  .list-group-item.disabled .list-group-item-heading, .list-group-item.disabled:focus .list-group-item-heading, .list-group-item.disabled:hover .list-group-item-heading {
    color: inherit; }
  .list-group-item.disabled .list-group-item-text, .list-group-item.disabled:focus .list-group-item-text, .list-group-item.disabled:hover .list-group-item-text {
    color: #818a91; }
  .list-group-item.active, .list-group-item.active:focus, .list-group-item.active:hover {
    z-index: 2;
    color: #fff;
    background-color: #61259e;
    border-color: #61259e; }
  .list-group-item.active .list-group-item-heading, .list-group-item.active:focus .list-group-item-heading, .list-group-item.active:hover .list-group-item-heading, .list-group-item.active .list-group-item-heading > small, .list-group-item.active:focus .list-group-item-heading > small, .list-group-item.active:hover .list-group-item-heading > small, .list-group-item.active .list-group-item-heading > .small, .list-group-item.active:focus .list-group-item-heading > .small, .list-group-item.active:hover .list-group-item-heading > .small {
    color: inherit; }
  .list-group-item.active .list-group-item-text, .list-group-item.active:focus .list-group-item-text, .list-group-item.active:hover .list-group-item-text {
    color: #c7a5ea; }

.list-group-item-success {
  color: #fff;
  background-color: #24ce7b; }

a.list-group-item-success, button.list-group-item-success {
  color: #fff; }
  a.list-group-item-success .list-group-item-heading, button.list-group-item-success .list-group-item-heading {
    color: inherit; }
  a.list-group-item-success:focus, button.list-group-item-success:focus, a.list-group-item-success:hover, button.list-group-item-success:hover {
    color: #fff;
    background-color: #20b86e; }
  a.list-group-item-success.active, button.list-group-item-success.active, a.list-group-item-success.active:focus, button.list-group-item-success.active:focus, a.list-group-item-success.active:hover, button.list-group-item-success.active:hover {
    color: #fff;
    background-color: #fff;
    border-color: #fff; }

.list-group-item-info {
  color: #fff;
  background-color: #38b5e6; }

a.list-group-item-info, button.list-group-item-info {
  color: #fff; }
  a.list-group-item-info .list-group-item-heading, button.list-group-item-info .list-group-item-heading {
    color: inherit; }
  a.list-group-item-info:focus, button.list-group-item-info:focus, a.list-group-item-info:hover, button.list-group-item-info:hover {
    color: #fff;
    background-color: #21ade3; }
  a.list-group-item-info.active, button.list-group-item-info.active, a.list-group-item-info.active:focus, button.list-group-item-info.active:focus, a.list-group-item-info.active:hover, button.list-group-item-info.active:hover {
    color: #fff;
    background-color: #fff;
    border-color: #fff; }

.list-group-item-warning {
  color: #fff;
  background-color: #f48714; }

a.list-group-item-warning, button.list-group-item-warning {
  color: #fff; }
  a.list-group-item-warning .list-group-item-heading, button.list-group-item-warning .list-group-item-heading {
    color: inherit; }
  a.list-group-item-warning:focus, button.list-group-item-warning:focus, a.list-group-item-warning:hover, button.list-group-item-warning:hover {
    color: #fff;
    background-color: #e47a0b; }
  a.list-group-item-warning.active, button.list-group-item-warning.active, a.list-group-item-warning.active:focus, button.list-group-item-warning.active:focus, a.list-group-item-warning.active:hover, button.list-group-item-warning.active:hover {
    color: #fff;
    background-color: #fff;
    border-color: #fff; }

.list-group-item-danger {
  color: #fff;
  background-color: #f6303e; }

a.list-group-item-danger, button.list-group-item-danger {
  color: #fff; }
  a.list-group-item-danger .list-group-item-heading, button.list-group-item-danger .list-group-item-heading {
    color: inherit; }
  a.list-group-item-danger:focus, button.list-group-item-danger:focus, a.list-group-item-danger:hover, button.list-group-item-danger:hover {
    color: #fff;
    background-color: #f51827; }
  a.list-group-item-danger.active, button.list-group-item-danger.active, a.list-group-item-danger.active:focus, button.list-group-item-danger.active:focus, a.list-group-item-danger.active:hover, button.list-group-item-danger.active:hover {
    color: #fff;
    background-color: #fff;
    border-color: #fff; }

.list-group-item-heading {
  margin-top: 0;
  margin-bottom: 5px; }

.list-group-item-text {
  margin-bottom: 0;
  line-height: 1.3; }

.embed-responsive {
  position: relative;
  display: block;
  height: 0;
  padding: 0;
  overflow: hidden; }
  .embed-responsive .embed-responsive-item, .embed-responsive iframe, .embed-responsive embed, .embed-responsive object, .embed-responsive video {
    position: absolute;
    top: 0;
    bottom: 0;
    left: 0;
    width: 100%;
    height: 100%;
    border: 0; }

.embed-responsive-21by9 {
  padding-bottom: 42.85714%; }

.embed-responsive-16by9 {
  padding-bottom: 56.25%; }

.embed-responsive-4by3 {
  padding-bottom: 75%; }

.embed-responsive-1by1 {
  padding-bottom: 100%; }

.close {
  float: right;
  font-size: 1.5rem;
  font-weight: bold;
  line-height: 1;
  color: #000;
  text-shadow: 0 1px 0 #fff;
  opacity: 0.2; }
  .close:focus, .close:hover {
    color: #000;
    text-decoration: none;
    cursor: pointer;
    opacity: 0.5; }

button.close {
  padding: 0;
  cursor: pointer;
  background: transparent;
  border: 0;
  -webkit-appearance: none; }

.modal-open {
  overflow: hidden; }

.modal {
  position: fixed;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
  z-index: 1150;
  display: none;
  overflow: hidden;
  outline: 0;
  -webkit-overflow-scrolling: touch; }
  .modal.fade .modal-dialog {
    transition: transform 0.3s ease-out;
    transform: translate(0, -25%); }
  .modal.in .modal-dialog {
    transform: translate(0, 0); }

.modal-open .modal {
  overflow-x: hidden;
  overflow-y: auto; }

.modal-dialog {
  position: relative;
  width: auto;
  margin: 10px; }

.modal-content {
  position: relative;
  background-color: #fff;
  background-clip: padding-box;
  border: 1px solid rgba(0, 0, 0, .2);
  border-radius: 0;
  outline: 0; }

.modal-backdrop {
  position: fixed;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
  z-index: 1140;
  background-color: #000; }
  .modal-backdrop.fade {
    opacity: 0; }
  .modal-backdrop.in {
    opacity: 0.5; }

.modal-header {
  padding: 15px;
  border-bottom: 1px solid #e5e5e5; }
  .modal-header::after {
    content: "";
    display: table;
    clear: both; }

.modal-header .close {
  margin-top: -2px; }

.modal-title {
  margin: 0;
  line-height: 1.5; }

.modal-body {
  position: relative;
  padding: 15px; }

.modal-footer {
  padding: 15px;
  text-align: right;
  border-top: 1px solid #e5e5e5; }
  .modal-footer::after {
    content: "";
    display: table;
    clear: both; }
  .modal-footer .btn + .btn {
    margin-bottom: 0;
    margin-left: 5px; }
  .modal-footer .btn-group .btn + .btn {
    margin-left: -1px; }
  .modal-footer .btn-block + .btn-block {
    margin-left: 0; }

.modal-scrollbar-measure {
  position: absolute;
  top: -9999px;
  width: 50px;
  height: 50px;
  overflow: scroll; }

@media (min-width: 544px) {
  .modal-dialog {
    width: 600px;
    margin: 30px auto; }
    .modal-sm {
      width: 300px; } }

@media (min-width: 768px) {
  .modal-lg {
    width: 900px; } }

.tooltip {
  position: absolute;
  z-index: 1070;
  display: block;
  font-family: "Proxima Nova", "Helvetica Neue", Helvetica, Arial, sans-serif;
  font-style: normal;
  font-weight: normal;
  letter-spacing: normal;
  line-break: auto;
  line-height: 1.5;
  text-align: left;
  text-align: start;
  text-decoration: none;
  text-shadow: none;
  text-transform: none;
  white-space: normal;
  word-break: normal;
  word-spacing: normal;
  word-wrap: normal;
  font-size: 0.875rem;
  opacity: 0; }
  .tooltip.in {
    opacity: 0.9; }
  .tooltip.tooltip-top, .tooltip.bs-tether-element-attached-bottom {
    padding: 5px 0;
    margin-top: -3px; }
  .tooltip.tooltip-top .tooltip-arrow, .tooltip.bs-tether-element-attached-bottom .tooltip-arrow {
    bottom: 0;
    left: 50%;
    margin-left: -5px;
    border-width: 5px 5px 0;
    border-top-color: #000; }
  .tooltip.tooltip-right, .tooltip.bs-tether-element-attached-left {
    padding: 0 5px;
    margin-left: 3px; }
  .tooltip.tooltip-right .tooltip-arrow, .tooltip.bs-tether-element-attached-left .tooltip-arrow {
    top: 50%;
    left: 0;
    margin-top: -5px;
    border-width: 5px 5px 5px 0;
    border-right-color: #000; }
  .tooltip.tooltip-bottom, .tooltip.bs-tether-element-attached-top {
    padding: 5px 0;
    margin-top: 3px; }
  .tooltip.tooltip-bottom .tooltip-arrow, .tooltip.bs-tether-element-attached-top .tooltip-arrow {
    top: 0;
    left: 50%;
    margin-left: -5px;
    border-width: 0 5px 5px;
    border-bottom-color: #000; }
  .tooltip.tooltip-left, .tooltip.bs-tether-element-attached-right {
    padding: 0 5px;
    margin-left: -3px; }
  .tooltip.tooltip-left .tooltip-arrow, .tooltip.bs-tether-element-attached-right .tooltip-arrow {
    top: 50%;
    right: 0;
    margin-top: -5px;
    border-width: 5px 0 5px 5px;
    border-left-color: #000; }

.tooltip-inner {
  max-width: 200px;
  padding: 3px 8px;
  color: #fff;
  text-align: center;
  background-color: #000;
  border-radius: 0; }

.tooltip-arrow {
  position: absolute;
  width: 0;
  height: 0;
  border-color: transparent;
  border-style: solid; }

.popover {
  position: absolute;
  top: 0;
  left: 0;
  z-index: 1060;
  display: block;
  max-width: 276px;
  padding: 1px;
  font-family: "Proxima Nova", "Helvetica Neue", Helvetica, Arial, sans-serif;
  font-style: normal;
  font-weight: normal;
  letter-spacing: normal;
  line-break: auto;
  line-height: 1.5;
  text-align: left;
  text-align: start;
  text-decoration: none;
  text-shadow: none;
  text-transform: none;
  white-space: normal;
  word-break: normal;
  word-spacing: normal;
  word-wrap: normal;
  font-size: 0.875rem;
  background-color: #fff;
  background-clip: padding-box;
  border: 1px solid rgba(0, 0, 0, .2);
  border-radius: 0; }
  .popover.popover-top, .popover.bs-tether-element-attached-bottom {
    margin-top: -10px; }
  .popover.popover-top .popover-arrow, .popover.bs-tether-element-attached-bottom .popover-arrow {
    bottom: -11px;
    left: 50%;
    margin-left: -11px;
    border-top-color: rgba(0, 0, 0, 0.25);
    border-bottom-width: 0; }
  .popover.popover-top .popover-arrow::after, .popover.bs-tether-element-attached-bottom .popover-arrow::after {
    bottom: 1px;
    margin-left: -10px;
    content: "";
    border-top-color: #fff;
    border-bottom-width: 0; }
  .popover.popover-right, .popover.bs-tether-element-attached-left {
    margin-left: 10px; }
  .popover.popover-right .popover-arrow, .popover.bs-tether-element-attached-left .popover-arrow {
    top: 50%;
    left: -11px;
    margin-top: -11px;
    border-right-color: rgba(0, 0, 0, 0.25);
    border-left-width: 0; }
  .popover.popover-right .popover-arrow::after, .popover.bs-tether-element-attached-left .popover-arrow::after {
    bottom: -10px;
    left: 1px;
    content: "";
    border-right-color: #fff;
    border-left-width: 0; }
  .popover.popover-bottom, .popover.bs-tether-element-attached-top {
    margin-top: 10px; }
  .popover.popover-bottom .popover-arrow, .popover.bs-tether-element-attached-top .popover-arrow {
    top: -11px;
    left: 50%;
    margin-left: -11px;
    border-top-width: 0;
    border-bottom-color: rgba(0, 0, 0, 0.25); }
  .popover.popover-bottom .popover-arrow::after, .popover.bs-tether-element-attached-top .popover-arrow::after {
    top: 1px;
    margin-left: -10px;
    content: "";
    border-top-width: 0;
    border-bottom-color: #fff; }
  .popover.popover-left, .popover.bs-tether-element-attached-right {
    margin-left: -10px; }
  .popover.popover-left .popover-arrow, .popover.bs-tether-element-attached-right .popover-arrow {
    top: 50%;
    right: -11px;
    margin-top: -11px;
    border-right-width: 0;
    border-left-color: rgba(0, 0, 0, 0.25); }
  .popover.popover-left .popover-arrow::after, .popover.bs-tether-element-attached-right .popover-arrow::after {
    right: 1px;
    bottom: -10px;
    content: "";
    border-right-width: 0;
    border-left-color: #fff; }

.popover-title {
  padding: 8px 14px;
  margin: 0;
  font-size: 1rem;
  background-color: #f7f7f7;
  border-bottom: 1px solid #ebebeb;
  border-radius: -1 -1 0 0; }

.popover-content {
  padding: 9px 14px; }

.popover-arrow, .popover-arrow::after {
  position: absolute;
  display: block;
  width: 0;
  height: 0;
  border-color: transparent;
  border-style: solid; }

.popover-arrow {
  border-width: 11px; }

.popover-arrow::after {
  content: "";
  border-width: 10px; }

.carousel {
  position: relative; }

.carousel-inner {
  position: relative;
  width: 100%;
  overflow: hidden; }
  .carousel-inner > .carousel-item {
    position: relative;
    display: none;
    transition: 0.6s ease-in-out left; }
  .carousel-inner > .carousel-item > img, .carousel-inner > .carousel-item > a > img {
    line-height: 1; }
  @media all and (transform-3d), (-webkit-transform-3d) {
    .carousel-inner > .carousel-item {
      transition: transform 0.6s ease-in-out;
      backface-visibility: hidden;
      perspective: 1000px; }
      .carousel-inner > .carousel-item.next, .carousel-inner > .carousel-item.active.right {
        left: 0;
        transform: translate3d(100%, 0, 0); }
      .carousel-inner > .carousel-item.prev, .carousel-inner > .carousel-item.active.left {
        left: 0;
        transform: translate3d(-100%, 0, 0); }
      .carousel-inner > .carousel-item.next.left, .carousel-inner > .carousel-item.prev.right, .carousel-inner > .carousel-item.active {
        left: 0;
        transform: translate3d(0, 0, 0); } }
  .carousel-inner > .active, .carousel-inner > .next, .carousel-inner > .prev {
    display: block; }
  .carousel-inner > .active {
    left: 0; }
  .carousel-inner > .next, .carousel-inner > .prev {
    position: absolute;
    top: 0;
    width: 100%; }
  .carousel-inner > .next {
    left: 100%; }
  .carousel-inner > .prev {
    left: -100%; }
  .carousel-inner > .next.left, .carousel-inner > .prev.right {
    left: 0; }
  .carousel-inner > .active.left {
    left: -100%; }
  .carousel-inner > .active.right {
    left: 100%; }

.carousel-control {
  position: absolute;
  top: 0;
  bottom: 0;
  left: 0;
  width: 15%;
  font-size: 20px;
  color: #fff;
  text-align: center;
  text-shadow: 0 1px 2px rgba(0, 0, 0, .6);
  opacity: 0.5; }
  .carousel-control.left {
    background-image: linear-gradient(to right, rgba(0, 0, 0, .5) 0%, rgba(0, 0, 0, .0001) 100%);
    background-repeat: repeat-x;
    filter: progid:DXImageTransform.Microsoft.gradient(startColorstr="#80000000", endColorstr="#00000000", GradientType=1); }
  .carousel-control.right {
    right: 0;
    left: auto;
    background-image: linear-gradient(to right, rgba(0, 0, 0, .0001) 0%, rgba(0, 0, 0, .5) 100%);
    background-repeat: repeat-x;
    filter: progid:DXImageTransform.Microsoft.gradient(startColorstr="#00000000", endColorstr="#80000000", GradientType=1); }
  .carousel-control:focus, .carousel-control:hover {
    color: #fff;
    text-decoration: none;
    outline: 0;
    opacity: 0.9; }
  .carousel-control .icon-prev, .carousel-control .icon-next {
    position: absolute;
    top: 50%;
    z-index: 5;
    display: inline-block;
    width: 20px;
    height: 20px;
    margin-top: -10px;
    font-family: serif;
    line-height: 1; }
  .carousel-control .icon-prev {
    left: 50%;
    margin-left: -10px; }
  .carousel-control .icon-next {
    right: 50%;
    margin-right: -10px; }
  .carousel-control .icon-prev::before {
    content: "\2039"; }
  .carousel-control .icon-next::before {
    content: "\203a"; }

.carousel-indicators {
  position: absolute;
  bottom: 10px;
  left: 50%;
  z-index: 15;
  width: 60%;
  padding-left: 0;
  margin-left: -30%;
  text-align: center;
  list-style: none; }
  .carousel-indicators li {
    display: inline-block;
    width: 10px;
    height: 10px;
    margin: 1px;
    text-indent: -999px;
    cursor: pointer;
    background-color: rgba(0, 0, 0, 0);
    border: 1px solid #fff;
    border-radius: 10px; }
  .carousel-indicators .active {
    width: 12px;
    height: 12px;
    margin: 0;
    background-color: #fff; }

.carousel-caption {
  position: absolute;
  right: 15%;
  bottom: 20px;
  left: 15%;
  z-index: 10;
  padding-top: 20px;
  padding-bottom: 20px;
  color: #fff;
  text-align: center;
  text-shadow: 0 1px 2px rgba(0, 0, 0, .6); }
  .carousel-caption .btn {
    text-shadow: none; }

@media (min-width: 544px) {
  .carousel-control .icon-prev, .carousel-control .icon-next {
    width: 30px;
    height: 30px;
    margin-top: -15px;
    font-size: 30px; }
    .carousel-control .icon-prev {
      margin-left: -15px; }
    .carousel-control .icon-next {
      margin-right: -15px; }
    .carousel-caption {
      right: 20%;
      left: 20%;
      padding-bottom: 30px; }
    .carousel-indicators {
      bottom: 20px; } }

.clearfix::after {
  content: "";
  display: table;
  clear: both; }

.center-block {
  display: block;
  margin-left: auto;
  margin-right: auto; }
  .pull-xs-left {
    float: left !important; }
  .pull-xs-right {
    float: right !important; }
  .pull-xs-none {
    float: none !important; }
  @media (min-width: 544px) {
  .pull-sm-left {
    float: left !important; }
    .pull-sm-right {
      float: right !important; }

    .pull-sm-none {
      float: none !important; } }
  @media (min-width: 768px) {
  .pull-md-left {
    float: left !important; }
    .pull-md-right {
      float: right !important; }

    .pull-md-none {
      float: none !important; } }
  @media (min-width: 992px) {
  .pull-lg-left {
    float: left !important; }
    .pull-lg-right {
      float: right !important; }

    .pull-lg-none {
      float: none !important; } }
  @media (min-width: 1200px) {
  .pull-xl-left {
    float: left !important; }
    .pull-xl-right {
      float: right !important; }

    .pull-xl-none {
      float: none !important; } }

.sr-only {
  position: absolute;
  width: 1px;
  height: 1px;
  padding: 0;
  margin: -1px;
  overflow: hidden;
  clip: rect(0, 0, 0, 0);
  border: 0; }

.sr-only-focusable:active, .sr-only-focusable:focus {
  position: static;
  width: auto;
  height: auto;
  margin: 0;
  overflow: visible;
  clip: auto; }

.invisible {
  visibility: hidden !important; }

.text-hide {
  font: "0/0" a;
  color: transparent;
  text-shadow: none;
  background-color: transparent;
  border: 0; }

.text-justify {
  text-align: justify !important; }

.text-nowrap {
  white-space: nowrap !important; }

.text-truncate {
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap; }
  .text-xs-left {
    text-align: left !important; }
  .text-xs-right {
    text-align: right !important; }
  .text-xs-center {
    text-align: center !important; }
  @media (min-width: 544px) {
  .text-sm-left {
    text-align: left !important; }
    .text-sm-right {
      text-align: right !important; }

    .text-sm-center {
      text-align: center !important; } }
  @media (min-width: 768px) {
  .text-md-left {
    text-align: left !important; }
    .text-md-right {
      text-align: right !important; }

    .text-md-center {
      text-align: center !important; } }
  @media (min-width: 992px) {
  .text-lg-left {
    text-align: left !important; }
    .text-lg-right {
      text-align: right !important; }

    .text-lg-center {
      text-align: center !important; } }
  @media (min-width: 1200px) {
  .text-xl-left {
    text-align: left !important; }
    .text-xl-right {
      text-align: right !important; }

    .text-xl-center {
      text-align: center !important; } }

.text-lowercase {
  text-transform: lowercase !important; }

.text-uppercase {
  text-transform: uppercase !important; }

.text-capitalize {
  text-transform: capitalize !important; }

.font-weight-normal {
  font-weight: normal; }

.font-weight-bold {
  font-weight: bold; }

.font-italic {
  font-style: italic; }

.text-muted {
  color: #818a91; }

.text-primary {
  color: #61259e !important; }

a.text-primary:focus, a.text-primary:hover {
  color: #481b75; }

.text-success {
  color: #24ce7b !important; }

a.text-success:focus, a.text-success:hover {
  color: #1ca361; }

.text-info {
  color: #38b5e6 !important; }

a.text-info:focus, a.text-info:hover {
  color: #1a9dd1; }

.text-warning {
  color: #f48714 !important; }

a.text-warning:focus, a.text-warning:hover {
  color: #cb6d0a; }

.text-danger {
  color: #f6303e !important; }

a.text-danger:focus, a.text-danger:hover {
  color: #e90a1a; }

.bg-inverse {
  color: #eceeef;
  background-color: #353535; }

.bg-faded {
  background-color: #f7f7f9; }

.bg-primary {
  color: #fff !important;
  background-color: #61259e !important; }

a.bg-primary:focus, a.bg-primary:hover {
  background-color: #481b75; }

.bg-success {
  color: #fff !important;
  background-color: #24ce7b !important; }

a.bg-success:focus, a.bg-success:hover {
  background-color: #1ca361; }

.bg-info {
  color: #fff !important;
  background-color: #38b5e6 !important; }

a.bg-info:focus, a.bg-info:hover {
  background-color: #1a9dd1; }

.bg-warning {
  color: #fff !important;
  background-color: #f48714 !important; }

a.bg-warning:focus, a.bg-warning:hover {
  background-color: #cb6d0a; }

.bg-danger {
  color: #fff !important;
  background-color: #f6303e !important; }

a.bg-danger:focus, a.bg-danger:hover {
  background-color: #e90a1a; }

.m-x-auto {
  margin-right: auto !important;
  margin-left: auto !important; }
  .m-a-0 {
    margin: 0 0 !important; }
  .m-t-0 {
    margin-top: 0 !important; }
  .m-r-0 {
    margin-right: 0 !important; }
  .m-b-0 {
    margin-bottom: 0 !important; }
  .m-l-0 {
    margin-left: 0 !important; }
  .m-x-0 {
    margin-right: 0 !important;
    margin-left: 0 !important; }
  .m-y-0 {
    margin-top: 0 !important;
    margin-bottom: 0 !important; }
  .m-a-1 {
    margin: 1rem 1rem !important; }
  .m-t-1 {
    margin-top: 1rem !important; }
  .m-r-1 {
    margin-right: 1rem !important; }
  .m-b-1 {
    margin-bottom: 1rem !important; }
  .m-l-1 {
    margin-left: 1rem !important; }
  .m-x-1 {
    margin-right: 1rem !important;
    margin-left: 1rem !important; }
  .m-y-1 {
    margin-top: 1rem !important;
    margin-bottom: 1rem !important; }
  .m-a-2 {
    margin: 1.5rem 1.5rem !important; }
  .m-t-2 {
    margin-top: 1.5rem !important; }
  .m-r-2 {
    margin-right: 1.5rem !important; }
  .m-b-2 {
    margin-bottom: 1.5rem !important; }
  .m-l-2 {
    margin-left: 1.5rem !important; }
  .m-x-2 {
    margin-right: 1.5rem !important;
    margin-left: 1.5rem !important; }
  .m-y-2 {
    margin-top: 1.5rem !important;
    margin-bottom: 1.5rem !important; }
  .m-a-3 {
    margin: 3rem 3rem !important; }
  .m-t-3 {
    margin-top: 3rem !important; }
  .m-r-3 {
    margin-right: 3rem !important; }
  .m-b-3 {
    margin-bottom: 3rem !important; }
  .m-l-3 {
    margin-left: 3rem !important; }
  .m-x-3 {
    margin-right: 3rem !important;
    margin-left: 3rem !important; }
  .m-y-3 {
    margin-top: 3rem !important;
    margin-bottom: 3rem !important; }
  .p-a-0 {
    padding: 0 0 !important; }
  .p-t-0 {
    padding-top: 0 !important; }
  .p-r-0 {
    padding-right: 0 !important; }
  .p-b-0 {
    padding-bottom: 0 !important; }
  .p-l-0 {
    padding-left: 0 !important; }
  .p-x-0 {
    padding-right: 0 !important;
    padding-left: 0 !important; }
  .p-y-0 {
    padding-top: 0 !important;
    padding-bottom: 0 !important; }
  .p-a-1 {
    padding: 1rem 1rem !important; }
  .p-t-1 {
    padding-top: 1rem !important; }
  .p-r-1 {
    padding-right: 1rem !important; }
  .p-b-1 {
    padding-bottom: 1rem !important; }
  .p-l-1 {
    padding-left: 1rem !important; }
  .p-x-1 {
    padding-right: 1rem !important;
    padding-left: 1rem !important; }
  .p-y-1 {
    padding-top: 1rem !important;
    padding-bottom: 1rem !important; }
  .p-a-2 {
    padding: 1.5rem 1.5rem !important; }
  .p-t-2 {
    padding-top: 1.5rem !important; }
  .p-r-2 {
    padding-right: 1.5rem !important; }
  .p-b-2 {
    padding-bottom: 1.5rem !important; }
  .p-l-2 {
    padding-left: 1.5rem !important; }
  .p-x-2 {
    padding-right: 1.5rem !important;
    padding-left: 1.5rem !important; }
  .p-y-2 {
    padding-top: 1.5rem !important;
    padding-bottom: 1.5rem !important; }
  .p-a-3 {
    padding: 3rem 3rem !important; }
  .p-t-3 {
    padding-top: 3rem !important; }
  .p-r-3 {
    padding-right: 3rem !important; }
  .p-b-3 {
    padding-bottom: 3rem !important; }
  .p-l-3 {
    padding-left: 3rem !important; }
  .p-x-3 {
    padding-right: 3rem !important;
    padding-left: 3rem !important; }
  .p-y-3 {
    padding-top: 3rem !important;
    padding-bottom: 3rem !important; }

.pos-f-t {
  position: fixed;
  top: 0;
  right: 0;
  left: 0;
  z-index: 1030; }
  .hidden-xs-up {
    display: none !important; }
  @media (max-width: 543px) {
    .hidden-xs-down {
      display: none !important; } }
  @media (min-width: 544px) {
    .hidden-sm-up {
      display: none !important; } }
  @media (max-width: 767px) {
    .hidden-sm-down {
      display: none !important; } }
  @media (min-width: 768px) {
    .hidden-md-up {
      display: none !important; } }
  @media (max-width: 991px) {
    .hidden-md-down {
      display: none !important; } }
  @media (min-width: 992px) {
    .hidden-lg-up {
      display: none !important; } }
  @media (max-width: 1199px) {
    .hidden-lg-down {
      display: none !important; } }
  @media (min-width: 1200px) {
    .hidden-xl-up {
      display: none !important; } }
  .hidden-xl-down {
    display: none !important; }

.visible-print-block {
  display: none !important; }
  @media print {
  .visible-print-block {
    display: block !important; } }

.visible-print-inline {
  display: none !important; }
  @media print {
  .visible-print-inline {
    display: inline !important; } }

.visible-print-inline-block {
  display: none !important; }
  @media print {
  .visible-print-inline-block {
    display: inline-block !important; } }

@media print {
    .hidden-print {
      display: none !important; } }

#menu {
  padding: 0;
  float: right;
  list-style: none;
  margin: 1.1em 1.5em 0 0; }
  #menu li {
    height: 100%;
    margin-left: 1em;
    position: relative;
    display: inline-block;
    color: #c5c9cc; }
  #menu li.dropdown {
    padding-right: 0.75em; }
  #menu li.dropdown:after {
    top: 25%;
    right: 0;
    content: "\f0d7";
    font-size: 0.5em;
    position: absolute;
    font-family: "FontAwesome"; }
  #menu li a {
    color: #c5c9cc; }
  #menu li .dropdown-menu {
    right: 0;
    left: auto;
    padding: 2em;
    border-radius: 0;
    min-width: 350px;
    margin-top: 1.3em;
    color: #585858; }
  #menu li .dropdown-menu a {
    color: #585858; }
  #menu li .dropdown-menu .arrow {
    left: 75%;
    top: -11px;
    width: 22px;
    height: 11px;
    margin-left: -11px;
    position: absolute;
    letter-spacing: normal;
    border-bottom: 11px solid #fff;
    border-left: 11px solid transparent;
    border-right: 11px solid transparent;
    border-top: none; }
  #menu li .dropdown-menu .media {
    margin-top: 0; }
    #menu li .dropdown-menu .media .media-heading {
      margin-bottom: 0;
      font-weight: bold; }
    #menu li .dropdown-menu .media .email {
      margin-bottom: 0.06em; }
    #menu li .dropdown-menu .media .btn {
      color: #fff; }

@media (max-width: 767px) {
  #menu {
    display: none; } }

#push {
  top: -100%;
  padding: 2em;
  position: absolute;
  background: #585858; }
  #push form {
    padding: 1.5em 0; }
  #push .modules a {
    color: #eceeef; }
  #push .modules a:hover {
    text-decoration: underline; }
  #push .dismiss {
    top: 0.5em;
    right: 1em;
    z-index: 10001;
    position: absolute;
    font-size: 1.25rem;
    color: #b5bcc0; }

body.pushing #push {
  top: 0;
  position: relative; }

#brand {
  float: left;
  width: 12em;
  height: 12em;
  background-position: center;
  background-repeat: no-repeat;
  background-color: #61259e;
  background-image: url("[[relativeurl]]/public/app/default/assets/core/pyrocms/pyrocms-theme/resources/img/icon-dark-transparent.png"); }

@media (max-width: 767px) {
  #brand {
    width: 4em;
    height: 4em;
    background-size: 45%; } }

#banner {
  min-height: 15vw;
  background-repeat: no-repeat;
  background-size: cover !important;
  background-position: center center; }

#navbar {
  height: 4em;
  background: #3e3e3e; }

#header {
  height: 8em;
  background: #353535; }

@media (max-width: 767px) {
  #header {
    height: auto;
    padding: 1em 0; } }

#footer {
  padding: 1em 3em;
  background: #e1e4e6;
  overflow: hidden; }
  #footer ul {
    margin: 0;
    padding: 0;
    list-style: none;
    display: inline-block; }
  #footer ul.pull-right {
    margin-top: -0.35em; }
  #footer ul li {
    color: #b5bcc0;
    display: inline-block;
    font-size: 0.875rem; }
  #footer ul li:not(:last-child) {
    margin-right: 0.75em; }
  #footer ul li.logo {
    margin-right: 2em; }
    #footer ul li.logo img {
      height: 2em;
      margin-top: -0.5em;
      display: inline-block; }
  #footer ul li.footprint span {
    color: #c2c9cc; }

#buttons {
  padding: 0;
  float: right;
  list-style: none;
  display: inline-block;
  margin: 4em 1.5em 0 0; }
  #buttons .btn {
    display: inline-block; }
  #buttons .btn:not(:first-of-type) {
    margin-left: 1em; }

@media (max-width: 767px) {
  #buttons {
    float: none;
    display: block;
    margin: 1em 1.5em 0; }
    #buttons .btn {
      display: block; } }

#sections {
  display: inline-block;
  margin: 1.5em 0 0 1.5em; }
  #sections ul {
    margin: 0;
    padding: 0;
    list-style: none; }
  #sections ul li {
    display: inline-block; }
  #sections ul li a {
    font-size: 1.5em;
    margin-right: 1em;
    position: relative;
    color: #eceeef;
    text-decoration: none; }
    #sections ul li a i {
      font-size: 0.5em;
      color: #eceeef; }
  #sections ul li:not(:last-child) a:after {
    top: 0;
    content: '/';
    right: -0.75em;
    position: absolute;
    margin-top: -0.15em;
    color: #646464; }
  #sections ul li.active a {
    color: #38b5e6; }
  #sections .description {
    margin-top: 0.75em;
    color: #818a91;
    display: inline-block; }

@media (max-width: 767px) {
  #sections {
    margin-top: 0;
    display: block; }
    #sections ul li a {
      font-size: 16px; }
    #sections .description {
      display: none; } }

#navigation {
  margin-top: 1.5em;
  margin-left: 1.5em;
  display: inline-block; }
  #navigation .nav {
    border-bottom: none; }
  #navigation .nav li a {
    border: none;
    color: #c5c9cc; }
    #navigation .nav li a:hover {
      color: #e0e2e4; }
    #navigation .nav li a.active {
      color: #fff;
      background: #353535; }
    #navigation .nav li a i {
      color: #686868; }

@media (max-width: 767px) {
  #navigation .nav li:not(:first-child) {
    display: none; } }

.nav.nav-sections {
  margin-bottom: 1em;
  border-bottom: 1px solid #e5e5e5; }
  .nav.nav-sections li {
    text-align: center;
    display: inline-block; }
  .nav.nav-sections li a {
    color: #3e3e3e;
    display: block;
    padding: 0.5em 2em;
    border-right: 1px solid #e5e5e5; }
    .nav.nav-sections li a:hover {
      background: #eceeef; }
  .nav.nav-sections li.active a {
    color: #fff;
    background: #38b5e6; }
  .nav.nav-pills .nav-item .nav-link {
    color: #353535; }
    .nav.nav-pills .nav-item .nav-link:hover {
      background: #eceeef; }
    .nav.nav-pills .nav-item .nav-link small {
      color: #818a91; }

.tab-pane:not(.active) {
  display: none; }

.lead {
  color: #818a91; }

pre {
  margin-bottom: 0; }

.card {
  border: none;
  position: relative;
  background: #fff;
  margin-bottom: 1.5rem;
  box-shadow: 5px 5px 0 rgba(66, 66, 66, 0.1);
  border-radius: 0; }
  .card.card-container {
    border: none;
    box-shadow: none;
    background: transparent; }

.card-corner {
  right: 0;
  bottom: 0;
  content: '';
  position: absolute;
  border-right: 20px solid;
  border-top: transparent 20px solid; }
  .card-corner.card-corner-primary {
    border-right-color: #61259e; }
  .card-corner.card-corner-success {
    border-right-color: #24ce7b; }
  .card-corner.card-corner-warning {
    border-right-color: #f48714; }
  .card-corner.card-corner-danger {
    border-right-color: #f6303e; }
  .card-corner.card-corner-info {
    border-right-color: #38b5e6; }

.card-label {
  color: #fff;
  display: inline-block;
  margin-bottom: 0.75rem;
  padding: 0.75rem 2.5rem; }
  .card-label.card-label-primary {
    background: #61259e; }
  .card-label.card-label-success {
    background: #24ce7b; }
  .card-label.card-label-warning {
    background: #f48714; }
  .card-label.card-label-danger {
    background: #f6303e; }
  .card-label.card-label-info {
    background: #38b5e6; }

.card-title {
  margin: 0;
  color: #50575c; }
  .card-title small {
    color: #818a91; }

.form .field-group {
  margin-bottom: 2rem;
  padding-bottom: 2rem;
  border-bottom: 1px solid #eceeef; }
  .form .field-group:last-child {
    margin-bottom: 0;
    padding-bottom: 0;
    border-bottom: none; }
  .form .form-group {
    margin-bottom: 0; }
  .form .form-group.has-info .c-checkbox, .form .form-group.has-info .c-radio {
    color: #38b5e6; }
  .form .form-group.has-danger .c-checkbox, .form .form-group.has-danger .c-radio {
    color: #f6303e; }
  .form .form-group.has-success .c-checkbox, .form .form-group.has-success .c-radio {
    color: #24ce7b; }
  .form .form-group.has-warning .c-checkbox, .form .form-group.has-warning .c-radio {
    color: #f48714; }
  .form .controls.top.affix {
    top: 0;
    left: 0;
    right: 0;
    position: fixed;
    border-radius: 0;
    z-index: 1050;
    border-width: 0 0 1px 0;
    padding: 0 0.9375rem; }
    .form .controls.top.affix + div {
      margin-top: 92px; }
  .form .controls .actions {
    display: inline-block; }
  .form .controls .buttons {
    float: right; }
  .form label.control-label {
    font-weight: bold; }
  .form label .required {
    color: #f6303e; }

.form-control {
  border-radius: 0; }

ul.tree {
  padding-left: 0;
  list-style: none; }
  ul.tree ul, ul.tree ol {
    list-style: none; }
  ul.tree li .card {
    padding-right: 4px;
    margin-bottom: 9px;
    border-radius: 3px;
    background-color: #fff;
    border: 2px solid transparent;
    box-shadow: 0 3px 0 rgba(0, 0, 0, 0.03); }
  ul.tree li .card .handle {
    cursor: move;
    line-height: 1;
    padding: 6px 9px;
    border-radius: 2px;
    background: #eceeef;
    color: rgba(0, 0, 0, 0.2); }
  ul.tree li .card .buttons {
    float: right;
    display: none; }
  ul.tree li .card > span {
    margin-left: 6px; }
  ul.tree li .card:hover > .buttons {
    display: block; }
  ul.tree li.dragged {
    opacity: 0.5;
    position: absolute;
    margin-bottom: 1.5; }
  ul.tree li.placeholder {
    height: 30px;
    margin-bottom: 9px;
    border: 2px dashed #818a91;
    border-radius: 0; }
/*!
 * # Semantic UI 1.12.2 - Loader
 * http://github.com/semantic-org/semantic-ui/
 *
 *
 * Copyright 2014 Contributors
 * Released under the MIT license
 * http://opensource.org/licenses/MIT
 *
 */
/*******************************
 Loader
 *******************************/
/* Standard Size */
.loader {
  top: 50%;
  left: 50%;
  margin: 0;
  z-index: 1000;
  display: none;
  position: absolute;
  text-align: center;
  -webkit-transform: translateX(-50%) translateY(-50%);
  -ms-transform: translateX(-50%) translateY(-50%);
  transform: translateX(-50%) translateY(-50%); }
/* Static Shape */
.loader:before {
  position: absolute;
  content: '';
  top: 0%;
  left: 50%;
  width: 100%;
  height: 100%;
  border-radius: 500rem;
  border: 0.2em solid rgba(0, 0, 0, 0.1); }
/* Active Shape */
.loader:after {
  position: absolute;
  content: '';
  top: 0%;
  left: 50%;
  width: 100%;
  height: 100%;
  -webkit-animation: loader 0.6s linear;
  animation: loader 0.6s linear;
  -webkit-animation-iteration-count: infinite;
  animation-iteration-count: infinite;
  border-radius: 500rem;
  border-color: #aaa transparent transparent;
  border-style: solid;
  border-width: 0.2em;
  box-shadow: 0px 0px 0px 1px transparent; }
/* Active Animation */
@-webkit-keyframes loader {
  from {
    -webkit-transform: rotate(0deg);
    transform: rotate(0deg); }

  to {
    -webkit-transform: rotate(360deg);
    transform: rotate(360deg); } }

@keyframes loader {
  from {
    -webkit-transform: rotate(0deg);
    transform: rotate(0deg); }

  to {
    -webkit-transform: rotate(360deg);
    transform: rotate(360deg); } }
/* Sizes */
.loader:before, .loader:after {
  width: 2.2585em;
  height: 2.2585em;
  margin: 0em 0em 0em -1.12925em; }

.mini.loader:before, .mini.loader:after {
  width: 1.2857em;
  height: 1.2857em;
  margin: 0em 0em 0em -0.64285em; }

.small.loader:before, .small.loader:after {
  width: 1.7142em;
  height: 1.7142em;
  margin: 0em 0em 0em -0.8571em; }

.large.loader:before, .large.loader:after {
  width: 4.5714em;
  height: 4.5714em;
  margin: 0em 0em 0em -2.2857em; }
/*-------------------
 Coupling
 --------------------*/
/* White Dimmer (Inverted) */
.inverted.dimmer .loader {
  color: rgba(0, 0, 0, 0.8); }

.inverted.dimmer .loader:before {
  border-color: rgba(0, 0, 0, 0.1); }

.inverted.dimmer .loader:after {
  border-color: #aaa transparent transparent; }
/*******************************
 Types
 *******************************/
/*-------------------
 Text
 --------------------*/
.text.loader {
  width: auto !important;
  height: auto !important;
  text-align: center;
  font-style: normal; }
/*******************************
 States
 *******************************/
.indeterminate.loader:after {
  -webkit-animation-direction: reverse;
  animation-direction: reverse;
  -webkit-animation-duration: 1.2s;
  animation-duration: 1.2s; }

.loader.active, .loader.visible {
  display: block; }

.loader.disabled, .loader.hidden {
  display: none; }
/*******************************
 Variations
 *******************************/
/*-------------------
 Sizes
 --------------------*/
/* Loader */
.inverted.dimmer .mini.loader, .mini.loader {
  width: 1.2857em;
  height: 1.2857em;
  font-size: 0.7857em; }

.inverted.dimmer .small.loader, .small.loader {
  width: 1.7142em;
  height: 1.7142em;
  font-size: 0.9285em; }

.inverted.dimmer .loader, .loader {
  width: 2.2585em;
  height: 2.2585em;
  font-size: 1em; }

.inverted.dimmer .loader.large, .loader.large {
  width: 4.5714em;
  height: 4.5714em;
  font-size: 1.1428em; }
/* Text Loader */
.mini.text.loader {
  min-width: 1.2857em;
  padding-top: 1.9857em; }

.small.text.loader {
  min-width: 1.7142em;
  padding-top: 2.4142em; }

.text.loader {
  min-width: 2.2585em;
  padding-top: 2.9585em; }

.large.text.loader {
  min-width: 4.5714em;
  padding-top: 5.2714em; }
/*-------------------
 Inverted
 --------------------*/
.inverted.loader {
  color: #fff; }

.inverted.loader:before {
  border-color: rgba(255, 255, 255, 0.15); }

.inverted.loader:after {
  border-top-color: #fff; }
/*-------------------
 Inline
 --------------------*/
.inline.loader {
  position: relative;
  vertical-align: middle;
  margin: 0em;
  left: 0em;
  top: 0em;
  -webkit-transform: none;
  -ms-transform: none;
  transform: none; }

.inline.loader.active, .inline.loader.visible {
  display: inline-block; }
/* Centered Inline */
.centered.inline.loader.active, .centered.inline.loader.visible {
  display: block; }

body.modal-open {
  overflow: visible; }

.modal {
  overflow: hidden; }
  .modal.fade .modal-dialog {
    transition: transform 0.3s ease-out; }
  .modal .modal-content {
    min-height: 100px; }

.modal-loading {
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
  z-index: 99999;
  position: absolute;
  background: rgba(255, 255, 255, 0.5); }

.modal-dialog.modal-wide {
  width: auto;
  margin: 30px; }

.table {
  margin-bottom: 0; }
  .table th, .table td {
    vertical-align: middle; }
  .table th h1:last-of-type, .table td h1:last-of-type, .table th h2:last-of-type, .table td h2:last-of-type, .table th h3:last-of-type, .table td h3:last-of-type, .table th h4:last-of-type, .table td h4:last-of-type, .table th h5:last-of-type, .table td h5:last-of-type {
    margin-bottom: 0; }
  .table > thead > tr.dragged, .table > tbody > tr.dragged, .table > tfoot > tr.dragged {
    opacity: 0.2; }
  .table > thead > tr > th, .table > tbody > tr > th, .table > tfoot > tr > th, .table > thead > tr > td, .table > tbody > tr > td, .table > tfoot > tr > td {
    vertical-align: middle; }
    .table > thead > tr > th .handle:hover, .table > tbody > tr > th .handle:hover, .table > tfoot > tr > th .handle:hover, .table > thead > tr > td .handle:hover, .table > tbody > tr > td .handle:hover, .table > tfoot > tr > td .handle:hover {
      cursor: move; }
  .table thead th {
    vertical-align: bottom;
    border-bottom: 2px solid #eceeef; }
  .table thead th a {
    color: #353535; }

.table-filters {
  padding: 1rem;
  border-top: 1px solid #eceeef; }

.no-results {
  padding: 1rem;
  border-top: 1px solid #eceeef; }
/*!
 * animate.css -http://daneden.me/animate
 * Version - 3.5.1
 * Licensed under the MIT license - http://opensource.org/licenses/MIT
 *
 * Copyright (c) 2016 Daniel Eden
 */
.animate {
  -webkit-animation-duration: 0.5s;
  animation-duration: 0.5s;
  -webkit-animation-fill-mode: both;
  animation-fill-mode: both; }

.animate.infinite {
  -webkit-animation-iteration-count: infinite;
  animation-iteration-count: infinite; }

.animate.hinge {
  -webkit-animation-duration: 2s;
  animation-duration: 2s; }

.animate.flipOutX, .animate.flipOutY, .animate.bounceIn, .animate.bounceOut {
  -webkit-animation-duration: 0.75s;
  animation-duration: 0.75s; }

@-moz-keyframes spin {
  to {
    -moz-transform: rotate(360deg); } }

@-webkit-keyframes spin {
  to {
    -webkit-transform: rotate(360deg); } }

@keyframes spin {
  to {
    transform: rotate(360deg); } }

.spin {
  -webkit-animation-timing-function: linear;
  animation-timing-function: linear;
  -webkit-animation-name: spin;
  animation-name: spin; }

@-webkit-keyframes bounce {
  from, 20%, 53%, 80%, to {
    -webkit-animation-timing-function: cubic-bezier(0.215, 0.61, 0.355, 1);
    animation-timing-function: cubic-bezier(0.215, 0.61, 0.355, 1);
    -webkit-transform: translate3d(0, 0, 0);
    transform: translate3d(0, 0, 0); }

  40%, 43% {
    -webkit-animation-timing-function: cubic-bezier(0.755, 0.05, 0.855, 0.06);
    animation-timing-function: cubic-bezier(0.755, 0.05, 0.855, 0.06);
    -webkit-transform: translate3d(0, -30px, 0);
    transform: translate3d(0, -30px, 0); }

  70% {
    -webkit-animation-timing-function: cubic-bezier(0.755, 0.05, 0.855, 0.06);
    animation-timing-function: cubic-bezier(0.755, 0.05, 0.855, 0.06);
    -webkit-transform: translate3d(0, -15px, 0);
    transform: translate3d(0, -15px, 0); }

  90% {
    -webkit-transform: translate3d(0, -4px, 0);
    transform: translate3d(0, -4px, 0); } }

@keyframes bounce {
  from, 20%, 53%, 80%, to {
    -webkit-animation-timing-function: cubic-bezier(0.215, 0.61, 0.355, 1);
    animation-timing-function: cubic-bezier(0.215, 0.61, 0.355, 1);
    -webkit-transform: translate3d(0, 0, 0);
    transform: translate3d(0, 0, 0); }

  40%, 43% {
    -webkit-animation-timing-function: cubic-bezier(0.755, 0.05, 0.855, 0.06);
    animation-timing-function: cubic-bezier(0.755, 0.05, 0.855, 0.06);
    -webkit-transform: translate3d(0, -30px, 0);
    transform: translate3d(0, -30px, 0); }

  70% {
    -webkit-animation-timing-function: cubic-bezier(0.755, 0.05, 0.855, 0.06);
    animation-timing-function: cubic-bezier(0.755, 0.05, 0.855, 0.06);
    -webkit-transform: translate3d(0, -15px, 0);
    transform: translate3d(0, -15px, 0); }

  90% {
    -webkit-transform: translate3d(0, -4px, 0);
    transform: translate3d(0, -4px, 0); } }

.bounce {
  -webkit-animation-name: bounce;
  animation-name: bounce;
  -webkit-transform-origin: center bottom;
  transform-origin: center bottom; }

@-webkit-keyframes flash {
  from, 50%, to {
    opacity: 1; }

  25%, 75% {
    opacity: 0; } }

@keyframes flash {
  from, 50%, to {
    opacity: 1; }

  25%, 75% {
    opacity: 0; } }

.flash {
  -webkit-animation-name: flash;
  animation-name: flash; }
/* originally authored by Nick Pettit - https://github.com/nickpettit/glide */
@-webkit-keyframes pulse {
  from {
    -webkit-transform: scale3d(1, 1, 1);
    transform: scale3d(1, 1, 1); }

  50% {
    -webkit-transform: scale3d(1.05, 1.05, 1.05);
    transform: scale3d(1.05, 1.05, 1.05); }

  to {
    -webkit-transform: scale3d(1, 1, 1);
    transform: scale3d(1, 1, 1); } }

@keyframes pulse {
  from {
    -webkit-transform: scale3d(1, 1, 1);
    transform: scale3d(1, 1, 1); }

  50% {
    -webkit-transform: scale3d(1.05, 1.05, 1.05);
    transform: scale3d(1.05, 1.05, 1.05); }

  to {
    -webkit-transform: scale3d(1, 1, 1);
    transform: scale3d(1, 1, 1); } }

.pulse {
  -webkit-animation-name: pulse;
  animation-name: pulse; }

@-webkit-keyframes rubberBand {
  from {
    -webkit-transform: scale3d(1, 1, 1);
    transform: scale3d(1, 1, 1); }

  30% {
    -webkit-transform: scale3d(1.25, 0.75, 1);
    transform: scale3d(1.25, 0.75, 1); }

  40% {
    -webkit-transform: scale3d(0.75, 1.25, 1);
    transform: scale3d(0.75, 1.25, 1); }

  50% {
    -webkit-transform: scale3d(1.15, 0.85, 1);
    transform: scale3d(1.15, 0.85, 1); }

  65% {
    -webkit-transform: scale3d(0.95, 1.05, 1);
    transform: scale3d(0.95, 1.05, 1); }

  75% {
    -webkit-transform: scale3d(1.05, 0.95, 1);
    transform: scale3d(1.05, 0.95, 1); }

  to {
    -webkit-transform: scale3d(1, 1, 1);
    transform: scale3d(1, 1, 1); } }

@keyframes rubberBand {
  from {
    -webkit-transform: scale3d(1, 1, 1);
    transform: scale3d(1, 1, 1); }

  30% {
    -webkit-transform: scale3d(1.25, 0.75, 1);
    transform: scale3d(1.25, 0.75, 1); }

  40% {
    -webkit-transform: scale3d(0.75, 1.25, 1);
    transform: scale3d(0.75, 1.25, 1); }

  50% {
    -webkit-transform: scale3d(1.15, 0.85, 1);
    transform: scale3d(1.15, 0.85, 1); }

  65% {
    -webkit-transform: scale3d(0.95, 1.05, 1);
    transform: scale3d(0.95, 1.05, 1); }

  75% {
    -webkit-transform: scale3d(1.05, 0.95, 1);
    transform: scale3d(1.05, 0.95, 1); }

  to {
    -webkit-transform: scale3d(1, 1, 1);
    transform: scale3d(1, 1, 1); } }

.rubberBand {
  -webkit-animation-name: rubberBand;
  animation-name: rubberBand; }

@-webkit-keyframes shake {
  from, to {
    -webkit-transform: translate3d(0, 0, 0);
    transform: translate3d(0, 0, 0); }

  10%, 30%, 50%, 70%, 90% {
    -webkit-transform: translate3d(-10px, 0, 0);
    transform: translate3d(-10px, 0, 0); }

  20%, 40%, 60%, 80% {
    -webkit-transform: translate3d(10px, 0, 0);
    transform: translate3d(10px, 0, 0); } }

@keyframes shake {
  from, to {
    -webkit-transform: translate3d(0, 0, 0);
    transform: translate3d(0, 0, 0); }

  10%, 30%, 50%, 70%, 90% {
    -webkit-transform: translate3d(-10px, 0, 0);
    transform: translate3d(-10px, 0, 0); }

  20%, 40%, 60%, 80% {
    -webkit-transform: translate3d(10px, 0, 0);
    transform: translate3d(10px, 0, 0); } }

.shake {
  -webkit-animation-name: shake;
  animation-name: shake; }

@-webkit-keyframes headShake {
  0% {
    -webkit-transform: translateX(0);
    transform: translateX(0); }

  6.5% {
    -webkit-transform: translateX(-6px) rotateY(-9deg);
    transform: translateX(-6px) rotateY(-9deg); }

  18.5% {
    -webkit-transform: translateX(5px) rotateY(7deg);
    transform: translateX(5px) rotateY(7deg); }

  31.5% {
    -webkit-transform: translateX(-3px) rotateY(-5deg);
    transform: translateX(-3px) rotateY(-5deg); }

  43.5% {
    -webkit-transform: translateX(2px) rotateY(3deg);
    transform: translateX(2px) rotateY(3deg); }

  50% {
    -webkit-transform: translateX(0);
    transform: translateX(0); } }

@keyframes headShake {
  0% {
    -webkit-transform: translateX(0);
    transform: translateX(0); }

  6.5% {
    -webkit-transform: translateX(-6px) rotateY(-9deg);
    transform: translateX(-6px) rotateY(-9deg); }

  18.5% {
    -webkit-transform: translateX(5px) rotateY(7deg);
    transform: translateX(5px) rotateY(7deg); }

  31.5% {
    -webkit-transform: translateX(-3px) rotateY(-5deg);
    transform: translateX(-3px) rotateY(-5deg); }

  43.5% {
    -webkit-transform: translateX(2px) rotateY(3deg);
    transform: translateX(2px) rotateY(3deg); }

  50% {
    -webkit-transform: translateX(0);
    transform: translateX(0); } }

.headShake {
  -webkit-animation-timing-function: ease-in-out;
  animation-timing-function: ease-in-out;
  -webkit-animation-name: headShake;
  animation-name: headShake; }

@-webkit-keyframes swing {
  20% {
    -webkit-transform: rotate3d(0, 0, 1, 15deg);
    transform: rotate3d(0, 0, 1, 15deg); }

  40% {
    -webkit-transform: rotate3d(0, 0, 1, -10deg);
    transform: rotate3d(0, 0, 1, -10deg); }

  60% {
    -webkit-transform: rotate3d(0, 0, 1, 5deg);
    transform: rotate3d(0, 0, 1, 5deg); }

  80% {
    -webkit-transform: rotate3d(0, 0, 1, -5deg);
    transform: rotate3d(0, 0, 1, -5deg); }

  to {
    -webkit-transform: rotate3d(0, 0, 1, 0deg);
    transform: rotate3d(0, 0, 1, 0deg); } }

@keyframes swing {
  20% {
    -webkit-transform: rotate3d(0, 0, 1, 15deg);
    transform: rotate3d(0, 0, 1, 15deg); }

  40% {
    -webkit-transform: rotate3d(0, 0, 1, -10deg);
    transform: rotate3d(0, 0, 1, -10deg); }

  60% {
    -webkit-transform: rotate3d(0, 0, 1, 5deg);
    transform: rotate3d(0, 0, 1, 5deg); }

  80% {
    -webkit-transform: rotate3d(0, 0, 1, -5deg);
    transform: rotate3d(0, 0, 1, -5deg); }

  to {
    -webkit-transform: rotate3d(0, 0, 1, 0deg);
    transform: rotate3d(0, 0, 1, 0deg); } }

.swing {
  -webkit-transform-origin: top center;
  transform-origin: top center;
  -webkit-animation-name: swing;
  animation-name: swing; }

@-webkit-keyframes tada {
  from {
    -webkit-transform: scale3d(1, 1, 1);
    transform: scale3d(1, 1, 1); }

  10%, 20% {
    -webkit-transform: scale3d(0.9, 0.9, 0.9) rotate3d(0, 0, 1, -3deg);
    transform: scale3d(0.9, 0.9, 0.9) rotate3d(0, 0, 1, -3deg); }

  30%, 50%, 70%, 90% {
    -webkit-transform: scale3d(1.1, 1.1, 1.1) rotate3d(0, 0, 1, 3deg);
    transform: scale3d(1.1, 1.1, 1.1) rotate3d(0, 0, 1, 3deg); }

  40%, 60%, 80% {
    -webkit-transform: scale3d(1.1, 1.1, 1.1) rotate3d(0, 0, 1, -3deg);
    transform: scale3d(1.1, 1.1, 1.1) rotate3d(0, 0, 1, -3deg); }

  to {
    -webkit-transform: scale3d(1, 1, 1);
    transform: scale3d(1, 1, 1); } }

@keyframes tada {
  from {
    -webkit-transform: scale3d(1, 1, 1);
    transform: scale3d(1, 1, 1); }

  10%, 20% {
    -webkit-transform: scale3d(0.9, 0.9, 0.9) rotate3d(0, 0, 1, -3deg);
    transform: scale3d(0.9, 0.9, 0.9) rotate3d(0, 0, 1, -3deg); }

  30%, 50%, 70%, 90% {
    -webkit-transform: scale3d(1.1, 1.1, 1.1) rotate3d(0, 0, 1, 3deg);
    transform: scale3d(1.1, 1.1, 1.1) rotate3d(0, 0, 1, 3deg); }

  40%, 60%, 80% {
    -webkit-transform: scale3d(1.1, 1.1, 1.1) rotate3d(0, 0, 1, -3deg);
    transform: scale3d(1.1, 1.1, 1.1) rotate3d(0, 0, 1, -3deg); }

  to {
    -webkit-transform: scale3d(1, 1, 1);
    transform: scale3d(1, 1, 1); } }

.tada {
  -webkit-animation-name: tada;
  animation-name: tada; }
/* originally authored by Nick Pettit - https://github.com/nickpettit/glide */
@-webkit-keyframes wobble {
  from {
    -webkit-transform: none;
    transform: none; }

  15% {
    -webkit-transform: translate3d(-25%, 0, 0) rotate3d(0, 0, 1, -5deg);
    transform: translate3d(-25%, 0, 0) rotate3d(0, 0, 1, -5deg); }

  30% {
    -webkit-transform: translate3d(20%, 0, 0) rotate3d(0, 0, 1, 3deg);
    transform: translate3d(20%, 0, 0) rotate3d(0, 0, 1, 3deg); }

  45% {
    -webkit-transform: translate3d(-15%, 0, 0) rotate3d(0, 0, 1, -3deg);
    transform: translate3d(-15%, 0, 0) rotate3d(0, 0, 1, -3deg); }

  60% {
    -webkit-transform: translate3d(10%, 0, 0) rotate3d(0, 0, 1, 2deg);
    transform: translate3d(10%, 0, 0) rotate3d(0, 0, 1, 2deg); }

  75% {
    -webkit-transform: translate3d(-5%, 0, 0) rotate3d(0, 0, 1, -1deg);
    transform: translate3d(-5%, 0, 0) rotate3d(0, 0, 1, -1deg); }

  to {
    -webkit-transform: none;
    transform: none; } }

@keyframes wobble {
  from {
    -webkit-transform: none;
    transform: none; }

  15% {
    -webkit-transform: translate3d(-25%, 0, 0) rotate3d(0, 0, 1, -5deg);
    transform: translate3d(-25%, 0, 0) rotate3d(0, 0, 1, -5deg); }

  30% {
    -webkit-transform: translate3d(20%, 0, 0) rotate3d(0, 0, 1, 3deg);
    transform: translate3d(20%, 0, 0) rotate3d(0, 0, 1, 3deg); }

  45% {
    -webkit-transform: translate3d(-15%, 0, 0) rotate3d(0, 0, 1, -3deg);
    transform: translate3d(-15%, 0, 0) rotate3d(0, 0, 1, -3deg); }

  60% {
    -webkit-transform: translate3d(10%, 0, 0) rotate3d(0, 0, 1, 2deg);
    transform: translate3d(10%, 0, 0) rotate3d(0, 0, 1, 2deg); }

  75% {
    -webkit-transform: translate3d(-5%, 0, 0) rotate3d(0, 0, 1, -1deg);
    transform: translate3d(-5%, 0, 0) rotate3d(0, 0, 1, -1deg); }

  to {
    -webkit-transform: none;
    transform: none; } }

.wobble {
  -webkit-animation-name: wobble;
  animation-name: wobble; }

@-webkit-keyframes jello {
  from, 11.1%, to {
    -webkit-transform: none;
    transform: none; }

  22.2% {
    -webkit-transform: skewX(-12.5deg) skewY(-12.5deg);
    transform: skewX(-12.5deg) skewY(-12.5deg); }

  33.3% {
    -webkit-transform: skewX(6.25deg) skewY(6.25deg);
    transform: skewX(6.25deg) skewY(6.25deg); }

  44.4% {
    -webkit-transform: skewX(-3.125deg) skewY(-3.125deg);
    transform: skewX(-3.125deg) skewY(-3.125deg); }

  55.5% {
    -webkit-transform: skewX(1.5625deg) skewY(1.5625deg);
    transform: skewX(1.5625deg) skewY(1.5625deg); }

  66.6% {
    -webkit-transform: skewX(-0.78125deg) skewY(-0.78125deg);
    transform: skewX(-0.78125deg) skewY(-0.78125deg); }

  77.7% {
    -webkit-transform: skewX(0.39063deg) skewY(0.39063deg);
    transform: skewX(0.39063deg) skewY(0.39063deg); }

  88.8% {
    -webkit-transform: skewX(-0.19531deg) skewY(-0.19531deg);
    transform: skewX(-0.19531deg) skewY(-0.19531deg); } }

@keyframes jello {
  from, 11.1%, to {
    -webkit-transform: none;
    transform: none; }

  22.2% {
    -webkit-transform: skewX(-12.5deg) skewY(-12.5deg);
    transform: skewX(-12.5deg) skewY(-12.5deg); }

  33.3% {
    -webkit-transform: skewX(6.25deg) skewY(6.25deg);
    transform: skewX(6.25deg) skewY(6.25deg); }

  44.4% {
    -webkit-transform: skewX(-3.125deg) skewY(-3.125deg);
    transform: skewX(-3.125deg) skewY(-3.125deg); }

  55.5% {
    -webkit-transform: skewX(1.5625deg) skewY(1.5625deg);
    transform: skewX(1.5625deg) skewY(1.5625deg); }

  66.6% {
    -webkit-transform: skewX(-0.78125deg) skewY(-0.78125deg);
    transform: skewX(-0.78125deg) skewY(-0.78125deg); }

  77.7% {
    -webkit-transform: skewX(0.39063deg) skewY(0.39063deg);
    transform: skewX(0.39063deg) skewY(0.39063deg); }

  88.8% {
    -webkit-transform: skewX(-0.19531deg) skewY(-0.19531deg);
    transform: skewX(-0.19531deg) skewY(-0.19531deg); } }

.jello {
  -webkit-animation-name: jello;
  animation-name: jello;
  -webkit-transform-origin: center;
  transform-origin: center; }

@-webkit-keyframes bounceIn {
  from, 20%, 40%, 60%, 80%, to {
    -webkit-animation-timing-function: cubic-bezier(0.215, 0.61, 0.355, 1);
    animation-timing-function: cubic-bezier(0.215, 0.61, 0.355, 1); }

  0% {
    opacity: 0;
    -webkit-transform: scale3d(0.3, 0.3, 0.3);
    transform: scale3d(0.3, 0.3, 0.3); }

  20% {
    -webkit-transform: scale3d(1.1, 1.1, 1.1);
    transform: scale3d(1.1, 1.1, 1.1); }

  40% {
    -webkit-transform: scale3d(0.9, 0.9, 0.9);
    transform: scale3d(0.9, 0.9, 0.9); }

  60% {
    opacity: 1;
    -webkit-transform: scale3d(1.03, 1.03, 1.03);
    transform: scale3d(1.03, 1.03, 1.03); }

  80% {
    -webkit-transform: scale3d(0.97, 0.97, 0.97);
    transform: scale3d(0.97, 0.97, 0.97); }

  to {
    opacity: 1;
    -webkit-transform: scale3d(1, 1, 1);
    transform: scale3d(1, 1, 1); } }

@keyframes bounceIn {
  from, 20%, 40%, 60%, 80%, to {
    -webkit-animation-timing-function: cubic-bezier(0.215, 0.61, 0.355, 1);
    animation-timing-function: cubic-bezier(0.215, 0.61, 0.355, 1); }

  0% {
    opacity: 0;
    -webkit-transform: scale3d(0.3, 0.3, 0.3);
    transform: scale3d(0.3, 0.3, 0.3); }

  20% {
    -webkit-transform: scale3d(1.1, 1.1, 1.1);
    transform: scale3d(1.1, 1.1, 1.1); }

  40% {
    -webkit-transform: scale3d(0.9, 0.9, 0.9);
    transform: scale3d(0.9, 0.9, 0.9); }

  60% {
    opacity: 1;
    -webkit-transform: scale3d(1.03, 1.03, 1.03);
    transform: scale3d(1.03, 1.03, 1.03); }

  80% {
    -webkit-transform: scale3d(0.97, 0.97, 0.97);
    transform: scale3d(0.97, 0.97, 0.97); }

  to {
    opacity: 1;
    -webkit-transform: scale3d(1, 1, 1);
    transform: scale3d(1, 1, 1); } }

.bounceIn {
  -webkit-animation-name: bounceIn;
  animation-name: bounceIn; }

@-webkit-keyframes bounceInDown {
  from, 60%, 75%, 90%, to {
    -webkit-animation-timing-function: cubic-bezier(0.215, 0.61, 0.355, 1);
    animation-timing-function: cubic-bezier(0.215, 0.61, 0.355, 1); }

  0% {
    opacity: 0;
    -webkit-transform: translate3d(0, -3000px, 0);
    transform: translate3d(0, -3000px, 0); }

  60% {
    opacity: 1;
    -webkit-transform: translate3d(0, 25px, 0);
    transform: translate3d(0, 25px, 0); }

  75% {
    -webkit-transform: translate3d(0, -10px, 0);
    transform: translate3d(0, -10px, 0); }

  90% {
    -webkit-transform: translate3d(0, 5px, 0);
    transform: translate3d(0, 5px, 0); }

  to {
    -webkit-transform: none;
    transform: none; } }

@keyframes bounceInDown {
  from, 60%, 75%, 90%, to {
    -webkit-animation-timing-function: cubic-bezier(0.215, 0.61, 0.355, 1);
    animation-timing-function: cubic-bezier(0.215, 0.61, 0.355, 1); }

  0% {
    opacity: 0;
    -webkit-transform: translate3d(0, -3000px, 0);
    transform: translate3d(0, -3000px, 0); }

  60% {
    opacity: 1;
    -webkit-transform: translate3d(0, 25px, 0);
    transform: translate3d(0, 25px, 0); }

  75% {
    -webkit-transform: translate3d(0, -10px, 0);
    transform: translate3d(0, -10px, 0); }

  90% {
    -webkit-transform: translate3d(0, 5px, 0);
    transform: translate3d(0, 5px, 0); }

  to {
    -webkit-transform: none;
    transform: none; } }

.bounceInDown {
  -webkit-animation-name: bounceInDown;
  animation-name: bounceInDown; }

@-webkit-keyframes bounceInLeft {
  from, 60%, 75%, 90%, to {
    -webkit-animation-timing-function: cubic-bezier(0.215, 0.61, 0.355, 1);
    animation-timing-function: cubic-bezier(0.215, 0.61, 0.355, 1); }

  0% {
    opacity: 0;
    -webkit-transform: translate3d(-3000px, 0, 0);
    transform: translate3d(-3000px, 0, 0); }

  60% {
    opacity: 1;
    -webkit-transform: translate3d(25px, 0, 0);
    transform: translate3d(25px, 0, 0); }

  75% {
    -webkit-transform: translate3d(-10px, 0, 0);
    transform: translate3d(-10px, 0, 0); }

  90% {
    -webkit-transform: translate3d(5px, 0, 0);
    transform: translate3d(5px, 0, 0); }

  to {
    -webkit-transform: none;
    transform: none; } }

@keyframes bounceInLeft {
  from, 60%, 75%, 90%, to {
    -webkit-animation-timing-function: cubic-bezier(0.215, 0.61, 0.355, 1);
    animation-timing-function: cubic-bezier(0.215, 0.61, 0.355, 1); }

  0% {
    opacity: 0;
    -webkit-transform: translate3d(-3000px, 0, 0);
    transform: translate3d(-3000px, 0, 0); }

  60% {
    opacity: 1;
    -webkit-transform: translate3d(25px, 0, 0);
    transform: translate3d(25px, 0, 0); }

  75% {
    -webkit-transform: translate3d(-10px, 0, 0);
    transform: translate3d(-10px, 0, 0); }

  90% {
    -webkit-transform: translate3d(5px, 0, 0);
    transform: translate3d(5px, 0, 0); }

  to {
    -webkit-transform: none;
    transform: none; } }

.bounceInLeft {
  -webkit-animation-name: bounceInLeft;
  animation-name: bounceInLeft; }

@-webkit-keyframes bounceInRight {
  from, 60%, 75%, 90%, to {
    -webkit-animation-timing-function: cubic-bezier(0.215, 0.61, 0.355, 1);
    animation-timing-function: cubic-bezier(0.215, 0.61, 0.355, 1); }

  from {
    opacity: 0;
    -webkit-transform: translate3d(3000px, 0, 0);
    transform: translate3d(3000px, 0, 0); }

  60% {
    opacity: 1;
    -webkit-transform: translate3d(-25px, 0, 0);
    transform: translate3d(-25px, 0, 0); }

  75% {
    -webkit-transform: translate3d(10px, 0, 0);
    transform: translate3d(10px, 0, 0); }

  90% {
    -webkit-transform: translate3d(-5px, 0, 0);
    transform: translate3d(-5px, 0, 0); }

  to {
    -webkit-transform: none;
    transform: none; } }

@keyframes bounceInRight {
  from, 60%, 75%, 90%, to {
    -webkit-animation-timing-function: cubic-bezier(0.215, 0.61, 0.355, 1);
    animation-timing-function: cubic-bezier(0.215, 0.61, 0.355, 1); }

  from {
    opacity: 0;
    -webkit-transform: translate3d(3000px, 0, 0);
    transform: translate3d(3000px, 0, 0); }

  60% {
    opacity: 1;
    -webkit-transform: translate3d(-25px, 0, 0);
    transform: translate3d(-25px, 0, 0); }

  75% {
    -webkit-transform: translate3d(10px, 0, 0);
    transform: translate3d(10px, 0, 0); }

  90% {
    -webkit-transform: translate3d(-5px, 0, 0);
    transform: translate3d(-5px, 0, 0); }

  to {
    -webkit-transform: none;
    transform: none; } }

.bounceInRight {
  -webkit-animation-name: bounceInRight;
  animation-name: bounceInRight; }

@-webkit-keyframes bounceInUp {
  from, 60%, 75%, 90%, to {
    -webkit-animation-timing-function: cubic-bezier(0.215, 0.61, 0.355, 1);
    animation-timing-function: cubic-bezier(0.215, 0.61, 0.355, 1); }

  from {
    opacity: 0;
    -webkit-transform: translate3d(0, 3000px, 0);
    transform: translate3d(0, 3000px, 0); }

  60% {
    opacity: 1;
    -webkit-transform: translate3d(0, -20px, 0);
    transform: translate3d(0, -20px, 0); }

  75% {
    -webkit-transform: translate3d(0, 10px, 0);
    transform: translate3d(0, 10px, 0); }

  90% {
    -webkit-transform: translate3d(0, -5px, 0);
    transform: translate3d(0, -5px, 0); }

  to {
    -webkit-transform: translate3d(0, 0, 0);
    transform: translate3d(0, 0, 0); } }

@keyframes bounceInUp {
  from, 60%, 75%, 90%, to {
    -webkit-animation-timing-function: cubic-bezier(0.215, 0.61, 0.355, 1);
    animation-timing-function: cubic-bezier(0.215, 0.61, 0.355, 1); }

  from {
    opacity: 0;
    -webkit-transform: translate3d(0, 3000px, 0);
    transform: translate3d(0, 3000px, 0); }

  60% {
    opacity: 1;
    -webkit-transform: translate3d(0, -20px, 0);
    transform: translate3d(0, -20px, 0); }

  75% {
    -webkit-transform: translate3d(0, 10px, 0);
    transform: translate3d(0, 10px, 0); }

  90% {
    -webkit-transform: translate3d(0, -5px, 0);
    transform: translate3d(0, -5px, 0); }

  to {
    -webkit-transform: translate3d(0, 0, 0);
    transform: translate3d(0, 0, 0); } }

.bounceInUp {
  -webkit-animation-name: bounceInUp;
  animation-name: bounceInUp; }

@-webkit-keyframes bounceOut {
  20% {
    -webkit-transform: scale3d(0.9, 0.9, 0.9);
    transform: scale3d(0.9, 0.9, 0.9); }

  50%, 55% {
    opacity: 1;
    -webkit-transform: scale3d(1.1, 1.1, 1.1);
    transform: scale3d(1.1, 1.1, 1.1); }

  to {
    opacity: 0;
    -webkit-transform: scale3d(0.3, 0.3, 0.3);
    transform: scale3d(0.3, 0.3, 0.3); } }

@keyframes bounceOut {
  20% {
    -webkit-transform: scale3d(0.9, 0.9, 0.9);
    transform: scale3d(0.9, 0.9, 0.9); }

  50%, 55% {
    opacity: 1;
    -webkit-transform: scale3d(1.1, 1.1, 1.1);
    transform: scale3d(1.1, 1.1, 1.1); }

  to {
    opacity: 0;
    -webkit-transform: scale3d(0.3, 0.3, 0.3);
    transform: scale3d(0.3, 0.3, 0.3); } }

.bounceOut {
  -webkit-animation-name: bounceOut;
  animation-name: bounceOut; }

@-webkit-keyframes bounceOutDown {
  20% {
    -webkit-transform: translate3d(0, 10px, 0);
    transform: translate3d(0, 10px, 0); }

  40%, 45% {
    opacity: 1;
    -webkit-transform: translate3d(0, -20px, 0);
    transform: translate3d(0, -20px, 0); }

  to {
    opacity: 0;
    -webkit-transform: translate3d(0, 2000px, 0);
    transform: translate3d(0, 2000px, 0); } }

@keyframes bounceOutDown {
  20% {
    -webkit-transform: translate3d(0, 10px, 0);
    transform: translate3d(0, 10px, 0); }

  40%, 45% {
    opacity: 1;
    -webkit-transform: translate3d(0, -20px, 0);
    transform: translate3d(0, -20px, 0); }

  to {
    opacity: 0;
    -webkit-transform: translate3d(0, 2000px, 0);
    transform: translate3d(0, 2000px, 0); } }

.bounceOutDown {
  -webkit-animation-name: bounceOutDown;
  animation-name: bounceOutDown; }

@-webkit-keyframes bounceOutLeft {
  20% {
    opacity: 1;
    -webkit-transform: translate3d(20px, 0, 0);
    transform: translate3d(20px, 0, 0); }

  to {
    opacity: 0;
    -webkit-transform: translate3d(-2000px, 0, 0);
    transform: translate3d(-2000px, 0, 0); } }

@keyframes bounceOutLeft {
  20% {
    opacity: 1;
    -webkit-transform: translate3d(20px, 0, 0);
    transform: translate3d(20px, 0, 0); }

  to {
    opacity: 0;
    -webkit-transform: translate3d(-2000px, 0, 0);
    transform: translate3d(-2000px, 0, 0); } }

.bounceOutLeft {
  -webkit-animation-name: bounceOutLeft;
  animation-name: bounceOutLeft; }

@-webkit-keyframes bounceOutRight {
  20% {
    opacity: 1;
    -webkit-transform: translate3d(-20px, 0, 0);
    transform: translate3d(-20px, 0, 0); }

  to {
    opacity: 0;
    -webkit-transform: translate3d(2000px, 0, 0);
    transform: translate3d(2000px, 0, 0); } }

@keyframes bounceOutRight {
  20% {
    opacity: 1;
    -webkit-transform: translate3d(-20px, 0, 0);
    transform: translate3d(-20px, 0, 0); }

  to {
    opacity: 0;
    -webkit-transform: translate3d(2000px, 0, 0);
    transform: translate3d(2000px, 0, 0); } }

.bounceOutRight {
  -webkit-animation-name: bounceOutRight;
  animation-name: bounceOutRight; }

@-webkit-keyframes bounceOutUp {
  20% {
    -webkit-transform: translate3d(0, -10px, 0);
    transform: translate3d(0, -10px, 0); }

  40%, 45% {
    opacity: 1;
    -webkit-transform: translate3d(0, 20px, 0);
    transform: translate3d(0, 20px, 0); }

  to {
    opacity: 0;
    -webkit-transform: translate3d(0, -2000px, 0);
    transform: translate3d(0, -2000px, 0); } }

@keyframes bounceOutUp {
  20% {
    -webkit-transform: translate3d(0, -10px, 0);
    transform: translate3d(0, -10px, 0); }

  40%, 45% {
    opacity: 1;
    -webkit-transform: translate3d(0, 20px, 0);
    transform: translate3d(0, 20px, 0); }

  to {
    opacity: 0;
    -webkit-transform: translate3d(0, -2000px, 0);
    transform: translate3d(0, -2000px, 0); } }

.bounceOutUp {
  -webkit-animation-name: bounceOutUp;
  animation-name: bounceOutUp; }

@-webkit-keyframes fadeIn {
  from {
    opacity: 0; }

  to {
    opacity: 1; } }

@keyframes fadeIn {
  from {
    opacity: 0; }

  to {
    opacity: 1; } }

.fadeIn {
  -webkit-animation-name: fadeIn;
  animation-name: fadeIn; }

@-webkit-keyframes fadeInDown {
  from {
    opacity: 0;
    -webkit-transform: translate3d(0, -100%, 0);
    transform: translate3d(0, -100%, 0); }

  to {
    opacity: 1;
    -webkit-transform: none;
    transform: none; } }

@keyframes fadeInDown {
  from {
    opacity: 0;
    -webkit-transform: translate3d(0, -100%, 0);
    transform: translate3d(0, -100%, 0); }

  to {
    opacity: 1;
    -webkit-transform: none;
    transform: none; } }

.fadeInDown {
  -webkit-animation-name: fadeInDown;
  animation-name: fadeInDown; }

@-webkit-keyframes fadeInDownBig {
  from {
    opacity: 0;
    -webkit-transform: translate3d(0, -2000px, 0);
    transform: translate3d(0, -2000px, 0); }

  to {
    opacity: 1;
    -webkit-transform: none;
    transform: none; } }

@keyframes fadeInDownBig {
  from {
    opacity: 0;
    -webkit-transform: translate3d(0, -2000px, 0);
    transform: translate3d(0, -2000px, 0); }

  to {
    opacity: 1;
    -webkit-transform: none;
    transform: none; } }

.fadeInDownBig {
  -webkit-animation-name: fadeInDownBig;
  animation-name: fadeInDownBig; }

@-webkit-keyframes fadeInLeft {
  from {
    opacity: 0;
    -webkit-transform: translate3d(-100%, 0, 0);
    transform: translate3d(-100%, 0, 0); }

  to {
    opacity: 1;
    -webkit-transform: none;
    transform: none; } }

@keyframes fadeInLeft {
  from {
    opacity: 0;
    -webkit-transform: translate3d(-100%, 0, 0);
    transform: translate3d(-100%, 0, 0); }

  to {
    opacity: 1;
    -webkit-transform: none;
    transform: none; } }

.fadeInLeft {
  -webkit-animation-name: fadeInLeft;
  animation-name: fadeInLeft; }

@-webkit-keyframes fadeInLeftBig {
  from {
    opacity: 0;
    -webkit-transform: translate3d(-2000px, 0, 0);
    transform: translate3d(-2000px, 0, 0); }

  to {
    opacity: 1;
    -webkit-transform: none;
    transform: none; } }

@keyframes fadeInLeftBig {
  from {
    opacity: 0;
    -webkit-transform: translate3d(-2000px, 0, 0);
    transform: translate3d(-2000px, 0, 0); }

  to {
    opacity: 1;
    -webkit-transform: none;
    transform: none; } }

.fadeInLeftBig {
  -webkit-animation-name: fadeInLeftBig;
  animation-name: fadeInLeftBig; }

@-webkit-keyframes fadeInRight {
  from {
    opacity: 0;
    -webkit-transform: translate3d(100%, 0, 0);
    transform: translate3d(100%, 0, 0); }

  to {
    opacity: 1;
    -webkit-transform: none;
    transform: none; } }

@keyframes fadeInRight {
  from {
    opacity: 0;
    -webkit-transform: translate3d(100%, 0, 0);
    transform: translate3d(100%, 0, 0); }

  to {
    opacity: 1;
    -webkit-transform: none;
    transform: none; } }

.fadeInRight {
  -webkit-animation-name: fadeInRight;
  animation-name: fadeInRight; }

@-webkit-keyframes fadeInRightBig {
  from {
    opacity: 0;
    -webkit-transform: translate3d(2000px, 0, 0);
    transform: translate3d(2000px, 0, 0); }

  to {
    opacity: 1;
    -webkit-transform: none;
    transform: none; } }

@keyframes fadeInRightBig {
  from {
    opacity: 0;
    -webkit-transform: translate3d(2000px, 0, 0);
    transform: translate3d(2000px, 0, 0); }

  to {
    opacity: 1;
    -webkit-transform: none;
    transform: none; } }

.fadeInRightBig {
  -webkit-animation-name: fadeInRightBig;
  animation-name: fadeInRightBig; }

@-webkit-keyframes fadeInUp {
  from {
    opacity: 0;
    -webkit-transform: translate3d(0, 100%, 0);
    transform: translate3d(0, 100%, 0); }

  to {
    opacity: 1;
    -webkit-transform: none;
    transform: none; } }

@keyframes fadeInUp {
  from {
    opacity: 0;
    -webkit-transform: translate3d(0, 100%, 0);
    transform: translate3d(0, 100%, 0); }

  to {
    opacity: 1;
    -webkit-transform: none;
    transform: none; } }

.fadeInUp {
  -webkit-animation-name: fadeInUp;
  animation-name: fadeInUp; }

@-webkit-keyframes fadeInUpBig {
  from {
    opacity: 0;
    -webkit-transform: translate3d(0, 2000px, 0);
    transform: translate3d(0, 2000px, 0); }

  to {
    opacity: 1;
    -webkit-transform: none;
    transform: none; } }

@keyframes fadeInUpBig {
  from {
    opacity: 0;
    -webkit-transform: translate3d(0, 2000px, 0);
    transform: translate3d(0, 2000px, 0); }

  to {
    opacity: 1;
    -webkit-transform: none;
    transform: none; } }

.fadeInUpBig {
  -webkit-animation-name: fadeInUpBig;
  animation-name: fadeInUpBig; }

@-webkit-keyframes fadeOut {
  from {
    opacity: 1; }

  to {
    opacity: 0; } }

@keyframes fadeOut {
  from {
    opacity: 1; }

  to {
    opacity: 0; } }

.fadeOut {
  -webkit-animation-name: fadeOut;
  animation-name: fadeOut; }

@-webkit-keyframes fadeOutDown {
  from {
    opacity: 1; }

  to {
    opacity: 0;
    -webkit-transform: translate3d(0, 100%, 0);
    transform: translate3d(0, 100%, 0); } }

@keyframes fadeOutDown {
  from {
    opacity: 1; }

  to {
    opacity: 0;
    -webkit-transform: translate3d(0, 100%, 0);
    transform: translate3d(0, 100%, 0); } }

.fadeOutDown {
  -webkit-animation-name: fadeOutDown;
  animation-name: fadeOutDown; }

@-webkit-keyframes fadeOutDownBig {
  from {
    opacity: 1; }

  to {
    opacity: 0;
    -webkit-transform: translate3d(0, 2000px, 0);
    transform: translate3d(0, 2000px, 0); } }

@keyframes fadeOutDownBig {
  from {
    opacity: 1; }

  to {
    opacity: 0;
    -webkit-transform: translate3d(0, 2000px, 0);
    transform: translate3d(0, 2000px, 0); } }

.fadeOutDownBig {
  -webkit-animation-name: fadeOutDownBig;
  animation-name: fadeOutDownBig; }

@-webkit-keyframes fadeOutLeft {
  from {
    opacity: 1; }

  to {
    opacity: 0;
    -webkit-transform: translate3d(-100%, 0, 0);
    transform: translate3d(-100%, 0, 0); } }

@keyframes fadeOutLeft {
  from {
    opacity: 1; }

  to {
    opacity: 0;
    -webkit-transform: translate3d(-100%, 0, 0);
    transform: translate3d(-100%, 0, 0); } }

.fadeOutLeft {
  -webkit-animation-name: fadeOutLeft;
  animation-name: fadeOutLeft; }

@-webkit-keyframes fadeOutLeftBig {
  from {
    opacity: 1; }

  to {
    opacity: 0;
    -webkit-transform: translate3d(-2000px, 0, 0);
    transform: translate3d(-2000px, 0, 0); } }

@keyframes fadeOutLeftBig {
  from {
    opacity: 1; }

  to {
    opacity: 0;
    -webkit-transform: translate3d(-2000px, 0, 0);
    transform: translate3d(-2000px, 0, 0); } }

.fadeOutLeftBig {
  -webkit-animation-name: fadeOutLeftBig;
  animation-name: fadeOutLeftBig; }

@-webkit-keyframes fadeOutRight {
  from {
    opacity: 1; }

  to {
    opacity: 0;
    -webkit-transform: translate3d(100%, 0, 0);
    transform: translate3d(100%, 0, 0); } }

@keyframes fadeOutRight {
  from {
    opacity: 1; }

  to {
    opacity: 0;
    -webkit-transform: translate3d(100%, 0, 0);
    transform: translate3d(100%, 0, 0); } }

.fadeOutRight {
  -webkit-animation-name: fadeOutRight;
  animation-name: fadeOutRight; }

@-webkit-keyframes fadeOutRightBig {
  from {
    opacity: 1; }

  to {
    opacity: 0;
    -webkit-transform: translate3d(2000px, 0, 0);
    transform: translate3d(2000px, 0, 0); } }

@keyframes fadeOutRightBig {
  from {
    opacity: 1; }

  to {
    opacity: 0;
    -webkit-transform: translate3d(2000px, 0, 0);
    transform: translate3d(2000px, 0, 0); } }

.fadeOutRightBig {
  -webkit-animation-name: fadeOutRightBig;
  animation-name: fadeOutRightBig; }

@-webkit-keyframes fadeOutUp {
  from {
    opacity: 1; }

  to {
    opacity: 0;
    -webkit-transform: translate3d(0, -100%, 0);
    transform: translate3d(0, -100%, 0); } }

@keyframes fadeOutUp {
  from {
    opacity: 1; }

  to {
    opacity: 0;
    -webkit-transform: translate3d(0, -100%, 0);
    transform: translate3d(0, -100%, 0); } }

.fadeOutUp {
  -webkit-animation-name: fadeOutUp;
  animation-name: fadeOutUp; }

@-webkit-keyframes fadeOutUpBig {
  from {
    opacity: 1; }

  to {
    opacity: 0;
    -webkit-transform: translate3d(0, -2000px, 0);
    transform: translate3d(0, -2000px, 0); } }

@keyframes fadeOutUpBig {
  from {
    opacity: 1; }

  to {
    opacity: 0;
    -webkit-transform: translate3d(0, -2000px, 0);
    transform: translate3d(0, -2000px, 0); } }

.fadeOutUpBig {
  -webkit-animation-name: fadeOutUpBig;
  animation-name: fadeOutUpBig; }

@-webkit-keyframes flip {
  from {
    -webkit-transform: perspective(400px) rotate3d(0, 1, 0, -360deg);
    transform: perspective(400px) rotate3d(0, 1, 0, -360deg);
    -webkit-animation-timing-function: ease-out;
    animation-timing-function: ease-out; }

  40% {
    -webkit-transform: perspective(400px) translate3d(0, 0, 150px) rotate3d(0, 1, 0, -190deg);
    transform: perspective(400px) translate3d(0, 0, 150px) rotate3d(0, 1, 0, -190deg);
    -webkit-animation-timing-function: ease-out;
    animation-timing-function: ease-out; }

  50% {
    -webkit-transform: perspective(400px) translate3d(0, 0, 150px) rotate3d(0, 1, 0, -170deg);
    transform: perspective(400px) translate3d(0, 0, 150px) rotate3d(0, 1, 0, -170deg);
    -webkit-animation-timing-function: ease-in;
    animation-timing-function: ease-in; }

  80% {
    -webkit-transform: perspective(400px) scale3d(0.95, 0.95, 0.95);
    transform: perspective(400px) scale3d(0.95, 0.95, 0.95);
    -webkit-animation-timing-function: ease-in;
    animation-timing-function: ease-in; }

  to {
    -webkit-transform: perspective(400px);
    transform: perspective(400px);
    -webkit-animation-timing-function: ease-in;
    animation-timing-function: ease-in; } }

@keyframes flip {
  from {
    -webkit-transform: perspective(400px) rotate3d(0, 1, 0, -360deg);
    transform: perspective(400px) rotate3d(0, 1, 0, -360deg);
    -webkit-animation-timing-function: ease-out;
    animation-timing-function: ease-out; }

  40% {
    -webkit-transform: perspective(400px) translate3d(0, 0, 150px) rotate3d(0, 1, 0, -190deg);
    transform: perspective(400px) translate3d(0, 0, 150px) rotate3d(0, 1, 0, -190deg);
    -webkit-animation-timing-function: ease-out;
    animation-timing-function: ease-out; }

  50% {
    -webkit-transform: perspective(400px) translate3d(0, 0, 150px) rotate3d(0, 1, 0, -170deg);
    transform: perspective(400px) translate3d(0, 0, 150px) rotate3d(0, 1, 0, -170deg);
    -webkit-animation-timing-function: ease-in;
    animation-timing-function: ease-in; }

  80% {
    -webkit-transform: perspective(400px) scale3d(0.95, 0.95, 0.95);
    transform: perspective(400px) scale3d(0.95, 0.95, 0.95);
    -webkit-animation-timing-function: ease-in;
    animation-timing-function: ease-in; }

  to {
    -webkit-transform: perspective(400px);
    transform: perspective(400px);
    -webkit-animation-timing-function: ease-in;
    animation-timing-function: ease-in; } }

.animate.flip {
  -webkit-backface-visibility: visible;
  backface-visibility: visible;
  -webkit-animation-name: flip;
  animation-name: flip; }

@-webkit-keyframes flipInX {
  from {
    -webkit-transform: perspective(400px) rotate3d(1, 0, 0, 90deg);
    transform: perspective(400px) rotate3d(1, 0, 0, 90deg);
    -webkit-animation-timing-function: ease-in;
    animation-timing-function: ease-in;
    opacity: 0; }

  40% {
    -webkit-transform: perspective(400px) rotate3d(1, 0, 0, -20deg);
    transform: perspective(400px) rotate3d(1, 0, 0, -20deg);
    -webkit-animation-timing-function: ease-in;
    animation-timing-function: ease-in; }

  60% {
    -webkit-transform: perspective(400px) rotate3d(1, 0, 0, 10deg);
    transform: perspective(400px) rotate3d(1, 0, 0, 10deg);
    opacity: 1; }

  80% {
    -webkit-transform: perspective(400px) rotate3d(1, 0, 0, -5deg);
    transform: perspective(400px) rotate3d(1, 0, 0, -5deg); }

  to {
    -webkit-transform: perspective(400px);
    transform: perspective(400px); } }

@keyframes flipInX {
  from {
    -webkit-transform: perspective(400px) rotate3d(1, 0, 0, 90deg);
    transform: perspective(400px) rotate3d(1, 0, 0, 90deg);
    -webkit-animation-timing-function: ease-in;
    animation-timing-function: ease-in;
    opacity: 0; }

  40% {
    -webkit-transform: perspective(400px) rotate3d(1, 0, 0, -20deg);
    transform: perspective(400px) rotate3d(1, 0, 0, -20deg);
    -webkit-animation-timing-function: ease-in;
    animation-timing-function: ease-in; }

  60% {
    -webkit-transform: perspective(400px) rotate3d(1, 0, 0, 10deg);
    transform: perspective(400px) rotate3d(1, 0, 0, 10deg);
    opacity: 1; }

  80% {
    -webkit-transform: perspective(400px) rotate3d(1, 0, 0, -5deg);
    transform: perspective(400px) rotate3d(1, 0, 0, -5deg); }

  to {
    -webkit-transform: perspective(400px);
    transform: perspective(400px); } }

.flipInX {
  -webkit-backface-visibility: visible !important;
  backface-visibility: visible !important;
  -webkit-animation-name: flipInX;
  animation-name: flipInX; }

@-webkit-keyframes flipInY {
  from {
    -webkit-transform: perspective(400px) rotate3d(0, 1, 0, 90deg);
    transform: perspective(400px) rotate3d(0, 1, 0, 90deg);
    -webkit-animation-timing-function: ease-in;
    animation-timing-function: ease-in;
    opacity: 0; }

  40% {
    -webkit-transform: perspective(400px) rotate3d(0, 1, 0, -20deg);
    transform: perspective(400px) rotate3d(0, 1, 0, -20deg);
    -webkit-animation-timing-function: ease-in;
    animation-timing-function: ease-in; }

  60% {
    -webkit-transform: perspective(400px) rotate3d(0, 1, 0, 10deg);
    transform: perspective(400px) rotate3d(0, 1, 0, 10deg);
    opacity: 1; }

  80% {
    -webkit-transform: perspective(400px) rotate3d(0, 1, 0, -5deg);
    transform: perspective(400px) rotate3d(0, 1, 0, -5deg); }

  to {
    -webkit-transform: perspective(400px);
    transform: perspective(400px); } }

@keyframes flipInY {
  from {
    -webkit-transform: perspective(400px) rotate3d(0, 1, 0, 90deg);
    transform: perspective(400px) rotate3d(0, 1, 0, 90deg);
    -webkit-animation-timing-function: ease-in;
    animation-timing-function: ease-in;
    opacity: 0; }

  40% {
    -webkit-transform: perspective(400px) rotate3d(0, 1, 0, -20deg);
    transform: perspective(400px) rotate3d(0, 1, 0, -20deg);
    -webkit-animation-timing-function: ease-in;
    animation-timing-function: ease-in; }

  60% {
    -webkit-transform: perspective(400px) rotate3d(0, 1, 0, 10deg);
    transform: perspective(400px) rotate3d(0, 1, 0, 10deg);
    opacity: 1; }

  80% {
    -webkit-transform: perspective(400px) rotate3d(0, 1, 0, -5deg);
    transform: perspective(400px) rotate3d(0, 1, 0, -5deg); }

  to {
    -webkit-transform: perspective(400px);
    transform: perspective(400px); } }

.flipInY {
  -webkit-backface-visibility: visible !important;
  backface-visibility: visible !important;
  -webkit-animation-name: flipInY;
  animation-name: flipInY; }

@-webkit-keyframes flipOutX {
  from {
    -webkit-transform: perspective(400px);
    transform: perspective(400px); }

  30% {
    -webkit-transform: perspective(400px) rotate3d(1, 0, 0, -20deg);
    transform: perspective(400px) rotate3d(1, 0, 0, -20deg);
    opacity: 1; }

  to {
    -webkit-transform: perspective(400px) rotate3d(1, 0, 0, 90deg);
    transform: perspective(400px) rotate3d(1, 0, 0, 90deg);
    opacity: 0; } }

@keyframes flipOutX {
  from {
    -webkit-transform: perspective(400px);
    transform: perspective(400px); }

  30% {
    -webkit-transform: perspective(400px) rotate3d(1, 0, 0, -20deg);
    transform: perspective(400px) rotate3d(1, 0, 0, -20deg);
    opacity: 1; }

  to {
    -webkit-transform: perspective(400px) rotate3d(1, 0, 0, 90deg);
    transform: perspective(400px) rotate3d(1, 0, 0, 90deg);
    opacity: 0; } }

.flipOutX {
  -webkit-animation-name: flipOutX;
  animation-name: flipOutX;
  -webkit-backface-visibility: visible !important;
  backface-visibility: visible !important; }

@-webkit-keyframes flipOutY {
  from {
    -webkit-transform: perspective(400px);
    transform: perspective(400px); }

  30% {
    -webkit-transform: perspective(400px) rotate3d(0, 1, 0, -15deg);
    transform: perspective(400px) rotate3d(0, 1, 0, -15deg);
    opacity: 1; }

  to {
    -webkit-transform: perspective(400px) rotate3d(0, 1, 0, 90deg);
    transform: perspective(400px) rotate3d(0, 1, 0, 90deg);
    opacity: 0; } }

@keyframes flipOutY {
  from {
    -webkit-transform: perspective(400px);
    transform: perspective(400px); }

  30% {
    -webkit-transform: perspective(400px) rotate3d(0, 1, 0, -15deg);
    transform: perspective(400px) rotate3d(0, 1, 0, -15deg);
    opacity: 1; }

  to {
    -webkit-transform: perspective(400px) rotate3d(0, 1, 0, 90deg);
    transform: perspective(400px) rotate3d(0, 1, 0, 90deg);
    opacity: 0; } }

.flipOutY {
  -webkit-backface-visibility: visible !important;
  backface-visibility: visible !important;
  -webkit-animation-name: flipOutY;
  animation-name: flipOutY; }

@-webkit-keyframes lightSpeedIn {
  from {
    -webkit-transform: translate3d(100%, 0, 0) skewX(-30deg);
    transform: translate3d(100%, 0, 0) skewX(-30deg);
    opacity: 0; }

  60% {
    -webkit-transform: skewX(20deg);
    transform: skewX(20deg);
    opacity: 1; }

  80% {
    -webkit-transform: skewX(-5deg);
    transform: skewX(-5deg);
    opacity: 1; }

  to {
    -webkit-transform: none;
    transform: none;
    opacity: 1; } }

@keyframes lightSpeedIn {
  from {
    -webkit-transform: translate3d(100%, 0, 0) skewX(-30deg);
    transform: translate3d(100%, 0, 0) skewX(-30deg);
    opacity: 0; }

  60% {
    -webkit-transform: skewX(20deg);
    transform: skewX(20deg);
    opacity: 1; }

  80% {
    -webkit-transform: skewX(-5deg);
    transform: skewX(-5deg);
    opacity: 1; }

  to {
    -webkit-transform: none;
    transform: none;
    opacity: 1; } }

.lightSpeedIn {
  -webkit-animation-name: lightSpeedIn;
  animation-name: lightSpeedIn;
  -webkit-animation-timing-function: ease-out;
  animation-timing-function: ease-out; }

@-webkit-keyframes lightSpeedOut {
  from {
    opacity: 1; }

  to {
    -webkit-transform: translate3d(100%, 0, 0) skewX(30deg);
    transform: translate3d(100%, 0, 0) skewX(30deg);
    opacity: 0; } }

@keyframes lightSpeedOut {
  from {
    opacity: 1; }

  to {
    -webkit-transform: translate3d(100%, 0, 0) skewX(30deg);
    transform: translate3d(100%, 0, 0) skewX(30deg);
    opacity: 0; } }

.lightSpeedOut {
  -webkit-animation-name: lightSpeedOut;
  animation-name: lightSpeedOut;
  -webkit-animation-timing-function: ease-in;
  animation-timing-function: ease-in; }

@-webkit-keyframes rotateIn {
  from {
    -webkit-transform-origin: center;
    transform-origin: center;
    -webkit-transform: rotate3d(0, 0, 1, -200deg);
    transform: rotate3d(0, 0, 1, -200deg);
    opacity: 0; }

  to {
    -webkit-transform-origin: center;
    transform-origin: center;
    -webkit-transform: none;
    transform: none;
    opacity: 1; } }

@keyframes rotateIn {
  from {
    -webkit-transform-origin: center;
    transform-origin: center;
    -webkit-transform: rotate3d(0, 0, 1, -200deg);
    transform: rotate3d(0, 0, 1, -200deg);
    opacity: 0; }

  to {
    -webkit-transform-origin: center;
    transform-origin: center;
    -webkit-transform: none;
    transform: none;
    opacity: 1; } }

.rotateIn {
  -webkit-animation-name: rotateIn;
  animation-name: rotateIn; }

@-webkit-keyframes rotateInDownLeft {
  from {
    -webkit-transform-origin: left bottom;
    transform-origin: left bottom;
    -webkit-transform: rotate3d(0, 0, 1, -45deg);
    transform: rotate3d(0, 0, 1, -45deg);
    opacity: 0; }

  to {
    -webkit-transform-origin: left bottom;
    transform-origin: left bottom;
    -webkit-transform: none;
    transform: none;
    opacity: 1; } }

@keyframes rotateInDownLeft {
  from {
    -webkit-transform-origin: left bottom;
    transform-origin: left bottom;
    -webkit-transform: rotate3d(0, 0, 1, -45deg);
    transform: rotate3d(0, 0, 1, -45deg);
    opacity: 0; }

  to {
    -webkit-transform-origin: left bottom;
    transform-origin: left bottom;
    -webkit-transform: none;
    transform: none;
    opacity: 1; } }

.rotateInDownLeft {
  -webkit-animation-name: rotateInDownLeft;
  animation-name: rotateInDownLeft; }

@-webkit-keyframes rotateInDownRight {
  from {
    -webkit-transform-origin: right bottom;
    transform-origin: right bottom;
    -webkit-transform: rotate3d(0, 0, 1, 45deg);
    transform: rotate3d(0, 0, 1, 45deg);
    opacity: 0; }

  to {
    -webkit-transform-origin: right bottom;
    transform-origin: right bottom;
    -webkit-transform: none;
    transform: none;
    opacity: 1; } }

@keyframes rotateInDownRight {
  from {
    -webkit-transform-origin: right bottom;
    transform-origin: right bottom;
    -webkit-transform: rotate3d(0, 0, 1, 45deg);
    transform: rotate3d(0, 0, 1, 45deg);
    opacity: 0; }

  to {
    -webkit-transform-origin: right bottom;
    transform-origin: right bottom;
    -webkit-transform: none;
    transform: none;
    opacity: 1; } }

.rotateInDownRight {
  -webkit-animation-name: rotateInDownRight;
  animation-name: rotateInDownRight; }

@-webkit-keyframes rotateInUpLeft {
  from {
    -webkit-transform-origin: left bottom;
    transform-origin: left bottom;
    -webkit-transform: rotate3d(0, 0, 1, 45deg);
    transform: rotate3d(0, 0, 1, 45deg);
    opacity: 0; }

  to {
    -webkit-transform-origin: left bottom;
    transform-origin: left bottom;
    -webkit-transform: none;
    transform: none;
    opacity: 1; } }

@keyframes rotateInUpLeft {
  from {
    -webkit-transform-origin: left bottom;
    transform-origin: left bottom;
    -webkit-transform: rotate3d(0, 0, 1, 45deg);
    transform: rotate3d(0, 0, 1, 45deg);
    opacity: 0; }

  to {
    -webkit-transform-origin: left bottom;
    transform-origin: left bottom;
    -webkit-transform: none;
    transform: none;
    opacity: 1; } }

.rotateInUpLeft {
  -webkit-animation-name: rotateInUpLeft;
  animation-name: rotateInUpLeft; }

@-webkit-keyframes rotateInUpRight {
  from {
    -webkit-transform-origin: right bottom;
    transform-origin: right bottom;
    -webkit-transform: rotate3d(0, 0, 1, -90deg);
    transform: rotate3d(0, 0, 1, -90deg);
    opacity: 0; }

  to {
    -webkit-transform-origin: right bottom;
    transform-origin: right bottom;
    -webkit-transform: none;
    transform: none;
    opacity: 1; } }

@keyframes rotateInUpRight {
  from {
    -webkit-transform-origin: right bottom;
    transform-origin: right bottom;
    -webkit-transform: rotate3d(0, 0, 1, -90deg);
    transform: rotate3d(0, 0, 1, -90deg);
    opacity: 0; }

  to {
    -webkit-transform-origin: right bottom;
    transform-origin: right bottom;
    -webkit-transform: none;
    transform: none;
    opacity: 1; } }

.rotateInUpRight {
  -webkit-animation-name: rotateInUpRight;
  animation-name: rotateInUpRight; }

@-webkit-keyframes rotateOut {
  from {
    -webkit-transform-origin: center;
    transform-origin: center;
    opacity: 1; }

  to {
    -webkit-transform-origin: center;
    transform-origin: center;
    -webkit-transform: rotate3d(0, 0, 1, 200deg);
    transform: rotate3d(0, 0, 1, 200deg);
    opacity: 0; } }

@keyframes rotateOut {
  from {
    -webkit-transform-origin: center;
    transform-origin: center;
    opacity: 1; }

  to {
    -webkit-transform-origin: center;
    transform-origin: center;
    -webkit-transform: rotate3d(0, 0, 1, 200deg);
    transform: rotate3d(0, 0, 1, 200deg);
    opacity: 0; } }

.rotateOut {
  -webkit-animation-name: rotateOut;
  animation-name: rotateOut; }

@-webkit-keyframes rotateOutDownLeft {
  from {
    -webkit-transform-origin: left bottom;
    transform-origin: left bottom;
    opacity: 1; }

  to {
    -webkit-transform-origin: left bottom;
    transform-origin: left bottom;
    -webkit-transform: rotate3d(0, 0, 1, 45deg);
    transform: rotate3d(0, 0, 1, 45deg);
    opacity: 0; } }

@keyframes rotateOutDownLeft {
  from {
    -webkit-transform-origin: left bottom;
    transform-origin: left bottom;
    opacity: 1; }

  to {
    -webkit-transform-origin: left bottom;
    transform-origin: left bottom;
    -webkit-transform: rotate3d(0, 0, 1, 45deg);
    transform: rotate3d(0, 0, 1, 45deg);
    opacity: 0; } }

.rotateOutDownLeft {
  -webkit-animation-name: rotateOutDownLeft;
  animation-name: rotateOutDownLeft; }

@-webkit-keyframes rotateOutDownRight {
  from {
    -webkit-transform-origin: right bottom;
    transform-origin: right bottom;
    opacity: 1; }

  to {
    -webkit-transform-origin: right bottom;
    transform-origin: right bottom;
    -webkit-transform: rotate3d(0, 0, 1, -45deg);
    transform: rotate3d(0, 0, 1, -45deg);
    opacity: 0; } }

@keyframes rotateOutDownRight {
  from {
    -webkit-transform-origin: right bottom;
    transform-origin: right bottom;
    opacity: 1; }

  to {
    -webkit-transform-origin: right bottom;
    transform-origin: right bottom;
    -webkit-transform: rotate3d(0, 0, 1, -45deg);
    transform: rotate3d(0, 0, 1, -45deg);
    opacity: 0; } }

.rotateOutDownRight {
  -webkit-animation-name: rotateOutDownRight;
  animation-name: rotateOutDownRight; }

@-webkit-keyframes rotateOutUpLeft {
  from {
    -webkit-transform-origin: left bottom;
    transform-origin: left bottom;
    opacity: 1; }

  to {
    -webkit-transform-origin: left bottom;
    transform-origin: left bottom;
    -webkit-transform: rotate3d(0, 0, 1, -45deg);
    transform: rotate3d(0, 0, 1, -45deg);
    opacity: 0; } }

@keyframes rotateOutUpLeft {
  from {
    -webkit-transform-origin: left bottom;
    transform-origin: left bottom;
    opacity: 1; }

  to {
    -webkit-transform-origin: left bottom;
    transform-origin: left bottom;
    -webkit-transform: rotate3d(0, 0, 1, -45deg);
    transform: rotate3d(0, 0, 1, -45deg);
    opacity: 0; } }

.rotateOutUpLeft {
  -webkit-animation-name: rotateOutUpLeft;
  animation-name: rotateOutUpLeft; }

@-webkit-keyframes rotateOutUpRight {
  from {
    -webkit-transform-origin: right bottom;
    transform-origin: right bottom;
    opacity: 1; }

  to {
    -webkit-transform-origin: right bottom;
    transform-origin: right bottom;
    -webkit-transform: rotate3d(0, 0, 1, 90deg);
    transform: rotate3d(0, 0, 1, 90deg);
    opacity: 0; } }

@keyframes rotateOutUpRight {
  from {
    -webkit-transform-origin: right bottom;
    transform-origin: right bottom;
    opacity: 1; }

  to {
    -webkit-transform-origin: right bottom;
    transform-origin: right bottom;
    -webkit-transform: rotate3d(0, 0, 1, 90deg);
    transform: rotate3d(0, 0, 1, 90deg);
    opacity: 0; } }

.rotateOutUpRight {
  -webkit-animation-name: rotateOutUpRight;
  animation-name: rotateOutUpRight; }

@-webkit-keyframes hinge {
  0% {
    -webkit-transform-origin: top left;
    transform-origin: top left;
    -webkit-animation-timing-function: ease-in-out;
    animation-timing-function: ease-in-out; }

  20%, 60% {
    -webkit-transform: rotate3d(0, 0, 1, 80deg);
    transform: rotate3d(0, 0, 1, 80deg);
    -webkit-transform-origin: top left;
    transform-origin: top left;
    -webkit-animation-timing-function: ease-in-out;
    animation-timing-function: ease-in-out; }

  40%, 80% {
    -webkit-transform: rotate3d(0, 0, 1, 60deg);
    transform: rotate3d(0, 0, 1, 60deg);
    -webkit-transform-origin: top left;
    transform-origin: top left;
    -webkit-animation-timing-function: ease-in-out;
    animation-timing-function: ease-in-out;
    opacity: 1; }

  to {
    -webkit-transform: translate3d(0, 700px, 0);
    transform: translate3d(0, 700px, 0);
    opacity: 0; } }

@keyframes hinge {
  0% {
    -webkit-transform-origin: top left;
    transform-origin: top left;
    -webkit-animation-timing-function: ease-in-out;
    animation-timing-function: ease-in-out; }

  20%, 60% {
    -webkit-transform: rotate3d(0, 0, 1, 80deg);
    transform: rotate3d(0, 0, 1, 80deg);
    -webkit-transform-origin: top left;
    transform-origin: top left;
    -webkit-animation-timing-function: ease-in-out;
    animation-timing-function: ease-in-out; }

  40%, 80% {
    -webkit-transform: rotate3d(0, 0, 1, 60deg);
    transform: rotate3d(0, 0, 1, 60deg);
    -webkit-transform-origin: top left;
    transform-origin: top left;
    -webkit-animation-timing-function: ease-in-out;
    animation-timing-function: ease-in-out;
    opacity: 1; }

  to {
    -webkit-transform: translate3d(0, 700px, 0);
    transform: translate3d(0, 700px, 0);
    opacity: 0; } }

.hinge {
  -webkit-animation-name: hinge;
  animation-name: hinge; }
/* originally authored by Nick Pettit - https://github.com/nickpettit/glide */
@-webkit-keyframes rollIn {
  from {
    opacity: 0;
    -webkit-transform: translate3d(-100%, 0, 0) rotate3d(0, 0, 1, -120deg);
    transform: translate3d(-100%, 0, 0) rotate3d(0, 0, 1, -120deg); }

  to {
    opacity: 1;
    -webkit-transform: none;
    transform: none; } }

@keyframes rollIn {
  from {
    opacity: 0;
    -webkit-transform: translate3d(-100%, 0, 0) rotate3d(0, 0, 1, -120deg);
    transform: translate3d(-100%, 0, 0) rotate3d(0, 0, 1, -120deg); }

  to {
    opacity: 1;
    -webkit-transform: none;
    transform: none; } }

.rollIn {
  -webkit-animation-name: rollIn;
  animation-name: rollIn; }
/* originally authored by Nick Pettit - https://github.com/nickpettit/glide */
@-webkit-keyframes rollOut {
  from {
    opacity: 1; }

  to {
    opacity: 0;
    -webkit-transform: translate3d(100%, 0, 0) rotate3d(0, 0, 1, 120deg);
    transform: translate3d(100%, 0, 0) rotate3d(0, 0, 1, 120deg); } }

@keyframes rollOut {
  from {
    opacity: 1; }

  to {
    opacity: 0;
    -webkit-transform: translate3d(100%, 0, 0) rotate3d(0, 0, 1, 120deg);
    transform: translate3d(100%, 0, 0) rotate3d(0, 0, 1, 120deg); } }

.rollOut {
  -webkit-animation-name: rollOut;
  animation-name: rollOut; }

@-webkit-keyframes zoomIn {
  from {
    opacity: 0;
    -webkit-transform: scale3d(0.3, 0.3, 0.3);
    transform: scale3d(0.3, 0.3, 0.3); }

  50% {
    opacity: 1; } }

@keyframes zoomIn {
  from {
    opacity: 0;
    -webkit-transform: scale3d(0.3, 0.3, 0.3);
    transform: scale3d(0.3, 0.3, 0.3); }

  50% {
    opacity: 1; } }

.zoomIn {
  -webkit-animation-name: zoomIn;
  animation-name: zoomIn; }

@-webkit-keyframes zoomInDown {
  from {
    opacity: 0;
    -webkit-transform: scale3d(0.1, 0.1, 0.1) translate3d(0, -1000px, 0);
    transform: scale3d(0.1, 0.1, 0.1) translate3d(0, -1000px, 0);
    -webkit-animation-timing-function: cubic-bezier(0.55, 0.055, 0.675, 0.19);
    animation-timing-function: cubic-bezier(0.55, 0.055, 0.675, 0.19); }

  60% {
    opacity: 1;
    -webkit-transform: scale3d(0.475, 0.475, 0.475) translate3d(0, 60px, 0);
    transform: scale3d(0.475, 0.475, 0.475) translate3d(0, 60px, 0);
    -webkit-animation-timing-function: cubic-bezier(0.175, 0.885, 0.32, 1);
    animation-timing-function: cubic-bezier(0.175, 0.885, 0.32, 1); } }

@keyframes zoomInDown {
  from {
    opacity: 0;
    -webkit-transform: scale3d(0.1, 0.1, 0.1) translate3d(0, -1000px, 0);
    transform: scale3d(0.1, 0.1, 0.1) translate3d(0, -1000px, 0);
    -webkit-animation-timing-function: cubic-bezier(0.55, 0.055, 0.675, 0.19);
    animation-timing-function: cubic-bezier(0.55, 0.055, 0.675, 0.19); }

  60% {
    opacity: 1;
    -webkit-transform: scale3d(0.475, 0.475, 0.475) translate3d(0, 60px, 0);
    transform: scale3d(0.475, 0.475, 0.475) translate3d(0, 60px, 0);
    -webkit-animation-timing-function: cubic-bezier(0.175, 0.885, 0.32, 1);
    animation-timing-function: cubic-bezier(0.175, 0.885, 0.32, 1); } }

.zoomInDown {
  -webkit-animation-name: zoomInDown;
  animation-name: zoomInDown; }

@-webkit-keyframes zoomInLeft {
  from {
    opacity: 0;
    -webkit-transform: scale3d(0.1, 0.1, 0.1) translate3d(-1000px, 0, 0);
    transform: scale3d(0.1, 0.1, 0.1) translate3d(-1000px, 0, 0);
    -webkit-animation-timing-function: cubic-bezier(0.55, 0.055, 0.675, 0.19);
    animation-timing-function: cubic-bezier(0.55, 0.055, 0.675, 0.19); }

  60% {
    opacity: 1;
    -webkit-transform: scale3d(0.475, 0.475, 0.475) translate3d(10px, 0, 0);
    transform: scale3d(0.475, 0.475, 0.475) translate3d(10px, 0, 0);
    -webkit-animation-timing-function: cubic-bezier(0.175, 0.885, 0.32, 1);
    animation-timing-function: cubic-bezier(0.175, 0.885, 0.32, 1); } }

@keyframes zoomInLeft {
  from {
    opacity: 0;
    -webkit-transform: scale3d(0.1, 0.1, 0.1) translate3d(-1000px, 0, 0);
    transform: scale3d(0.1, 0.1, 0.1) translate3d(-1000px, 0, 0);
    -webkit-animation-timing-function: cubic-bezier(0.55, 0.055, 0.675, 0.19);
    animation-timing-function: cubic-bezier(0.55, 0.055, 0.675, 0.19); }

  60% {
    opacity: 1;
    -webkit-transform: scale3d(0.475, 0.475, 0.475) translate3d(10px, 0, 0);
    transform: scale3d(0.475, 0.475, 0.475) translate3d(10px, 0, 0);
    -webkit-animation-timing-function: cubic-bezier(0.175, 0.885, 0.32, 1);
    animation-timing-function: cubic-bezier(0.175, 0.885, 0.32, 1); } }

.zoomInLeft {
  -webkit-animation-name: zoomInLeft;
  animation-name: zoomInLeft; }

@-webkit-keyframes zoomInRight {
  from {
    opacity: 0;
    -webkit-transform: scale3d(0.1, 0.1, 0.1) translate3d(1000px, 0, 0);
    transform: scale3d(0.1, 0.1, 0.1) translate3d(1000px, 0, 0);
    -webkit-animation-timing-function: cubic-bezier(0.55, 0.055, 0.675, 0.19);
    animation-timing-function: cubic-bezier(0.55, 0.055, 0.675, 0.19); }

  60% {
    opacity: 1;
    -webkit-transform: scale3d(0.475, 0.475, 0.475) translate3d(-10px, 0, 0);
    transform: scale3d(0.475, 0.475, 0.475) translate3d(-10px, 0, 0);
    -webkit-animation-timing-function: cubic-bezier(0.175, 0.885, 0.32, 1);
    animation-timing-function: cubic-bezier(0.175, 0.885, 0.32, 1); } }

@keyframes zoomInRight {
  from {
    opacity: 0;
    -webkit-transform: scale3d(0.1, 0.1, 0.1) translate3d(1000px, 0, 0);
    transform: scale3d(0.1, 0.1, 0.1) translate3d(1000px, 0, 0);
    -webkit-animation-timing-function: cubic-bezier(0.55, 0.055, 0.675, 0.19);
    animation-timing-function: cubic-bezier(0.55, 0.055, 0.675, 0.19); }

  60% {
    opacity: 1;
    -webkit-transform: scale3d(0.475, 0.475, 0.475) translate3d(-10px, 0, 0);
    transform: scale3d(0.475, 0.475, 0.475) translate3d(-10px, 0, 0);
    -webkit-animation-timing-function: cubic-bezier(0.175, 0.885, 0.32, 1);
    animation-timing-function: cubic-bezier(0.175, 0.885, 0.32, 1); } }

.zoomInRight {
  -webkit-animation-name: zoomInRight;
  animation-name: zoomInRight; }

@-webkit-keyframes zoomInUp {
  from {
    opacity: 0;
    -webkit-transform: scale3d(0.1, 0.1, 0.1) translate3d(0, 1000px, 0);
    transform: scale3d(0.1, 0.1, 0.1) translate3d(0, 1000px, 0);
    -webkit-animation-timing-function: cubic-bezier(0.55, 0.055, 0.675, 0.19);
    animation-timing-function: cubic-bezier(0.55, 0.055, 0.675, 0.19); }

  60% {
    opacity: 1;
    -webkit-transform: scale3d(0.475, 0.475, 0.475) translate3d(0, -60px, 0);
    transform: scale3d(0.475, 0.475, 0.475) translate3d(0, -60px, 0);
    -webkit-animation-timing-function: cubic-bezier(0.175, 0.885, 0.32, 1);
    animation-timing-function: cubic-bezier(0.175, 0.885, 0.32, 1); } }

@keyframes zoomInUp {
  from {
    opacity: 0;
    -webkit-transform: scale3d(0.1, 0.1, 0.1) translate3d(0, 1000px, 0);
    transform: scale3d(0.1, 0.1, 0.1) translate3d(0, 1000px, 0);
    -webkit-animation-timing-function: cubic-bezier(0.55, 0.055, 0.675, 0.19);
    animation-timing-function: cubic-bezier(0.55, 0.055, 0.675, 0.19); }

  60% {
    opacity: 1;
    -webkit-transform: scale3d(0.475, 0.475, 0.475) translate3d(0, -60px, 0);
    transform: scale3d(0.475, 0.475, 0.475) translate3d(0, -60px, 0);
    -webkit-animation-timing-function: cubic-bezier(0.175, 0.885, 0.32, 1);
    animation-timing-function: cubic-bezier(0.175, 0.885, 0.32, 1); } }

.zoomInUp {
  -webkit-animation-name: zoomInUp;
  animation-name: zoomInUp; }

@-webkit-keyframes zoomOut {
  from {
    opacity: 1; }

  50% {
    opacity: 0;
    -webkit-transform: scale3d(0.3, 0.3, 0.3);
    transform: scale3d(0.3, 0.3, 0.3); }

  to {
    opacity: 0; } }

@keyframes zoomOut {
  from {
    opacity: 1; }

  50% {
    opacity: 0;
    -webkit-transform: scale3d(0.3, 0.3, 0.3);
    transform: scale3d(0.3, 0.3, 0.3); }

  to {
    opacity: 0; } }

.zoomOut {
  -webkit-animation-name: zoomOut;
  animation-name: zoomOut; }

@-webkit-keyframes zoomOutDown {
  40% {
    opacity: 1;
    -webkit-transform: scale3d(0.475, 0.475, 0.475) translate3d(0, -60px, 0);
    transform: scale3d(0.475, 0.475, 0.475) translate3d(0, -60px, 0);
    -webkit-animation-timing-function: cubic-bezier(0.55, 0.055, 0.675, 0.19);
    animation-timing-function: cubic-bezier(0.55, 0.055, 0.675, 0.19); }

  to {
    opacity: 0;
    -webkit-transform: scale3d(0.1, 0.1, 0.1) translate3d(0, 2000px, 0);
    transform: scale3d(0.1, 0.1, 0.1) translate3d(0, 2000px, 0);
    -webkit-transform-origin: center bottom;
    transform-origin: center bottom;
    -webkit-animation-timing-function: cubic-bezier(0.175, 0.885, 0.32, 1);
    animation-timing-function: cubic-bezier(0.175, 0.885, 0.32, 1); } }

@keyframes zoomOutDown {
  40% {
    opacity: 1;
    -webkit-transform: scale3d(0.475, 0.475, 0.475) translate3d(0, -60px, 0);
    transform: scale3d(0.475, 0.475, 0.475) translate3d(0, -60px, 0);
    -webkit-animation-timing-function: cubic-bezier(0.55, 0.055, 0.675, 0.19);
    animation-timing-function: cubic-bezier(0.55, 0.055, 0.675, 0.19); }

  to {
    opacity: 0;
    -webkit-transform: scale3d(0.1, 0.1, 0.1) translate3d(0, 2000px, 0);
    transform: scale3d(0.1, 0.1, 0.1) translate3d(0, 2000px, 0);
    -webkit-transform-origin: center bottom;
    transform-origin: center bottom;
    -webkit-animation-timing-function: cubic-bezier(0.175, 0.885, 0.32, 1);
    animation-timing-function: cubic-bezier(0.175, 0.885, 0.32, 1); } }

.zoomOutDown {
  -webkit-animation-name: zoomOutDown;
  animation-name: zoomOutDown; }

@-webkit-keyframes zoomOutLeft {
  40% {
    opacity: 1;
    -webkit-transform: scale3d(0.475, 0.475, 0.475) translate3d(42px, 0, 0);
    transform: scale3d(0.475, 0.475, 0.475) translate3d(42px, 0, 0); }

  to {
    opacity: 0;
    -webkit-transform: scale(0.1) translate3d(-2000px, 0, 0);
    transform: scale(0.1) translate3d(-2000px, 0, 0);
    -webkit-transform-origin: left center;
    transform-origin: left center; } }

@keyframes zoomOutLeft {
  40% {
    opacity: 1;
    -webkit-transform: scale3d(0.475, 0.475, 0.475) translate3d(42px, 0, 0);
    transform: scale3d(0.475, 0.475, 0.475) translate3d(42px, 0, 0); }

  to {
    opacity: 0;
    -webkit-transform: scale(0.1) translate3d(-2000px, 0, 0);
    transform: scale(0.1) translate3d(-2000px, 0, 0);
    -webkit-transform-origin: left center;
    transform-origin: left center; } }

.zoomOutLeft {
  -webkit-animation-name: zoomOutLeft;
  animation-name: zoomOutLeft; }

@-webkit-keyframes zoomOutRight {
  40% {
    opacity: 1;
    -webkit-transform: scale3d(0.475, 0.475, 0.475) translate3d(-42px, 0, 0);
    transform: scale3d(0.475, 0.475, 0.475) translate3d(-42px, 0, 0); }

  to {
    opacity: 0;
    -webkit-transform: scale(0.1) translate3d(2000px, 0, 0);
    transform: scale(0.1) translate3d(2000px, 0, 0);
    -webkit-transform-origin: right center;
    transform-origin: right center; } }

@keyframes zoomOutRight {
  40% {
    opacity: 1;
    -webkit-transform: scale3d(0.475, 0.475, 0.475) translate3d(-42px, 0, 0);
    transform: scale3d(0.475, 0.475, 0.475) translate3d(-42px, 0, 0); }

  to {
    opacity: 0;
    -webkit-transform: scale(0.1) translate3d(2000px, 0, 0);
    transform: scale(0.1) translate3d(2000px, 0, 0);
    -webkit-transform-origin: right center;
    transform-origin: right center; } }

.zoomOutRight {
  -webkit-animation-name: zoomOutRight;
  animation-name: zoomOutRight; }

@-webkit-keyframes zoomOutUp {
  40% {
    opacity: 1;
    -webkit-transform: scale3d(0.475, 0.475, 0.475) translate3d(0, 60px, 0);
    transform: scale3d(0.475, 0.475, 0.475) translate3d(0, 60px, 0);
    -webkit-animation-timing-function: cubic-bezier(0.55, 0.055, 0.675, 0.19);
    animation-timing-function: cubic-bezier(0.55, 0.055, 0.675, 0.19); }

  to {
    opacity: 0;
    -webkit-transform: scale3d(0.1, 0.1, 0.1) translate3d(0, -2000px, 0);
    transform: scale3d(0.1, 0.1, 0.1) translate3d(0, -2000px, 0);
    -webkit-transform-origin: center bottom;
    transform-origin: center bottom;
    -webkit-animation-timing-function: cubic-bezier(0.175, 0.885, 0.32, 1);
    animation-timing-function: cubic-bezier(0.175, 0.885, 0.32, 1); } }

@keyframes zoomOutUp {
  40% {
    opacity: 1;
    -webkit-transform: scale3d(0.475, 0.475, 0.475) translate3d(0, 60px, 0);
    transform: scale3d(0.475, 0.475, 0.475) translate3d(0, 60px, 0);
    -webkit-animation-timing-function: cubic-bezier(0.55, 0.055, 0.675, 0.19);
    animation-timing-function: cubic-bezier(0.55, 0.055, 0.675, 0.19); }

  to {
    opacity: 0;
    -webkit-transform: scale3d(0.1, 0.1, 0.1) translate3d(0, -2000px, 0);
    transform: scale3d(0.1, 0.1, 0.1) translate3d(0, -2000px, 0);
    -webkit-transform-origin: center bottom;
    transform-origin: center bottom;
    -webkit-animation-timing-function: cubic-bezier(0.175, 0.885, 0.32, 1);
    animation-timing-function: cubic-bezier(0.175, 0.885, 0.32, 1); } }

.zoomOutUp {
  -webkit-animation-name: zoomOutUp;
  animation-name: zoomOutUp; }

@-webkit-keyframes slideInDown {
  from {
    -webkit-transform: translate3d(0, -100%, 0);
    transform: translate3d(0, -100%, 0);
    visibility: visible; }

  to {
    -webkit-transform: translate3d(0, 0, 0);
    transform: translate3d(0, 0, 0); } }

@keyframes slideInDown {
  from {
    -webkit-transform: translate3d(0, -100%, 0);
    transform: translate3d(0, -100%, 0);
    visibility: visible; }

  to {
    -webkit-transform: translate3d(0, 0, 0);
    transform: translate3d(0, 0, 0); } }

.slideInDown {
  -webkit-animation-name: slideInDown;
  animation-name: slideInDown; }

@-webkit-keyframes slideInLeft {
  from {
    -webkit-transform: translate3d(-100%, 0, 0);
    transform: translate3d(-100%, 0, 0);
    visibility: visible; }

  to {
    -webkit-transform: translate3d(0, 0, 0);
    transform: translate3d(0, 0, 0); } }

@keyframes slideInLeft {
  from {
    -webkit-transform: translate3d(-100%, 0, 0);
    transform: translate3d(-100%, 0, 0);
    visibility: visible; }

  to {
    -webkit-transform: translate3d(0, 0, 0);
    transform: translate3d(0, 0, 0); } }

.slideInLeft {
  -webkit-animation-name: slideInLeft;
  animation-name: slideInLeft; }

@-webkit-keyframes slideInRight {
  from {
    -webkit-transform: translate3d(100%, 0, 0);
    transform: translate3d(100%, 0, 0);
    visibility: visible; }

  to {
    -webkit-transform: translate3d(0, 0, 0);
    transform: translate3d(0, 0, 0); } }

@keyframes slideInRight {
  from {
    -webkit-transform: translate3d(100%, 0, 0);
    transform: translate3d(100%, 0, 0);
    visibility: visible; }

  to {
    -webkit-transform: translate3d(0, 0, 0);
    transform: translate3d(0, 0, 0); } }

.slideInRight {
  -webkit-animation-name: slideInRight;
  animation-name: slideInRight; }

@-webkit-keyframes slideInUp {
  from {
    -webkit-transform: translate3d(0, 100%, 0);
    transform: translate3d(0, 100%, 0);
    visibility: visible; }

  to {
    -webkit-transform: translate3d(0, 0, 0);
    transform: translate3d(0, 0, 0); } }

@keyframes slideInUp {
  from {
    -webkit-transform: translate3d(0, 100%, 0);
    transform: translate3d(0, 100%, 0);
    visibility: visible; }

  to {
    -webkit-transform: translate3d(0, 0, 0);
    transform: translate3d(0, 0, 0); } }

.slideInUp {
  -webkit-animation-name: slideInUp;
  animation-name: slideInUp; }

@-webkit-keyframes slideOutDown {
  from {
    -webkit-transform: translate3d(0, 0, 0);
    transform: translate3d(0, 0, 0); }

  to {
    visibility: hidden;
    -webkit-transform: translate3d(0, 100%, 0);
    transform: translate3d(0, 100%, 0); } }

@keyframes slideOutDown {
  from {
    -webkit-transform: translate3d(0, 0, 0);
    transform: translate3d(0, 0, 0); }

  to {
    visibility: hidden;
    -webkit-transform: translate3d(0, 100%, 0);
    transform: translate3d(0, 100%, 0); } }

.slideOutDown {
  -webkit-animation-name: slideOutDown;
  animation-name: slideOutDown; }

@-webkit-keyframes slideOutLeft {
  from {
    -webkit-transform: translate3d(0, 0, 0);
    transform: translate3d(0, 0, 0); }

  to {
    visibility: hidden;
    -webkit-transform: translate3d(-100%, 0, 0);
    transform: translate3d(-100%, 0, 0); } }

@keyframes slideOutLeft {
  from {
    -webkit-transform: translate3d(0, 0, 0);
    transform: translate3d(0, 0, 0); }

  to {
    visibility: hidden;
    -webkit-transform: translate3d(-100%, 0, 0);
    transform: translate3d(-100%, 0, 0); } }

.slideOutLeft {
  -webkit-animation-name: slideOutLeft;
  animation-name: slideOutLeft; }

@-webkit-keyframes slideOutRight {
  from {
    -webkit-transform: translate3d(0, 0, 0);
    transform: translate3d(0, 0, 0); }

  to {
    visibility: hidden;
    -webkit-transform: translate3d(100%, 0, 0);
    transform: translate3d(100%, 0, 0); } }

@keyframes slideOutRight {
  from {
    -webkit-transform: translate3d(0, 0, 0);
    transform: translate3d(0, 0, 0); }

  to {
    visibility: hidden;
    -webkit-transform: translate3d(100%, 0, 0);
    transform: translate3d(100%, 0, 0); } }

.slideOutRight {
  -webkit-animation-name: slideOutRight;
  animation-name: slideOutRight; }

@-webkit-keyframes slideOutUp {
  from {
    -webkit-transform: translate3d(0, 0, 0);
    transform: translate3d(0, 0, 0); }

  to {
    visibility: hidden;
    -webkit-transform: translate3d(0, -100%, 0);
    transform: translate3d(0, -100%, 0); } }

@keyframes slideOutUp {
  from {
    -webkit-transform: translate3d(0, 0, 0);
    transform: translate3d(0, 0, 0); }

  to {
    visibility: hidden;
    -webkit-transform: translate3d(0, -100%, 0);
    transform: translate3d(0, -100%, 0); } }

.slideOutUp {
  -webkit-animation-name: slideOutUp;
  animation-name: slideOutUp; }

.btn.btn-xs {
  font-size: 0.75rem;
  padding: 0.1875rem 0.5rem; }

.btn-login-outline {
  color: rgba(255, 255, 255, 0.5);
  background-image: none;
  background-color: transparent;
  border-color: rgba(255, 255, 255, 0.5); }
  .btn-login-outline:focus, .btn-login-outline.focus, .btn-login-outline:active, .btn-login-outline.active, .open > .btn-login-outline.dropdown-toggle {
    color: #fff;
    background-color: rgba(255, 255, 255, 0.5);
    border-color: rgba(255, 255, 255, 0.5); }
  .btn-login-outline:hover {
    color: #fff;
    background-color: rgba(255, 255, 255, 0.5);
    border-color: rgba(255, 255, 255, 0.5); }
  .btn-login-outline.disabled:focus, .btn-login-outline:disabled:focus, .btn-login-outline.disabled.focus, .btn-login-outline:disabled.focus {
    border-color: rgba(255, 255, 255, 0.5); }
  .btn-login-outline.disabled:hover, .btn-login-outline:disabled:hover {
    border-color: rgba(255, 255, 255, 0.5); }
  .btn-login-outline:hover {
    background: rgba(255, 255, 255, 0.1); }

.progress-primary[value]::-webkit-progress-value {
  background-color: #61259e; }
  .progress-primary[value]::-moz-progress-bar {
    background-color: #61259e; }
  @media screen and (min-width: 0 \0
    ) {
  .progress-primary .progress-bar {
    background-color: #61259e; } }

.text-faded {
  color: #bfc7c9; }

.breadcrumb {
  padding-top: 1em;
  margin-bottom: 0;
  background: transparent; }
  .breadcrumb > li {
    font-size: 0.875rem; }
  .breadcrumb > li a {
    color: #818a91; }
  .breadcrumb > li + li::before {
    padding-right: 0.5rem;
    padding-left: 0.5rem; }
  .breadcrumb > .active a {
    color: #38b5e6; }

.pagination {
  list-style-type: none;
  margin: 1rem auto 1rem auto; }
  .pagination li {
    display: inline;
    padding: 0.5rem 0.5rem; }

.input-group-addon {
  border-radius: 0; }

html, body {
  height: 100%; }

#main {
  min-height: 100vh; }

.hidden {
  display: none; }

.c-input > input:active ~ .c-indicator {
  opacity: 0.4;
  background-color: #0074d9; }
  .c-input > input:disabled ~ .c-indicator {
    opacity: 0.4; }

.c-select {
  border-radius: 0; }

#login {
  width: 100%;
  height: 100%;
  padding-top: 35vh;
  margin-top: -5rem;
  background: #61259e;
  background-repeat: no-repeat;
  background-size: cover !important;
  background-position: center center; }
  #login .logo {
    opacity: 0.6;
    text-align: center;
    margin-bottom: 2em; }
  #login form label {
    color: #fff; }
  #login form .credentials {
    position: relative; }
  #login form .credentials input {
    color: #999;
    background: rgba(66, 66, 66, 0.3);
    border-color: rgba(255, 255, 255, 0.2); }
    #login form .credentials input[type="email"] {
      margin-bottom: 0;
      border-bottom: none;
      border-bottom-left-radius: 0;
      border-bottom-right-radius: 0;
      padding-right: 40px; }
    #login form .credentials input[type="text"] {
      margin-bottom: 0;
      border-bottom: none;
      border-bottom-left-radius: 0;
      border-bottom-right-radius: 0;
      padding-right: 40px; }
    #login form .credentials input[type="password"] {
      border-top-left-radius: 0;
      border-top-right-radius: 0;
      padding-right: 40px; }
  #login form .credentials i {
    right: 1em;
    margin-top: -1.6em;
    position: absolute;
    color: #999; }
    #login form .credentials i.fa-lock {
      right: 1.15em; }

#installer {
  padding-top: 5em; }
  #installer .logo {
    text-align: center;
    margin-bottom: 3em; }
  #installer .controls.top {
    display: none; }
  #installer .finished {
    text-align: center; }
